@@ -63,18 +63,14 @@
 package org.opennms.protocols.snmp;
 
 import java.io.ByteArrayOutputStream;
-import java.io.IOException;
 import java.io.InterruptedIOException;
 import java.io.OutputStream;
 import java.io.PrintStream;
 import java.lang.reflect.Method;
 import java.net.DatagramPacket;
+import java.net.DatagramSocket;
 import java.net.InetAddress;
-import java.net.InetSocketAddress;
-import java.net.SocketAddress;
 import java.net.SocketException;
-import java.nio.ByteBuffer;
-import java.nio.channels.DatagramChannel;
 import java.util.Date;
 import java.util.LinkedList;
 import java.util.Vector;
@@ -120,7 +116,7 @@ public class SnmpPortal
 	 * SNMP messages.
 	 *
 	 */
-	private DatagramChannel m_channel;
+	private DatagramSocket m_comm;
 
 	/**
 	 * the receiver thread that runs the inner class Receiver.
@@ -309,25 +305,15 @@ public class SnmpPortal
 
 		m_handler = handler;
 
-		try {
-	        if (port >= 0) {
-	        	InetSocketAddress address = new InetSocketAddress(laddr, port);
-			    m_channel = DatagramChannel.open();
-			    m_channel.socket().bind(address);
-	        }
-	        else {
-	        	InetSocketAddress address = new InetSocketAddress(laddr, 0);
-			    m_channel = DatagramChannel.open();
-			    m_channel.socket().bind(address);
-	        }
-		} catch (SocketException e) {
-			throw e;
-		} catch (IOException e) {
-			throw new SocketException(e.getMessage());
-		}
+        if (port >= 0) {
+		    m_comm = new DatagramSocket(port, laddr);
+        }
+        else {
+            m_comm = new DatagramSocket(0, laddr);
+        }
 
-        m_channel.socket().setReceiveBufferSize(receiveBufferSize);
-        m_channel.socket().setSendBufferSize(sendBufferSize);
+        m_comm.setReceiveBufferSize(receiveBufferSize);
+        m_comm.setSendBufferSize(sendBufferSize);
         
         //
 		// Determine whether or not it is necessary to use the socket.setSoTimeout()
@@ -347,7 +333,7 @@ public class SnmpPortal
 		if (bSocketSoTimeoutRequired == true)
 		{
 			String strSocketSoTimeoutPeriod = System.getProperty(PROP_SOCKET_TIMEOUT_PERIOD);
-			int timeout = 3000; // Default socket timeout is 3 seconds
+			int timeout = 100; // Default socket timeout is 100 milli seconds
 			if (strSocketSoTimeoutPeriod != null)
 			{
 				try
@@ -356,10 +342,10 @@ public class SnmpPortal
 				}
 				catch (NumberFormatException e)
 				{
-					timeout = 3000;
+					timeout = 100;
 				}
 			}
-			m_channel.socket().setSoTimeout(timeout);
+			m_comm.setSoTimeout(timeout);
 		}
 		else if(osName != null && osName.equalsIgnoreCase("linux"))
 		{
@@ -370,7 +356,7 @@ public class SnmpPortal
 			// and the're on linux then THEY MUST have a timeout
 			// set of it will hang a thread.
 			//
-			m_channel.socket().setSoTimeout(100);
+			m_comm.setSoTimeout(100);
 		}
 
 		m_isClosing  = false;
@@ -392,7 +378,7 @@ public class SnmpPortal
 			fastExecutor.start();			
 		}
 
-		m_recvThread = new Receiver("SnmpPortal-" + m_channel.socket().getPort());
+		m_recvThread = new Receiver("SnmpPortal-" + m_comm.getPort());
 		m_encoder    = encoder;
 
 		m_recvThread.start();
@@ -487,22 +473,18 @@ public class SnmpPortal
                 LinkedList fastReceiverQ = m_fastReceiverQ;
                 while(!m_isClosing && Thread.interrupted() == false)
                 {
-                	ByteBuffer buf = getBuffer();
-                	SocketAddress sock = null;
+                    byte[] buf = getBuffer();
 
                     try
                     {
+                        DatagramPacket pkt = new DatagramPacket(buf, buf.length);
                         // workaround for Bug (JOE-22) : synchronized + isClosed 
                         synchronized (closeLock) {
-                        	if (m_channel.socket().isClosed()) {
+                        	if (m_comm.isClosed()) {
                         		break;
                         	}
-                        	sock = m_channel.receive(buf);
+                        	m_comm.receive(pkt);
                         }
-                        DatagramPacket pkt = new DatagramPacket(buf.array(), buf.array().length);
-                        pkt.setLength(buf.position());
-                        pkt.setAddress(m_channel.socket().getInetAddress());
-                        pkt.setSocketAddress(sock);
                         synchronized(fastReceiverQ)
                         {
                             fastReceiverQ.addLast(pkt);
@@ -572,11 +554,6 @@ public class SnmpPortal
             }
         }
         
-        private void interruptFastReceiver()
-        {
-        	m_fastReceiver.interrupt();
-        }
-        
 		/**
 		 * The run method is an infinite loop method that
 		 * receives all datagrams for the session. If an
@@ -806,26 +783,26 @@ public class SnmpPortal
 		}
         
         // recycle the packet buffer if possible
-		cacheBuffer(ByteBuffer.wrap(pkt.getData()));
+        cacheBuffer(pkt.getData());
 	}
 
-	ByteBuffer getBuffer()
+    byte[] getBuffer()
     {
         synchronized(m_usedBuffers)
         {
             if(!m_usedBuffers.isEmpty())
-                return (ByteBuffer) m_usedBuffers.removeFirst();
+                return (byte[]) m_usedBuffers.removeFirst();
         }
-        return ByteBuffer.allocate(DATAGRAM_SOCKET_BUFFER_SIZE);
+        
+        return new byte[DATAGRAM_SOCKET_BUFFER_SIZE];
     }
     
-    void cacheBuffer(ByteBuffer buffer)
+    void cacheBuffer(byte[] buffer)
     {
         synchronized(m_usedBuffers)
         {
             // only keep 20 * 64k of buffers around
             if(m_usedBuffers.size() < 20)
-            	buffer.rewind();
                 m_usedBuffers.addLast(buffer);
         }                
     }
@@ -997,9 +974,14 @@ public class SnmpPortal
 		throws java.io.IOException
 	{
 		//
-		// send new datagram packet
+		// create a new datagram packet
 		//
-		m_channel.send(ByteBuffer.wrap(buf, 0, length), new InetSocketAddress(peer.getPeer(), peer.getPort()));
+		DatagramPacket pkt = new DatagramPacket(buf,
+							length,
+							peer.getPeer(),
+							peer.getPort());
+
+		m_comm.send(pkt);
 
 	}
 
@@ -1090,9 +1072,8 @@ public class SnmpPortal
 	{
 		m_isClosing = true;
 		// workaround for Bug (JOE-22) : synchronized
-		m_recvThread.interruptFastReceiver();
 		synchronized (closeLock) {
-			m_channel.socket().close();
+			m_comm.close();
 		}
         m_recvThread.notifyOnClose();
         
