@@ -32,6 +32,8 @@ public class FacilityImageConstant extends FacilityConstant {
 
 	private static Image scope = null;
 
+	private static Image scopeInvalid = null;
+
 	private static Image node = null;
 
 	private static Image nodeInvalid = null;
@@ -44,7 +46,7 @@ public class FacilityImageConstant extends FacilityConstant {
 	 */
 	public static Image typeToImage(int type) {
 		ImageRegistry registry = ClusterControlPlugin.getDefault()
-		.getImageRegistry();
+				.getImageRegistry();
 
 		if (type == TYPE_COMPOSITE) {
 			if (composite == null)
@@ -57,6 +59,12 @@ public class FacilityImageConstant extends FacilityConstant {
 				.getDescriptor(ClusterControlPlugin.IMG_SCOPE)
 				.createImage();
 			return scope;
+		} else if (type == TYPE_SCOPE_INVALID) {
+			if (scopeInvalid == null)
+				scopeInvalid = registry
+				.getDescriptor(ClusterControlPlugin.IMG_SCOPE_INVALID)
+				.createImage();
+			return scopeInvalid;
 		} else if (type == TYPE_NODE) {
 			if (node == null)
 				node = registry.getDescriptor(ClusterControlPlugin.IMG_NODE)
