@@ -37,17 +37,17 @@ import com.clustercontrol.util.Messages;
  * @since 1.0.0
  */
 public class DateTimeDialog extends CommonDialog {
-	protected SWTCalendar swtcal = null;
+	private SWTCalendar swtcal = null;
 
-	protected Date dateBefore;
+	private Date dateBefore;
 
-	protected Date date;
+	private Date date;
 
-	protected Combo comboHours = null;
+	private Combo comboHours = null;
 
-	protected Combo comboMinutes = null;
+	private Combo comboMinutes = null;
 
-	protected Combo comboSecond = null;
+	private Combo comboSecond = null;
 
 	/**
 	 * コンストラクタ
