@@ -48,7 +48,11 @@ import com.clustercontrol.accesscontrol.dialog.LoginDialog;
 import com.clustercontrol.accesscontrol.etc.action.LogoutAction;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
 import com.clustercontrol.accesscontrol.util.LocalSession;
+import com.clustercontrol.jobmanagement.util.JobEditStateUtil;
+import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
 import com.clustercontrol.preference.ClusterControlCorePreferencePage;
+import com.clustercontrol.ws.access.InvalidUserPass_Exception;
+import com.clustercontrol.ws.jobmanagement.JobInfo;
 
 /**
  * ログインマネージャクラス<BR>
@@ -74,11 +78,17 @@ public class LoginManager {
 	public static final String ACTION_ID_LOGIN  = "com.clustercontrol.accesscontrol.etc.action.LoginAction";
 	public static final String ACTION_ID_LOGOUT = "com.clustercontrol.accesscontrol.etc.action.LogoutAction";
 
-	public static final String KEY_HTTP_CONNECT_TIMEOUT = "httpConnectTimeout";
+	public static final String KEY_HTTP_CONNECT_TIMEOUT = "httpConnectTimeout";	// Utilityオプションからも使用されています。
+
 	public static final int VALUE_HTTP_CONNECT_TIMEOUT = 10;
-	public static final String KEY_HTTP_REQUEST_TIMEOUT = "httpRequestTimeout";
+	public static final String KEY_HTTP_REQUEST_TIMEOUT = "httpRequestTimeout";	// Utilityオプションからも使用されています。
 	public static final int VALUE_HTTP_REQUEST_TIMEOUT = 60;
-	
+
+	public static final String KEY_HTTPS_KEYSTORE_PATH = "httpsKeystorePath";
+	public static final String VALUE_HTTPS_KEYSTORE_PATH = "";
+	public static final String KEY_HTTPS_KEYSTORE_PASSWORD = "httpsKeystorePassword";
+	public static final String VALUE_HTTPS_KEYSTORE_PASSWORD = "";
+
 	public static final String KEY_PROXY_HOST = "proxyHost";
 	public static final String VALUE_PROXY_HOST = "";
 	public static final String KEY_PROXY_PORT = "proxyPort";
@@ -87,38 +97,17 @@ public class LoginManager {
 	public static final String VALUE_PROXY_USER = "";
 	public static final String KEY_PROXY_PASSWORD = "proxyPassword";
 	public static final String VALUE_PROXY_PASSWORD = "";
-	
-	public static final String KEY_HTTPS_KEYSTORE_PATH = "httpsKeystorePath";
-	public static final String VALUE_HTTPS_KEYSTORE_PATH = "";
-	public static final String KEY_HTTPS_KEYSTORE_PASSWORD = "httpsKeystorePassword";
-	public static final String VALUE_HTTPS_KEYSTORE_PASSWORD = "";
 
-	private static LoginManager m_instance = null;
-	private String m_url = null;
-	private String m_uid = null;
-	private String m_password = null;
+	private static String m_url = null;
+	private static String m_uid = null;
+	private static String m_password = null;
 
-	private Display m_dislpay = null;
-	private IStatusLineManager m_lineManager = null;
+	private static Display m_dislpay = null;
+	private static IStatusLineManager m_lineManager = null;
 
 	/** ダイアログ表示制御用 */
 	private static boolean openInformation = false;
 
-	/**
-	 * このオブジェクトを取得します。 シングルトン
-	 * 
-	 * @return LoginManager ログインマネージャ
-	 * 
-	 * @version 2.0.0
-	 * @since 2.0.0
-	 */
-	public static LoginManager getContextManager() {
-		if (m_instance == null) {
-			m_instance = new LoginManager();
-		}
-		return m_instance;
-	}
-
 	/**
 	 * コンストラクタ
 	 * 
@@ -139,29 +128,27 @@ public class LoginManager {
 	 * @version 2.0.0
 	 * @since 2.0.0
 	 */
-	public synchronized void login(String uid, String password, String url) throws Exception {
-		//ログアウト
-		logout();
-
+	private synchronized static void login(String uid, String password, String url) throws Exception {
 		m_uid = uid;
 		m_password = password;
 		m_url = url;
 
+
 		IPreferenceStore store = ClusterControlPlugin.getDefault().getPreferenceStore();
 		int httpConnectTimeout = store.getInt(KEY_HTTP_CONNECT_TIMEOUT);
 		int httpRequestTimeout = store.getInt(KEY_HTTP_REQUEST_TIMEOUT);
 		m_log.info("connect.timeout=" + httpConnectTimeout + ", request.timeout=" + httpRequestTimeout);
-		
+
 		// HTTPS設定
 		URL u = new URL(url);
 		String keyStorePath = store.getString(KEY_HTTPS_KEYSTORE_PATH);
 		String keyStorePassword = store.getString(KEY_HTTPS_KEYSTORE_PASSWORD);
-		if(("https".equals(u.getProtocol()))){
+		if("https".equals(u.getProtocol())){
 			System.setProperty("javax.net.ssl.trustStore", keyStorePath);
 			System.setProperty("javax.net.ssl.trustStorePassword", keyStorePassword);
 			m_log.info("keystore.path=" + System.getProperty("javax.net.ssl.trustStore"));
 		}
-		
+
 		// プロキシ設定
 		String proxyHost = store.getString(KEY_PROXY_HOST);
 		int proxyPort = store.getInt(KEY_PROXY_PORT);
@@ -172,11 +159,11 @@ public class LoginManager {
 			System.setProperty(u.getProtocol() + ".proxyPort", Integer.toString(proxyPort));
 			BasicAuth basicAuth = new BasicAuth(proxyUser, proxyPassword);
 			Authenticator.setDefault(basicAuth);
-			m_log.info("proxy.host=" + System.getProperty(u.getProtocol() + ".proxyHost") + ", proxy.port=" + System.getProperty(u.getProtocol() + ".proxyPort") + ", proxy.user=" + proxyUser);
+			m_log.info("proxy.host=" + System.getProperty(u.getProtocol() + ".proxyHost") +
+					", proxy.port=" + System.getProperty("http.proxyPort") + ", proxy.user=" + proxyUser);
 		}
-		
+
 		EndpointManager.init(uid, password, url, httpConnectTimeout, httpRequestTimeout);
-		
 		try {
 			//ログインチェック
 			AccessEndpointWrapper.checkLogin();
@@ -220,7 +207,7 @@ public class LoginManager {
 			}
 
 			// クライアント側で保持するローカル情報の削除処理
-			LocalSession.getLocalSession().clearSessionData();
+			LocalSession.clearSessionData();
 			// マネージャの死活監視開始
 			LocalSession.getLocalSession().startChecktask(getInterval());
 
@@ -239,7 +226,26 @@ public class LoginManager {
 	 * @version 2.0.0
 	 * @since 2.0.0
 	 */
-	public synchronized void logout() throws NamingException {
+	public synchronized static void logout() {
+		// 既にログアウトしている場合は、何もしない。
+		if (!isLogin()) {
+			return;
+		}
+		
+		if (JobEditStateUtil.getLockedJobunitList().size() > 0) {
+			// ロックしているジョブユニットがある場合
+			for (JobInfo jobunit : JobEditStateUtil.getLockedJobunitList()) {
+				try {
+					JobEndpointWrapper.releaseEditLock(JobEditStateUtil.getEditSession(jobunit));
+					JobEditStateUtil.removeLockedJobunit(jobunit);
+				} catch (Exception e) {
+					m_log.warn("dispose() : " + e.getMessage());
+				}
+			}
+		}
+		JobEditStateUtil.clearEditStateAll();
+		
+		PerspectiveUtil.closeAllHinemosPerspective();
 		EndpointManager.logout();
 		m_uid = null;
 		m_url = null;
@@ -251,19 +257,21 @@ public class LoginManager {
 			m_lineManager.update(true);
 		}
 
-		LocalSession.getLocalSession().clearSessionData();
+		LocalSession.clearSessionData();
 		LocalSession.getLocalSession().stopChecktask();
 	}
 
 	/**
 	 * ログインチェック
 	 * 
-	 * @return
+	 * 本メソッドはUtilityオプションからも使用されています。
+	 * 
+	 * @return ログイン中か否か
 	 * 
 	 * @version 2.0.0
 	 * @since 2.0.0
 	 */
-	public boolean isLogin() {
+	public static boolean isLogin() {
 		if (m_uid != null) {
 			return true;
 		}
@@ -271,68 +279,87 @@ public class LoginManager {
 		return false;
 	}
 
-	public synchronized void getNamingContext() throws NamingException {
+	public synchronized static void login() {
 		if(!isLogin()){
-
 			Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
-
 			//ログインダイアログ表示
 			LoginDialog dialog = new LoginDialog(shell);
-
 			//ダイアログ表示
-			if (dialog.open() == IDialogConstants.OK_ID) {
-				try {
+			int loginRet = dialog.open();
+			if (loginRet != IDialogConstants.OK_ID) {
+				m_log.info("login() : cancel, " + loginRet);
+				PerspectiveUtil.closeAllHinemosPerspective();
+				return;
+			}
+			try {
 
-					//	login(dialog.getUserid(), dialog.getPassword());
-					login(dialog.getUserid(), dialog.getPassword(),dialog.getUrl());
+				// login(dialog.getUserid(), dialog.getPassword());
+				login(dialog.getUserid(), dialog.getPassword(),dialog.getUrl());
 
-					// ログイン成功ダイアログを生成
-					MessageDialog.openInformation(
-							null,
-							Messages.getString("successful"),
-							Messages.getString("message.accesscontrol.5"));
+				// ログイン成功ダイアログを生成
+				MessageDialog.openInformation(
+						null,
+						Messages.getString("successful"),
+						Messages.getString("message.accesscontrol.5"));
 
-					m_log.info("Login Success : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
-					m_log.info("Hinemos Client started");
-				} catch (CommunicationException e) {
-					// 接続失敗ダイアログを生成
-					Status status = new Status(
-							IStatus.ERROR,
-							ClusterControlPlugin.getPluginId(),
-							IStatus.OK,
-							Messages.getString("message.accesscontrol.22"),
-							e);
+				m_log.info("Login Success : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
+				m_log.info("Hinemos Client started");
+			} catch (CommunicationException e) {
+				// 接続失敗ダイアログを生成
+				Status status = new Status(
+						IStatus.ERROR,
+						ClusterControlPlugin.getPluginId(),
+						IStatus.OK,
+						Messages.getString("message.accesscontrol.22"),
+						e);
 
-					ErrorDialog.openError(
-							null,
-							Messages.getString("failed"),
-							Messages.getString("message.accesscontrol.21"),
-							status);
-					m_log.info("Login Fail : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
-				} catch (AccessException e) {
-					// ログイン失敗ダイアログを生成
-					MessageDialog.openWarning(
-							null,
-							Messages.getString("failed"),
-							Messages.getString("message.accesscontrol.6"));
-					m_log.info("Login Fail : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
-				} catch (Exception e) {
-					// 予期せぬエラーダイアログを生成
-					Status status = new Status(
-							IStatus.ERROR,
-							ClusterControlPlugin.getPluginId(),
-							IStatus.OK,
-							Messages.getString("message.accesscontrol.23"),
-							e);
+				ErrorDialog.openError(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.accesscontrol.21"),
+						status);
+				m_log.info("Login Fail : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
+				
+				// ログイン失敗の場合は再度ログインダイアログを出す。
+				login();
+			} catch (AccessException e) {
+				// ログイン失敗ダイアログを生成
+				MessageDialog.openWarning(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.accesscontrol.6"));
+				m_log.info("Login Fail : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
+				
+				// ログイン失敗の場合は再度ログインダイアログを出す。
+				login();
+			} catch (InvalidUserPass_Exception e){
+				// ログイン失敗ダイアログを生成
+				MessageDialog.openWarning(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.accesscontrol.45"));
+				m_log.info("Login Fail : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
+				
+				// ログイン失敗の場合は再度ログインダイアログを出す。
+				login();
+			} catch (Exception e) {
+				// 予期せぬエラーダイアログを生成
+				Status status = new Status(
+						IStatus.ERROR,
+						ClusterControlPlugin.getPluginId(),
+						IStatus.OK,
+						Messages.getString("message.accesscontrol.23"),
+						e);
 
-					ErrorDialog.openError(
-							null,
-							Messages.getString("failed"),
-							Messages.getString("message.accesscontrol.6"),
-							status
-					);
-					m_log.info("Login Fail : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
-				}
+				ErrorDialog.openError(
+						null,
+						Messages.getString("failed"),
+						Messages.getString("message.accesscontrol.6"),
+						status
+						);
+				m_log.info("Login Fail : userId = " + dialog.getUserid() + ", url = " + dialog.getUrl());
+				// ログイン失敗の場合は再度ログインダイアログを出す。
+				login();
 			}
 		}
 		return;
@@ -341,6 +368,8 @@ public class LoginManager {
 	/**
 	 * 接続先URLを取得します。
 	 * 
+	 * 本メソッドはUtilityオプションから使用されています。
+	 * 
 	 * @return String 接続先URL
 	 * @version 4.0.0
 	 * @since 2.0.0
@@ -349,7 +378,7 @@ public class LoginManager {
 
 		//リソースストアから接続先URLを取得
 		IPreferenceStore store = ClusterControlPlugin.getDefault()
-		.getPreferenceStore();
+				.getPreferenceStore();
 		String url = store.getString(KEY_EJB_URL);
 		if (url.compareTo("") == 0) {
 			url = VALUE_EJB_URL;
@@ -362,11 +391,11 @@ public class LoginManager {
 	 * 
 	 * @return
 	 */
-	public static int getInterval() {
+	private static int getInterval() {
 
 		//リソースストアから接続先の死活間隔を取得
 		IPreferenceStore store = ClusterControlPlugin.getDefault()
-		.getPreferenceStore();
+				.getPreferenceStore();
 		int interval = store.getInt(KEY_INTERVAL);
 
 		//m_log.debug("LoginManager.getInterval() interval = " + interval);
@@ -376,10 +405,12 @@ public class LoginManager {
 	/**
 	 * ユーザIDを取得します。
 	 * 
+	 * 本メソッドはUtilityオプションからも使用されています。
+	 * 
 	 * @return String ユーザID
 	 * @version 4.0.0
 	 */
-	public String getUserId() {
+	public static String getUserId() {
 		return m_uid;
 	}
 
@@ -389,7 +420,7 @@ public class LoginManager {
 	 * @return String パスワード
 	 * @version 4.0.0
 	 */
-	public String getPassword() {
+	public static String getPassword() {
 		return m_password;
 	}
 
@@ -398,7 +429,7 @@ public class LoginManager {
 	 * @param r
 	 * @return
 	 */
-	private boolean checkAsyncExec(Runnable r){
+	private static boolean checkAsyncExec(Runnable r){
 
 		if(m_dislpay == null){
 			//m_log.debug("LoginManager.checkAsyncExec() m_dislpay is null");
@@ -420,7 +451,7 @@ public class LoginManager {
 	/**
 	 * マネージャ切断をダイアログ表示してログアウト処理を行う
 	 */
-	public void disconnectManager(){
+	public static void disconnectManager(){
 		checkAsyncExec(new Runnable(){@Override
 			public void run() {
 			// ログアウトダイアログの表示
@@ -446,7 +477,7 @@ public class LoginManager {
 			}
 			//m_log.debug("LoginManager.disconnectManager() stop openInformation = " + openInformation);
 		}}
-		);
+				);
 
 	}
 
@@ -461,15 +492,15 @@ public class LoginManager {
 }
 
 class BasicAuth extends Authenticator{
-	 private String username;
-	 private String password;
-	 public BasicAuth(String username, String password)
-	 {
-		 this.username = username;
-		 this.password = password;
-	 }
+	private String username;
+	private String password;
+	protected BasicAuth(String username, String password){
+		this.username = username;
+		this.password = password;
+	}
 
-	 protected PasswordAuthentication getPasswordAuthentication() {
-		 return new PasswordAuthentication(username,password.toCharArray());
-	 }
+	@Override
+	protected PasswordAuthentication getPasswordAuthentication() {
+		return new PasswordAuthentication(username,password.toCharArray());
+	}
 }
\ No newline at end of file
