@@ -61,16 +61,16 @@ public abstract class ScopeListBaseView extends AutoUpdateView {
 	private Label pathLabel = null;
 
 	/** ノードをツリーに含めるか？ */
-	protected boolean scopeOnly = false;
+	private boolean scopeOnly = false;
 
 	/** 未登録ノード　スコープをツリーに含めるか？**/
-	protected boolean unregistered = true;
+	private boolean unregistered = true;
 
 	/** 内部イベント　スコープをツリーに含めるか？**/
-	protected boolean internal = true;
+	private boolean internal = true;
 
 	/** リポジトリ情報更新により、表示をリフレッシュするかどうか **/
-	protected boolean topicRefresh = true;
+	private boolean topicRefresh = true;
 
 	// ----- コンストラクタ ----- //
 
@@ -129,7 +129,7 @@ public abstract class ScopeListBaseView extends AutoUpdateView {
 		this.treeSash.setLayoutData(gridData);
 
 		// スコープツリー作成
-		this.scopeTreeComposite = new FacilityTreeComposite(treeSash, SWT.NONE, this.scopeOnly, this.unregistered, this.internal, this.topicRefresh);
+		this.scopeTreeComposite = new FacilityTreeComposite(treeSash, SWT.NONE, null, this.scopeOnly, this.unregistered, this.internal, this.topicRefresh);
 
 		// 追加コンポジットのベース作成
 		this.baseComposite = new Composite(this.treeSash, SWT.NONE);
@@ -152,9 +152,9 @@ public abstract class ScopeListBaseView extends AutoUpdateView {
 					public void selectionChanged(SelectionChangedEvent event) {
 						// 選択アイテム取得(ツリー自体でも行っているが、念のため)
 						StructuredSelection selection = (StructuredSelection) event
-						.getSelection();
+								.getSelection();
 						FacilityTreeItem selectItem = (FacilityTreeItem) selection
-						.getFirstElement();
+								.getFirstElement();
 						if (selectItem instanceof FacilityTreeItem) {
 							// パスラベルの更新
 							FacilityPath path = new FacilityPath(
