@@ -19,11 +19,13 @@
 package org.vafada.swtcalendar;
 
 import java.text.DateFormatSymbols;
+import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.List;
 import java.util.Locale;
 
+import org.eclipse.draw2d.ColorConstants;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.events.DisposeListener;
@@ -48,6 +50,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.Widget;
 
+import com.clustercontrol.ws.calendar.Ymd;
+
 public class SWTDayChooser extends Composite implements MouseListener,
 FocusListener, TraverseListener, KeyListener {
 	/**
@@ -91,6 +95,8 @@ FocusListener, TraverseListener, KeyListener {
 
 	private int style;
 
+	private ArrayList<Ymd> dateList;// = new ArrayList<Ymd>();
+
 	public SWTDayChooser(Composite parent, int style) {
 		super(parent, style & ~RED_WEEKEND);
 		this.style = style;
@@ -262,33 +268,136 @@ FocusListener, TraverseListener, KeyListener {
 		}
 	}
 
-	private static boolean isSameDay(Calendar cal1, Calendar cal2) {
+	/**
+	 * 描画処理
+	 * 複数選択用
+	 * dateListに格納されている日時と一致したら、色変更<BR>
+	 * @param dateList
+	 * @since 4.1.0
+	 */
+	protected void drawMultipleDays() {
+		calendar.get(Calendar.DAY_OF_YEAR); // Force calendar update
+		Calendar cal = (Calendar) calendar.clone();
+		int firstDayOfWeek = cal.getFirstDayOfWeek();
+		cal.set(Calendar.DAY_OF_MONTH, 1);
+
+		dayOffset = firstDayOfWeek - cal.get(Calendar.DAY_OF_WEEK);
+		if (dayOffset >= 0) {
+			dayOffset -= 7;
+		}
+		cal.add(Calendar.DAY_OF_MONTH, dayOffset);
+
+		Color foregroundColor = getForeground();
+		for (int i = 0; i < days.length; cal.add(Calendar.DAY_OF_MONTH, 1)) {
+			DayControl dayControl = days[i++];
+			dayControl
+			.setText(Integer.toString(cal.get(Calendar.DAY_OF_MONTH)));
+			if (isSameDay(cal, today)) {
+				dayControl.setBorderColor(getDisplay().getSystemColor(
+						SWT.COLOR_BLACK));
+			} else {
+				dayControl.setBorderColor(getBackground());
+			}
+
+			if (isSameMonth(cal, calendar)) {
+				int d = cal.get(Calendar.DAY_OF_WEEK);
+				if (d == Calendar.SUNDAY && (style & RED_SUNDAY) != 0
+						|| d == Calendar.SATURDAY
+						&& (style & RED_SATURDAY) != 0) {
+					dayControl.setForeground(getDisplay().getSystemColor(
+							SWT.COLOR_DARK_RED));
+				} else {
+					dayControl.setForeground(foregroundColor);
+				}
+			} else {
+				dayControl.setForeground(otherMonthColor);
+			}
+			dayControl.setBackground(getBackground());
+			//すでに、選択済みの日付の色を変更する
+			if(dateList == null){
+				continue;
+			}
+			for(Ymd ymd : dateList){
+				SimpleDateFormat sdf = new SimpleDateFormat("yyyy/M");
+				//「現在表示されている年月」＋「選択された日にち」を「yyyy/M/d」の形式に変換
+				String selectYMD = sdf.format(calendar.getTime()) + "/"+ dayControl.getText();
+				String ymdYMD = yyyyMMdd(ymd);
+				/*
+				 * 選択された日付か否か
+				 * 前後の月の日付と現在月の日付を区別するため
+				 * ラベルの色により判定する
+				 */
+				if(selectYMD.equals(ymdYMD)
+						&& !(dayControl.label.getForeground().equals(otherMonthColor))){
+					dayControl.setBackground(ColorConstants.lightBlue);
+					dayControl.setForeground(getSelectionForegroundColor());
+					break;
+				}
+			}
+		}
+	}
+	/**
+	 * Ymd(
+	 * Integer year
+	 * Integer month
+	 * Integer day
+	 * )をyyyy/M/dのString型へ変換する
+	 * @param ymd
+	 * @return yyyy/M/d
+	 */
+	private String yyyyMMdd(Ymd ymd){
+		return ymd.getYear() + "/" + ymd.getMonth() + "/" + ymd.getDay();
+	}
+	/**
+	 * 複数選択SWTカレンダを更新
+	 * @param dateList
+	 * @since 4.1.0
+	 */
+	protected void update(ArrayList<Ymd> dateList){
+		this.dateList = new ArrayList<Ymd>();
+		this.dateList = dateList;
+		drawMultipleDays();
+	}
+	protected static boolean isSameDay(Calendar cal1, Calendar cal2) {
 		return cal1.get(Calendar.DAY_OF_YEAR) == cal2.get(Calendar.DAY_OF_YEAR)
-		&& cal1.get(Calendar.YEAR) == cal2.get(Calendar.YEAR);
+				&& cal1.get(Calendar.YEAR) == cal2.get(Calendar.YEAR);
 	}
 
 	private static boolean isSameMonth(Calendar cal1, Calendar cal2) {
 		return cal1.get(Calendar.MONTH) == cal2.get(Calendar.MONTH)
-		&& cal1.get(Calendar.YEAR) == cal2.get(Calendar.YEAR);
+				&& cal1.get(Calendar.YEAR) == cal2.get(Calendar.YEAR);
 	}
 
 	public void setMonth(int month) {
 		calendar.set(Calendar.MONTH, month);
-		drawDays();
-		dateChanged();
+		//if(dateList.isEmpty()){
+		if(dateList == null){
+			drawDays();
+			dateChanged();
+		}else {
+			drawMultipleDays();
+		}
 	}
 
 	public void setYear(int year) {
 		calendar.set(Calendar.YEAR, year);
-		drawDays();
-		dateChanged();
+		if(dateList == null){
+			drawDays();
+			dateChanged();
+		}else {
+			drawMultipleDays();
+		}
 	}
 
 	public void setCalendar(Calendar cal) {
 		calendar = (Calendar) cal.clone();
 		calendar.setLenient(true);
-		drawDays();
-		dateChanged();
+		if(dateList == null){
+			drawDays();
+			dateChanged();
+		}else {
+			drawMultipleDays();
+		}
 	}
 
 	/*
@@ -484,7 +593,7 @@ FocusListener, TraverseListener, KeyListener {
 	@Override
 	public boolean isFocusControl() {
 		for (Control control = getDisplay().getFocusControl(); control != null; control = control
-		.getParent()) {
+				.getParent()) {
 			if (control == this) {
 				return true;
 			}
@@ -503,8 +612,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	private void dateChanged() {
 		if (!listeners.isEmpty()) {
-			SWTCalendarListener[] listenersArray = new SWTCalendarListener[listeners
-			                                                               .size()];
+			SWTCalendarListener[] listenersArray = new SWTCalendarListener[listeners.size()];
 			listeners.toArray(listenersArray);
 			for (int i = 0; i < listenersArray.length; i++) {
 				Event event = new Event();
