@@ -15,8 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.accesscontrol.etc.action;
 
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.action.IAction;
@@ -27,7 +25,6 @@ import org.eclipse.ui.IWorkbenchWindowActionDelegate;
 
 import com.clustercontrol.util.LoginManager;
 import com.clustercontrol.util.Messages;
-import com.clustercontrol.util.PerspectiveUtil;
 
 /**
  * ログアウトを行うアクションクラスです。
@@ -81,24 +78,15 @@ public class LogoutAction implements IWorkbenchWindowActionDelegate {
 
 	public void runLogout(){
 		// パースペクティブを閉じた後に、認証情報を削除する。
-		try {
 
-			if(LoginManager.getContextManager().isLogin()){
-
-				PerspectiveUtil.closeAllHinemosPerspective();
-				LoginManager.getContextManager().logout();
-
-			}
-			else{
-				// ログアウト済み通知ダイアログを生成
-				MessageDialog.openInformation(
-						null,
-						Messages.getString("info"),
-						Messages.getString("message.accesscontrol.18"));
-			}
-
-		} catch (NamingException e) {
-			m_log.warn("runLogout(), " + e.getMessage(), e);
+		if(LoginManager.isLogin()){
+			LoginManager.logout();
+		}else{
+			// ログアウト済み通知ダイアログを生成
+			MessageDialog.openInformation(
+					null,
+					Messages.getString("info"),
+					Messages.getString("message.accesscontrol.18"));
 		}
 	}
 
