@@ -35,7 +35,7 @@ public class LocalSession {
 	private static Log m_log = LogFactory.getLog( LoginManager.class );
 
 	/** ファシリティID更新用タイマー * */
-	protected static Timer m_timer = null;
+	private static Timer m_timer = null;
 
 	/** リポジトリ最終更新時刻 */
 	private static Date clientLastUpdate = null;
@@ -69,7 +69,7 @@ public class LocalSession {
 	}
 
 	// クライアント側で保持するローカル情報の削除処理
-	public void clearSessionData() {
+	public static void clearSessionData() {
 		// ファシリティツリーのローカルキャッシュをクリア
 		//m_log.debug("LocalSession.clearSessionData() start");
 		FacilityTree.clearCache();
@@ -80,7 +80,7 @@ public class LocalSession {
 	 * 
 	 * @return
 	 */
-	public Date getClientLastUpdate() {
+	private static Date getClientLastUpdate() {
 		return clientLastUpdate;
 	}
 
@@ -88,7 +88,7 @@ public class LocalSession {
 	 * 
 	 * @param repositoryLastUpdate
 	 */
-	public void setClientLastUpdate(Date lastUpdate) {
+	private static void setClientLastUpdate(Date lastUpdate) {
 		clientLastUpdate = lastUpdate;
 	}
 
@@ -147,15 +147,14 @@ public class LocalSession {
 	/**
 	 * 
 	 */
-	public void doCheck() {
+	public static void doCheck() {
 		//m_log.debug("LocalSession.doCheck() start");
 
 		// ログインチェック
 		//m_log.debug("LocalSession.doCheck() Login Check");
-		if(LoginManager.getContextManager().isLogin()){
+		if(LoginManager.isLogin()){
 			//m_log.debug("LocalSession.doCheck() ログイン済み");
-		}
-		else{
+		}else{
 			//m_log.debug("LocalSession.doCheck() ログイン済みでない");
 			return;
 		}
@@ -181,22 +180,22 @@ public class LocalSession {
 						e.getMessage(), e);
 			}
 			// ダイアログを表示する
-			LoginManager.getContextManager().disconnectManager();
+			LoginManager.disconnectManager();
 			return;
 		}
 
 		//m_log.debug("LocalSession.doCheck() Do Repository Update");
 		if (lastUpdate != null && getClientLastUpdate() != null) {
-			// リポジトリの最新更新時刻が古い場合にキャッシュ更新
+			// リポジトリの最新更新時刻が異なる場合にキャッシュ更新
 			//m_log.debug("LocalSession.doCheck() getClientLastUpdate().compareTo(lastUpdate) = " + getClientLastUpdate().compareTo(lastUpdate));
-			if (getClientLastUpdate().compareTo(lastUpdate) < 0) {
-				//m_log.debug("LocalSession.doCheck() update");
+			if (getClientLastUpdate().compareTo(lastUpdate) != 0) {
+				m_log.debug("LocalSession.doCheck() update");
 
 				// 最終更新時刻を更新
 				setClientLastUpdate(lastUpdate);
 
 				// リポジトリツリーキャッシュを更新して画面を再描画する
-				FacilityTree.reflesh();
+				FacilityTree.refresh();
 			}
 		}
 	}
@@ -204,7 +203,7 @@ public class LocalSession {
 	/**
 	 * EJB接続確認タイマータスク 通信エラーとなった場合はダイアログを表示する
 	 */
-	protected class SessionCheckTask extends TimerTask {
+	private class SessionCheckTask extends TimerTask {
 
 		@Override
 		public void run() {
