@@ -15,8 +15,10 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.accesscontrol.view.action;
 
+import java.security.MessageDigest;
 import java.util.List;
 
+import org.apache.commons.codec.binary.Base64;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
@@ -24,7 +26,6 @@ import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.ui.IViewActionDelegate;
 import org.eclipse.ui.IViewPart;
-import org.jboss.crypto.CryptoUtil;
 
 import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
 import com.clustercontrol.accesscontrol.dialog.ModifyPasswordDialog;
@@ -80,10 +81,10 @@ public class ModifyPasswordAction implements IViewActionDelegate {
 		// ユーザ一覧より、選択されているユーザのUIDを取得
 
 		UserListView view = (UserListView) this.viewPart
-		.getAdapter(UserListView.class);
+				.getAdapter(UserListView.class);
 
 		StructuredSelection selection = (StructuredSelection) view
-		.getComposite().getTableViewer().getSelection();
+				.getComposite().getTableViewer().getSelection();
 
 		List list = (List) selection.getFirstElement();
 		String uid = null;
@@ -94,17 +95,18 @@ public class ModifyPasswordAction implements IViewActionDelegate {
 		if (uid != null) {
 			// ダイアログを生成
 			ModifyPasswordDialog dialog =
-				new ModifyPasswordDialog(this.viewPart.getSite().getShell());
+					new ModifyPasswordDialog(this.viewPart.getSite().getShell());
 			dialog.setUserid(uid);
 
 			// ダイアログにて変更が選択された場合、入力内容をもって更新を行う。
 			if (dialog.open() == IDialogConstants.OK_ID) {
 				String password = dialog.getPassword();
 
-				String userId = LoginManager.getContextManager().getUserId();
+				String userId = LoginManager.getUserId();
 				// 自分自身のユーザパスワードは変更可能とする
 				try {
-					String passwordHash = CryptoUtil.createPasswordHash("MD5", CryptoUtil.BASE64_ENCODING, null, uid, password);
+					//String passwordHash = CryptoUtil.createPasswordHash("MD5", CryptoUtil.BASE64_ENCODING, null, uid, password);
+					String passwordHash = Base64.encodeBase64String(MessageDigest.getInstance("MD5").digest(password.getBytes()));
 					if(uid.equals(userId)){
 						AccessEndpointWrapper.changeOwnPassword(passwordHash);
 					}else{
