@@ -23,12 +23,17 @@ import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.ui.IViewActionDelegate;
 import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
+import com.clustercontrol.accesscontrol.view.RoleSettingTreeView;
 import com.clustercontrol.accesscontrol.view.UserListView;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.access.InvalidRole_Exception;
+import com.clustercontrol.ws.access.UnEditableUser_Exception;
+import com.clustercontrol.ws.access.UsedUser_Exception;
 
 /**
  * アクセス[ユーザ]ビューの「削除」のアクションクラス<BR>
@@ -72,11 +77,11 @@ public class UserDeleteAction implements IViewActionDelegate {
 	public void run(IAction action) {
 		// ユーザ一覧より、選択されているユーザのUIDを取得
 
-		UserListView view = (UserListView) this.viewPart
-		.getAdapter(UserListView.class);
+		UserListView userListView = (UserListView) this.viewPart
+				.getAdapter(UserListView.class);
 
-		StructuredSelection selection = (StructuredSelection) view
-		.getComposite().getTableViewer().getSelection();
+		StructuredSelection selection = (StructuredSelection) userListView
+				.getComposite().getTableViewer().getSelection();
 
 		List list = (List) selection.getFirstElement();
 		String uid = null;
@@ -93,35 +98,27 @@ public class UserDeleteAction implements IViewActionDelegate {
 					Messages.getString("message.accesscontrol.13", args))) {
 
 				try {
-					// 削除対象のユーザが、ジョブユニットの管理ユーザに設定されているかをチェックする
-					List<String> jobunitIdList = AccessEndpointWrapper.checkJobManagementUser(uid);
-
-					if (jobunitIdList.size() != 0) {
-						// 管理ユーザに設定されている場合
-						MessageDialog.openWarning(null, Messages.getString("message"),
-								Messages.getString("message.accesscontrol.24",
-										new String[]{ uid, jobunitIdList.toString() }));
-
-					} else {
-						try {
-							// 削除処理
-							AccessEndpointWrapper.deleteUserInfo(uid);
-							// 完了メッセージ
-							MessageDialog.openInformation(
-									null,
-									Messages.getString("successful"),
-									Messages.getString("message.accesscontrol.11"));
-
-						} catch (Exception e) {
-							throw e;
-						}
-					}
+					// 削除処理
+					AccessEndpointWrapper.deleteUserInfo(uid);
+					// 完了メッセージ
+					MessageDialog.openInformation(
+							null,
+							Messages.getString("successful"),
+							Messages.getString("message.accesscontrol.11"));
 				} catch (Exception e) {
 					String errMessage = "";
 					if (e instanceof InvalidRole_Exception) {
 						// 権限なし
 						MessageDialog.openInformation(null, Messages.getString("message"),
 								Messages.getString("message.accesscontrol.16"));
+					} else if (e instanceof UsedUser_Exception) {
+						// 現在ログインしているユーザは削除できない
+						MessageDialog.openInformation(null, Messages.getString("message"),
+								Messages.getString("message.accesscontrol.37"));
+					} else if (e instanceof UnEditableUser_Exception) {
+						// 削除不可なユーザの場合は削除できない。（システムユーザ、内部モジュール用ユーザ
+						MessageDialog.openInformation(null, Messages.getString("message"),
+								Messages.getString("message.accesscontrol.39"));
 					} else {
 						errMessage = ", " + e.getMessage();
 					}
@@ -133,7 +130,19 @@ public class UserDeleteAction implements IViewActionDelegate {
 							Messages.getString("message.accesscontrol.12") + errMessage);
 				}
 				// ビューを更新
-				view.update();
+				userListView.update();
+
+				//アクティブページを手に入れる
+				IWorkbenchPage page = PlatformUI.getWorkbench()
+						.getActiveWorkbenchWindow().getActivePage();
+
+				//ツリービューを更新する
+				IViewPart roleTreeViewPart = page.findView(RoleSettingTreeView.ID);
+				if (roleTreeViewPart != null) {
+					RoleSettingTreeView treeView = (RoleSettingTreeView) roleTreeViewPart
+							.getAdapter(RoleSettingTreeView.class);
+					treeView.update();
+				}
 			}
 		}
 	}
