@@ -19,14 +19,15 @@ import org.eclipse.ui.IFolderLayout;
 import org.eclipse.ui.IPageLayout;
 
 import com.clustercontrol.ClusterControlPerspectiveBase;
-import com.clustercontrol.calendar.view.AddInfoListView;
+import com.clustercontrol.calendar.view.CalendarPatternView;
 import com.clustercontrol.calendar.view.CalendarListView;
-import com.clustercontrol.calendar.view.WeekdayInfoListView;
+import com.clustercontrol.calendar.view.CalendarMonthView;
+import com.clustercontrol.calendar.view.CalendarWeekView;
 
 /**
  * カレンダパースペクティブクラス<BR>
  * 
- * @version 2.0.0
+ * @version 4.1.0
  * @since 2.0.0
  */
 public class CalendarPerspective extends ClusterControlPerspectiveBase {
@@ -42,18 +43,17 @@ public class CalendarPerspective extends ClusterControlPerspectiveBase {
 
 		//エディタ領域のIDを取得
 		String editorArea = layout.getEditorArea();
-		//エディタ領域の上部60%を占めるフォルダを作成
-		IFolderLayout top = layout.createFolder("top", IPageLayout.TOP,
-				0.6f, editorArea);
-		//エディタ領域の下部40%を占めるフォルダの作成
-		IFolderLayout bottom = layout.createFolder("bottom",
-				IPageLayout.BOTTOM, 0.4f, editorArea);
-		//ID=bottomの左50%を占めるフォルダを作成
-		IFolderLayout bottomLeft = layout.createFolder("bottomLeft",
-				IPageLayout.LEFT, 0.5f, "bottom");
+		//エディタ領域の上部45%を占めるフォルダを作成
+		float upper = 0.45f;
+		IFolderLayout top = layout.createFolder("top", IPageLayout.TOP, upper, editorArea);
+		//エディタ領域の上部左55%を占めるフォルダを作成
+		IFolderLayout topLeft = layout.createFolder("topLeft",IPageLayout.LEFT, 0.55f, "top");
+		//エディタ領域の下部55%を占めるフォルダの作成
+		IFolderLayout bottom = layout.createFolder("bottom",IPageLayout.BOTTOM, 1 - upper, editorArea);
 
-		top.addView(CalendarListView.ID);
-		bottomLeft.addView(WeekdayInfoListView.ID);
-		bottom.addView(AddInfoListView.ID);
+		topLeft.addView(CalendarListView.ID);
+		topLeft.addView(CalendarPatternView.ID);
+		top.addView(CalendarMonthView.ID);
+		bottom.addView(CalendarWeekView.ID);
 	}
 }
\ No newline at end of file
