@@ -34,7 +34,7 @@ import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.collectiverun.action.ModifyMaster;
 import com.clustercontrol.collectiverun.composite.action.MasterInfoModifyListener;
 import com.clustercontrol.collectiverun.util.TreeItemUtil;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.collectiverun.CommandParameterInfo;
@@ -105,8 +105,8 @@ public class CommandParameterComposite extends Composite {
 		this.id.setLayoutData(gridData);
 		this.id.addModifyListener(new MasterInfoModifyListener(this.composite));
 		List<String> list =
-			TreeItemUtil.getParameterIdList(
-					TreeItemUtil.getTopTreeItem(selectItem));
+				TreeItemUtil.getParameterIdList(
+						TreeItemUtil.getTopTreeItem(selectItem));
 		for(int i = 0; i < list.size(); i++){
 			this.id.add(list.get(i));
 		}
@@ -284,7 +284,7 @@ public class CommandParameterComposite extends Composite {
 	 * @param result
 	 *            ValidateResultオブジェクト
 	 */
-	protected void displayError(ValidateResult result) {
+	private void displayError(ValidateResult result) {
 		MessageDialog.openWarning(
 				null,
 				result.getID(),
