@@ -32,7 +32,7 @@ import com.clustercontrol.ws.collectiverun.TreeItem;
  * @since 2.1.0
  */
 public class CopyTreeItemAction extends Action {
-	protected TreeComposite composite;
+	private TreeComposite composite;
 
 	public CopyTreeItemAction(TreeComposite composite) {
 		this.composite = composite;
