@@ -27,7 +27,7 @@ import com.clustercontrol.collectiverun.composite.TreeComposite;
  * @since 2.1.0
  */
 public class MasterInfoModifyListener implements ModifyListener {
-	protected TreeComposite composite;
+	private TreeComposite composite;
 
 	/**
 	 * コンストラクタ
