@@ -30,11 +30,11 @@ import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.collectiverun.action.GetHistoryFilterProperty;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * ジョブ検索ダイアログクラス
