@@ -104,9 +104,9 @@ implements IWorkbenchPreferencePage {
 
 		// 周期
 		IntegerFieldEditor cycle =
-			new IntegerFieldEditor(
-					P_HISTORY_UPDATE_CYCLE,
-					Messages.getString("autoupdate.cycle") + " : ", group);
+				new IntegerFieldEditor(
+						P_HISTORY_UPDATE_CYCLE,
+						Messages.getString("autoupdate.cycle") + " : ", group);
 		cycle.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
 		String[] args = {
 				Integer.toString(1),
@@ -120,9 +120,9 @@ implements IWorkbenchPreferencePage {
 
 		// 表示履歴数
 		IntegerFieldEditor histories =
-			new IntegerFieldEditor(
-					P_HISTORY_MAX_HISTORIES,
-					Messages.getString("number.of.display.histories") + " : ", group);
+				new IntegerFieldEditor(
+						P_HISTORY_MAX_HISTORIES,
+						Messages.getString("number.of.display.histories") + " : ", group);
 		histories.setValidRange(1, DataRangeConstant.SMALLINT_HIGH);
 		histories.setErrorMessage(Messages.getString("message.hinemos.8", args ));
 		this.addField(histories);
@@ -145,11 +145,11 @@ implements IWorkbenchPreferencePage {
 	/**
 	 * 設定内容を反映します。
 	 */
-	protected void applySetting() {
+	private void applySetting() {
 		IPreferenceStore store = this.getPreferenceStore();
 
 		IWorkbench workbench = ClusterControlPlugin.getDefault()
-		.getWorkbench();
+				.getWorkbench();
 		IWorkbenchWindow[] windows = workbench.getWorkbenchWindows();
 
 		int windowCount = windows.length;
@@ -160,7 +160,7 @@ implements IWorkbenchPreferencePage {
 
 			for (int j = 0; j < pageCount; j++) {
 				HistoryView historyView = (HistoryView) pages[j]
-				                                              .findView(HistoryView.ID);
+						.findView(HistoryView.ID);
 				if (historyView != null) {
 					int cycle = store.getInt(P_HISTORY_UPDATE_CYCLE);
 					historyView.setInterval(cycle);
