@@ -24,6 +24,7 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.RGB;
 import org.eclipse.swt.layout.GridData;
@@ -39,6 +40,7 @@ import org.eclipse.ui.PlatformUI;
 import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
+import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.TextWithParameterComposite;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorNumericDialog;
@@ -73,6 +75,8 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 	private Button checkSelected = null;	// checkbox(指定したノードでまとめてコマンド実行)
 	private Text textNode = null;			// コマンド実行ノードのスコープ文字列を表示するテキストボックス
 	private Button buttonNode = null;		// 実行種別ボタン(特定のノードでまとめてコマンド実行)
+	private Button buttonAgentUser = null; //実効ユーザ種別（エージェント起動ユーザ）
+	private Button buttonSpecifyUser = null; //実効ユーザ種別（ユーザを指定する）
 	private Text textEffectiveUser = null;	// 実効ユーザを入力するテキストボックス
 	private TextWithParameterComposite textCommand = null;		//  コマンド文字列を入力するテキストボックス
 
@@ -94,10 +98,12 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 	 * 
 	 * @param parent 親となるシェルオブジェクト
 	 * @param monitorId 変更対象となるコマンド監視の監視項目ID
+	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public MonitorCustomDialog(Shell parent, String monitorId) {
+	public MonitorCustomDialog(Shell parent, String monitorId, boolean updateFlg) {
 		super(parent);
 		this.monitorId = monitorId;
+		this.updateFlg = updateFlg;
 	}
 
 	/**
@@ -181,7 +187,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 				// シェルを取得
 				Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
 
-				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, false, false);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, getMonitorBasicScope().getOwnerRoleId(), false, false);
 				dialog.setSelectNodeOnly(true);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem item = dialog.getSelectItem();
@@ -197,14 +203,63 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 			}
 		});
 
-		// テキストボックス(コマンド)の設定
-		label = new Label(groupCheckRule, SWT.NONE);
-		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
-		label.setText(Messages.getString("monitor.custom.effectiveuser") + " : ");
-		gridData.horizontalSpan = WIDTH_TITLE;
-		label.setLayoutData(gridData);
+		// チェック設定のグループを設定
+		Group groupEffectiveUser = new Group(groupCheckRule, SWT.NONE);
+		groupEffectiveUser.setText(Messages.getString("effective.user"));
+		layout = new GridLayout(15, true);
+		layout.marginWidth = 5;
+		layout.marginHeight = 5;
+		groupEffectiveUser.setLayout(layout);
 
-		this.textEffectiveUser = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
+		gridData.horizontalSpan = 15;
+		groupEffectiveUser.setLayoutData(gridData);
+
+		this.buttonAgentUser = new Button(groupEffectiveUser, SWT.RADIO);
+		this.buttonAgentUser.setText(Messages.getString("agent.user"));
+		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
+		gridData.horizontalSpan = 15;
+		this.buttonAgentUser.setLayoutData(gridData);
+		this.buttonAgentUser.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					buttonSpecifyUser.setSelection(false);
+					textEffectiveUser.setEnabled(false);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
+
+		this.buttonSpecifyUser = new Button(groupEffectiveUser, SWT.RADIO);
+		this.buttonSpecifyUser.setText(Messages.getString("specified.user"));
+		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
+		gridData.horizontalSpan = 4;
+		this.buttonSpecifyUser.setLayoutData(gridData);
+		this.buttonSpecifyUser.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					buttonAgentUser.setSelection(false);
+					textEffectiveUser.setEnabled(true);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
+
+		this.textEffectiveUser = new Text(groupEffectiveUser, SWT.BORDER | SWT.LEFT);
 		this.textEffectiveUser.setText("");
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL);
 		gridData.horizontalSpan = 11;
@@ -326,8 +381,8 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 			this.textNode.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
 
-		// コマンド文字列が必須項目であることを明示
-		if ("".equals(this.textEffectiveUser.getText())) {
+		// コマンド実効ユーザが必須項目であることを明示
+		if (buttonSpecifyUser.getSelection() && "".equals(this.textEffectiveUser.getText())) {
 			this.textEffectiveUser.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		} else {
 			this.textEffectiveUser.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
@@ -369,6 +424,9 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 			this.checkSelected.setSelection(false);
 			this.textNode.setEnabled(false);
 			this.buttonNode.setEnabled(false);
+			this.buttonAgentUser.setSelection(true);
+			this.buttonSpecifyUser.setSelection(false);
+			this.textEffectiveUser.setEnabled(false);
 		} else {
 			if (customInfo.getCommandExecType() == CommandExecType.INDIVIDUAL) {
 				this.checkSelected.setSelection(false);
@@ -395,6 +453,15 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 				}
 				this.textNode.setText(facilityPath);
 			}
+			if (customInfo.getSpecifyUser() == YesNoConstant.TYPE_YES) {
+				this.buttonAgentUser.setSelection(false);
+				this.buttonSpecifyUser.setSelection(true);
+				this.textEffectiveUser.setEnabled(true);
+			} else {
+				this.buttonAgentUser.setSelection(true);
+				this.buttonSpecifyUser.setSelection(false);
+				this.textEffectiveUser.setEnabled(false);
+			}
 			this.textEffectiveUser.setText(customInfo.getEffectiveUser());
 			this.textCommand.setText(customInfo.getCommand());
 		}
@@ -438,6 +505,11 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		}
 
 		// 実効ユーザの格納
+		if (this.buttonSpecifyUser.getSelection()) {
+			customInfo.setSpecifyUser(YesNoConstant.TYPE_YES);
+		} else {
+			customInfo.setSpecifyUser(YesNoConstant.TYPE_NO);
+		}
 		customInfo.setEffectiveUser(this.textEffectiveUser.getText());
 
 		// コマンド文字列の格納
@@ -486,7 +558,7 @@ public class MonitorCustomDialog extends CommonMonitorNumericDialog {
 		MonitorInfo info = this.inputData;
 		if (info != null) {
 			String[] args = { info.getMonitorId() };
-			if (this.monitorId == null) {
+			if (!this.updateFlg) {
 				// 新規作成の場合
 				try {
 					result = MonitorSettingEndpointWrapper.addMonitor(info);
