@@ -53,16 +53,18 @@ public class GetHistoryTableDefine {
 	public static final int FACILITY_ID = 8;
 	/** スコープ */
 	public static final int SCOPE = 9;
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 10;
 	/** 開始予定日時 */
-	public static final int SCHEDULED_START_TIME = 10;
+	public static final int SCHEDULED_START_TIME = 11;
 	/** 開始・再実行日時 */
-	public static final int START_RERUN_TIME = 11;
+	public static final int START_RERUN_TIME = 12;
 	/** 終了・中断日時 */
-	public static final int END_SUSPEND_TIME = 12;
+	public static final int END_SUSPEND_TIME = 13;
 	/** 実行契機種別 */
-	public static final int TRIGGER_TYPE = 13;
+	public static final int TRIGGER_TYPE = 14;
 	/** 実行契機情報 */
-	public static final int TRIGGER_INFO = 14;
+	public static final int TRIGGER_INFO = 15;
 
 	/** 初期表示時ソートカラム */
 	public static final int SORT_COLUMN_INDEX = SESSION_ID;
@@ -81,7 +83,7 @@ public class GetHistoryTableDefine {
 		Locale locale = Locale.getDefault();
 
 		tableDefine.add(STATUS,
-				new TableColumnInfo(Messages.getString("run.status", locale), TableColumnInfo.STATE, 60, SWT.LEFT));
+				new TableColumnInfo(Messages.getString("run.status", locale), TableColumnInfo.STATE, 70, SWT.LEFT));
 		tableDefine.add(END_STATUS,
 				new TableColumnInfo(Messages.getString("end.status", locale), TableColumnInfo.END_STATUS, 60, SWT.LEFT));
 		tableDefine.add(END_VALUE,
@@ -100,6 +102,8 @@ public class GetHistoryTableDefine {
 				new TableColumnInfo(Messages.getString("facility.id", locale), TableColumnInfo.NONE, 100, SWT.LEFT));
 		tableDefine.add(SCOPE,
 				new TableColumnInfo(Messages.getString("scope", locale), TableColumnInfo.FACILITY, 150, SWT.LEFT));
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
 		tableDefine.add(SCHEDULED_START_TIME,
 				new TableColumnInfo(Messages.getString("scheduled.start.time", locale), TableColumnInfo.NONE, 140, SWT.LEFT));
 		tableDefine.add(START_RERUN_TIME,
@@ -107,7 +111,7 @@ public class GetHistoryTableDefine {
 		tableDefine.add(END_SUSPEND_TIME,
 				new TableColumnInfo(Messages.getString("end.suspend.time", locale), TableColumnInfo.NONE, 140, SWT.LEFT));
 		tableDefine.add(TRIGGER_TYPE,
-				new TableColumnInfo(Messages.getString("trigger.type", locale), TableColumnInfo.NONE, 90, SWT.LEFT));
+				new TableColumnInfo(Messages.getString("trigger.type", locale), TableColumnInfo.NONE, 110, SWT.LEFT));
 		tableDefine.add(TRIGGER_INFO,
 				new TableColumnInfo(Messages.getString("trigger.info", locale), TableColumnInfo.NONE, 140, SWT.LEFT));
 
