@@ -44,7 +44,7 @@ public class OperationJob {
 		PropertyUtil.deletePropertyDefine(property);
 
 		try {
-			JobEndpointWrapper.operationJob(JobPropertyUtil.property2nodeOperation(property));
+			JobEndpointWrapper.operationJob(JobPropertyUtil.property2jobOperation(property));
 		} catch (InvalidRole_Exception e) {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
