@@ -21,9 +21,9 @@ import java.util.HashMap;
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
-import com.clustercontrol.jobmanagement.composite.JobPropertyDefine;
+import com.clustercontrol.jobmanagement.editor.JobPropertyDefine;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 
@@ -55,7 +55,7 @@ public class WaitRuleProperty {
 	 * 
 	 * <p>
 	 * <ol>
-	 *  <li>待ち条件の設定項目毎にID, 名前, 処理定数（{@link com.clustercontrol.bean.PropertyConstant}）を指定し、
+	 *  <li>待ち条件の設定項目毎にID, 名前, 処理定数（{@link com.clustercontrol.bean.PropertyDefineConstant}）を指定し、
 	 *      プロパティ（{@link com.clustercontrol.bean.Property}）を生成します。</li>
 	 *  <li>各設定項目のプロパティをツリー状に定義します。</li>
 	 * </ol>
@@ -91,7 +91,7 @@ public class WaitRuleProperty {
 	 * @return 待ち条件用プロパティ
 	 * 
 	 * @see com.clustercontrol.bean.Property
-	 * @see com.clustercontrol.bean.PropertyConstant
+	 * @see com.clustercontrol.bean.PropertyDefineConstant
 	 * @see com.clustercontrol.bean.JudgmentObjectConstant
 	 * @see com.clustercontrol.bean.EndStatusConstant
 	 */
@@ -99,15 +99,15 @@ public class WaitRuleProperty {
 	public Property getProperty(JobTreeItem item, int type) {
 		//プロパティ項目定義
 		Property judgmentObject = new Property(ID_JUDGMENT_OBJECT,
-				Messages.getString("name"), PropertyConstant.EDITOR_SELECT);
+				Messages.getString("name"), PropertyDefineConstant.EDITOR_SELECT);
 		Property job = new Property(ID_JOB_ID,
-				Messages.getString("job.id"), PropertyConstant.EDITOR_JOB);
+				Messages.getString("job.id"), PropertyDefineConstant.EDITOR_JOB);
 		Property conditionEndStatus = new Property(ID_CONDITION_END_STATUS,
-				Messages.getString("value"), PropertyConstant.EDITOR_SELECT);
+				Messages.getString("value"), PropertyDefineConstant.EDITOR_SELECT);
 		Property conditionEndValue = new Property(ID_CONDITION_END_VALUE,
-				Messages.getString("value"), PropertyConstant.EDITOR_NUM, DataRangeConstant.SMALLINT_HIGH, DataRangeConstant.SMALLINT_LOW);
+				Messages.getString("value"), PropertyDefineConstant.EDITOR_NUM, DataRangeConstant.SMALLINT_HIGH, DataRangeConstant.SMALLINT_LOW);
 		Property time = new Property(ID_TIME,
-				Messages.getString("wait.rule.time.example"), PropertyConstant.EDITOR_TIME);
+				Messages.getString("wait.rule.time.example"), PropertyDefineConstant.EDITOR_TIME);
 
 		//JobPropertyDefineクラスはClusterControlでは定義されていない
 		JobPropertyDefine define = new JobPropertyDefine(item);
@@ -149,10 +149,12 @@ public class WaitRuleProperty {
 		Object conditionEndStatuss[][] = {
 				{ EndStatusConstant.STRING_NORMAL,
 					EndStatusConstant.STRING_WARNING,
-					EndStatusConstant.STRING_ABNORMAL },
+					EndStatusConstant.STRING_ABNORMAL,
+					EndStatusConstant.STRING_ANY},
 					{ EndStatusConstant.STRING_NORMAL,
 						EndStatusConstant.STRING_WARNING,
-						EndStatusConstant.STRING_ABNORMAL } };
+						EndStatusConstant.STRING_ABNORMAL,
+						EndStatusConstant.STRING_ANY} };
 
 		judgmentObject.setSelectValues(judgmentObjectValues);
 		conditionEndStatus.setSelectValues(conditionEndStatuss);
@@ -164,11 +166,11 @@ public class WaitRuleProperty {
 		time.setValue("");
 
 		//変更の可/不可を設定
-		judgmentObject.setModify(PropertyConstant.MODIFY_OK);
-		job.setModify(PropertyConstant.MODIFY_OK);
-		conditionEndStatus.setModify(PropertyConstant.MODIFY_OK);
-		conditionEndValue.setModify(PropertyConstant.MODIFY_OK);
-		time.setModify(PropertyConstant.MODIFY_OK);
+		judgmentObject.setModify(PropertyDefineConstant.MODIFY_OK);
+		job.setModify(PropertyDefineConstant.MODIFY_OK);
+		conditionEndStatus.setModify(PropertyDefineConstant.MODIFY_OK);
+		conditionEndValue.setModify(PropertyDefineConstant.MODIFY_OK);
+		time.setModify(PropertyDefineConstant.MODIFY_OK);
 
 		Property property = new Property(null, null, null);
 
