@@ -37,16 +37,17 @@ import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.NumberVerifyListener;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.NumberVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
+import com.clustercontrol.jobmanagement.bean.CommandStopTypeConstant;
 import com.clustercontrol.jobmanagement.bean.ProcessingMethodConstant;
 import com.clustercontrol.jobmanagement.bean.SystemParameterConstant;
 import com.clustercontrol.repository.FacilityPath;
-import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobCommandInfo;
+import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
@@ -57,37 +58,49 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
  */
 public class CommandComposite extends Composite {
 	/** スコープ用テキスト */
-	protected Text m_scope = null;
+	private Text m_scope = null;
 	/** 起動コマンド用テキスト */
-	protected Text m_startCommand = null;
+	private Text m_startCommand = null;
+	/** 停止コマンド用ラジオボタン */
+	private Button m_executeStopCommand;
 	/** 停止コマンド用テキスト */
-	protected Text m_stopCommand = null;
+	private Text m_stopCommand = null;
+	/** プロセス終了用ラジオボタン */
+	private Button m_destroyProcess;
+	/** エージェントと同じユーザ用ラジオボタン */
+	private Button m_agentUser = null;
+	/** ユーザを指定する用ラジオボタン */
+	private Button m_specifyUser = null;
 	/** 実効ユーザ用テキスト */
-	protected Text m_user = null;
+	private Text m_user = null;
 	/** ジョブ変数用ラジオボタン */
-	protected Button m_scopeJobParam = null;
+	private Button m_scopeJobParam = null;
 	/** 固定値用ラジオボタン */
-	protected Button m_scopeFixedValue = null;
+	private Button m_scopeFixedValue = null;
 	/** スコープ参照用ボタン */
-	protected Button m_scopeSelect = null;
+	private Button m_scopeSelect = null;
 	/** 全てのノードで実行用ラジオボタン */
-	protected Button m_allNode = null;
+	private Button m_allNode = null;
 	/** 正常終了するまでノードを順次リトライ用ラジオボタン */
-	protected Button m_retry = null;
+	private Button m_retry = null;
 	/** コマンド実行失敗時に終了する用チェックボタン */
-	protected Button m_errorCondition = null;
+	private Button m_errorCondition = null;
 	/** 終了値用テキスト */
-	protected Text m_errorEndValue = null;
+	private Text m_errorEndValue = null;
 	/** コマンド実行失敗時に終了する用グループ */
-	protected Group m_errorEndConditionGroup = null;
+	private Group m_errorEndConditionGroup = null;
+	/** リトライ回数用テキスト */
+	private Text m_messageRetry;
 	/** ファシリティID */
-	protected String m_facilityId = null;
+	private String m_facilityId = null;
 	/** スコープ */
-	protected String m_facilityPath = null;
+	private String m_facilityPath = null;
 	/** ジョブコマンド情報 */
-	protected JobCommandInfo m_execute = null;
+	private JobCommandInfo m_execute = null;
 	/** シェル */
-	protected Shell m_shell = null;
+	private Shell m_shell = null;
+	/** オーナーロールID */
+	private String m_ownerRoleId = null;
 
 	/**
 	 * コンストラクタ
@@ -111,7 +124,7 @@ public class CommandComposite extends Composite {
 	private void initialize() {
 		RowLayout layout = new RowLayout();
 		layout.type = SWT.VERTICAL;
-		layout.spacing = 10;
+		layout.spacing = 1;
 		layout.marginWidth = 10;
 		layout.marginHeight = 10;
 		layout.fill = true;
@@ -121,6 +134,7 @@ public class CommandComposite extends Composite {
 		RowLayout rowLayout = null;
 		Label label = null;
 
+		// スコープ
 		Group group = new Group(this, SWT.NONE);
 		group.setText(Messages.getString("scope"));
 		rowLayout = new RowLayout();
@@ -137,7 +151,7 @@ public class CommandComposite extends Composite {
 		m_scopeJobParam = new Button(composite, SWT.RADIO);
 		m_scopeJobParam.setText(Messages.getString("job.parameter") + " : ");
 		m_scopeJobParam.setLayoutData(
-				new RowData(100, SizeConstant.SIZE_BUTTON_HEIGHT));
+				new RowData(120, SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_scopeJobParam.addSelectionListener(new SelectionListener() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -168,7 +182,7 @@ public class CommandComposite extends Composite {
 
 		m_scopeFixedValue = new Button(composite, SWT.RADIO);
 		m_scopeFixedValue.setText(Messages.getString("fixed.value") + " : ");
-		m_scopeFixedValue.setLayoutData(new RowData(100,
+		m_scopeFixedValue.setLayoutData(new RowData(120,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_scopeFixedValue.addSelectionListener(new SelectionListener() {
 			@Override
@@ -203,30 +217,26 @@ public class CommandComposite extends Composite {
 		m_scopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_ownerRoleId);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE) {
-						m_facilityPath = "";
-						m_facilityId = "";
-					} else {
-						FacilityPath path = new FacilityPath(
-								ClusterControlPlugin.getDefault()
-								.getSeparator());
-						m_facilityPath = path.getPath(selectItem);
-						m_facilityId = selectItem.getData().getFacilityId();
-					}
-
+					FacilityInfo info = selectItem.getData();
+					FacilityPath path = new FacilityPath(
+							ClusterControlPlugin.getDefault()
+							.getSeparator());
+					m_facilityPath = path.getPath(selectItem);
+					m_facilityId = info.getFacilityId();
 					m_scope.setText(m_facilityPath);
 					update();
 				}
 			}
 		});
 
+		// スコープ処理
 		group = new Group(this, SWT.NONE);
 		group.setText(Messages.getString("scope.process"));
 		rowLayout = new RowLayout();
-		rowLayout.type = SWT.VERTICAL;
+		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
 		group.setLayout(rowLayout);
@@ -234,11 +244,11 @@ public class CommandComposite extends Composite {
 		m_allNode = new Button(group, SWT.RADIO);
 		m_allNode.setText(Messages.getString("scope.process.all.nodes"));
 		m_allNode.setLayoutData(
-				new RowData(350,SizeConstant.SIZE_BUTTON_HEIGHT));
+				new RowData(200,SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_retry = new Button(group, SWT.RADIO);
 		m_retry.setText(Messages.getString("scope.process.retry.nodes"));
 		m_retry.setLayoutData(
-				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
+				new RowData(300, SizeConstant.SIZE_BUTTON_HEIGHT));
 
 		composite = new Composite(this, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -251,8 +261,9 @@ public class CommandComposite extends Composite {
 		label.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
+		// 起動コマンド
 		this.m_startCommand = new Text(composite, SWT.BORDER);
-		this.m_startCommand.setLayoutData(new RowData(300,
+		this.m_startCommand.setLayoutData(new RowData(400,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_startCommand.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_1024));
@@ -263,19 +274,71 @@ public class CommandComposite extends Composite {
 			}
 		});
 
-		composite = new Composite(this, SWT.NONE);
+		// 停止
+		group = new Group(this, SWT.NONE);
+		group.setText(Messages.getString("stop"));
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.marginWidth = 10;
+		rowLayout.marginHeight = 10;
+		group.setLayout(rowLayout);
+
+		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
 
-		label = new Label(composite, SWT.NONE);
-		label.setText(Messages.getString("stop.command") + " : ");
-		label.setLayoutData(new RowData(100,
-				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_destroyProcess = new Button(composite, SWT.RADIO);
+		m_destroyProcess.setText(Messages.getString("shutdown.process"));
+		m_destroyProcess.setLayoutData(
+				new RowData(190, SizeConstant.SIZE_BUTTON_HEIGHT));
+		m_destroyProcess.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					m_executeStopCommand.setSelection(false);
+					m_stopCommand.setEnabled(false);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
+
+		composite = new Composite(group, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+
+		m_executeStopCommand = new Button(composite, SWT.RADIO);
+		m_executeStopCommand.setText(Messages.getString("stop.command"));
+		m_executeStopCommand.setLayoutData(
+				new RowData(120,SizeConstant.SIZE_BUTTON_HEIGHT));
+		m_executeStopCommand.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					m_destroyProcess.setSelection(false);
+					m_stopCommand.setEnabled(true);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
 
 		this.m_stopCommand = new Text(composite, SWT.BORDER);
-		this.m_stopCommand.setLayoutData(new RowData(300,
+		this.m_stopCommand.setLayoutData(new RowData(160,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_stopCommand.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_1024));
@@ -286,18 +349,71 @@ public class CommandComposite extends Composite {
 			}
 		});
 
-		composite = new Composite(this, SWT.NONE);
+		// 実効ユーザ
+		group = new Group(this, SWT.NONE);
+		group.setText(Messages.getString("effective.user"));
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.marginWidth = 10;
+		rowLayout.marginHeight = 10;
+		group.setLayout(rowLayout);
+
+		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
 
-		label = new Label(composite, SWT.NONE);
-		label.setText(Messages.getString("effective.user") + " : ");
-		label.setLayoutData(new RowData(100, SizeConstant.SIZE_LABEL_HEIGHT));
+		m_agentUser = new Button(composite, SWT.RADIO);
+		m_agentUser.setText(Messages.getString("agent.user"));
+		m_agentUser.setLayoutData(
+				new RowData(190, SizeConstant.SIZE_BUTTON_HEIGHT));
+		m_agentUser.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					m_specifyUser.setSelection(false);
+					m_user.setEnabled(false);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
+
+		composite = new Composite(group, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+
+		m_specifyUser = new Button(composite, SWT.RADIO);
+		m_specifyUser.setText(Messages.getString("specified.user"));
+		m_specifyUser.setLayoutData(
+				new RowData(120, SizeConstant.SIZE_BUTTON_HEIGHT));
+		m_specifyUser.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					m_agentUser.setSelection(false);
+					m_user.setEnabled(true);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
 
 		this.m_user = new Text(composite, SWT.BORDER);
-		this.m_user.setLayoutData(new RowData(300, SizeConstant.SIZE_TEXT_HEIGHT));
+		this.m_user.setLayoutData(new RowData(160, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_user.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
 		this.m_user.addModifyListener(new ModifyListener(){
@@ -315,7 +431,7 @@ public class CommandComposite extends Composite {
 
 		m_errorCondition = new Button(composite, SWT.CHECK);
 		m_errorCondition.setText(Messages.getString("command.error.ended"));
-		m_errorCondition.setLayoutData(new RowData(220,
+		m_errorCondition.setLayoutData(new RowData(300,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_errorCondition.addSelectionListener(new SelectionListener() {
 			@Override
@@ -324,9 +440,11 @@ public class CommandComposite extends Composite {
 				if (check.getSelection()) {
 					m_errorEndConditionGroup.setEnabled(true);
 					m_errorEndValue.setEnabled(true);
+					m_messageRetry.setEnabled(true);
 				} else {
 					m_errorEndConditionGroup.setEnabled(false);
 					m_errorEndValue.setEnabled(false);
+					m_messageRetry.setEnabled(false);
 				}
 				update();
 			}
@@ -339,7 +457,7 @@ public class CommandComposite extends Composite {
 
 		m_errorEndConditionGroup = new Group(this, SWT.NONE);
 		rowLayout = new RowLayout();
-		rowLayout.type = SWT.VERTICAL;
+		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
 		rowLayout.spacing = 10;
@@ -350,9 +468,31 @@ public class CommandComposite extends Composite {
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
-		Label skipEndValueTitle = new Label(composite, SWT.LEFT);
+		Label messageRetryTitle = new Label(composite, SWT.LEFT);
+		messageRetryTitle.setText(Messages.getString("job.retries") + " : ");
+		messageRetryTitle.setLayoutData(new RowData(90,
+				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_messageRetry= new Text(composite, SWT.BORDER);
+		m_messageRetry.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
+		m_messageRetry.addVerifyListener(
+				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
+		m_messageRetry.addModifyListener(
+				new ModifyListener(){
+					@Override
+					public void modifyText(ModifyEvent arg0) {
+						update();
+					}
+				}
+				);
+
+		composite = new Composite(m_errorEndConditionGroup, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+		Label skipEndValueTitle = new Label(composite, SWT.RIGHT);
 		skipEndValueTitle.setText(Messages.getString("end.value") + " : ");
-		skipEndValueTitle.setLayoutData(new RowData(80,
+		skipEndValueTitle.setLayoutData(new RowData(70,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		m_errorEndValue = new Text(composite, SWT.BORDER);
 		m_errorEndValue.setLayoutData(new RowData(100,
@@ -366,7 +506,7 @@ public class CommandComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 	}
 
 	/**
@@ -386,12 +526,12 @@ public class CommandComposite extends Composite {
 		}else{
 			this.m_startCommand.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
-		if("".equals(this.m_stopCommand.getText())){
+		if(m_executeStopCommand.getSelection() && "".equals(this.m_stopCommand.getText())){
 			this.m_stopCommand.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
 			this.m_stopCommand.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
-		if("".equals(this.m_user.getText())){
+		if(m_specifyUser.getSelection() && "".equals(this.m_user.getText())){
 			this.m_user.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
 			this.m_user.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
@@ -401,6 +541,11 @@ public class CommandComposite extends Composite {
 		}else{
 			this.m_errorEndValue.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
+		if("".equals(this.m_messageRetry.getText())){
+			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
 	}
 
 	/**
@@ -416,8 +561,15 @@ public class CommandComposite extends Composite {
 		m_scope.setText("");
 		m_allNode.setSelection(true);
 		m_startCommand.setText("");
+		m_executeStopCommand.setSelection(false);
+		m_destroyProcess.setSelection(true);
 		m_stopCommand.setText("");
+		m_stopCommand.setEnabled(false);
+		m_agentUser.setSelection(true);
+		m_specifyUser.setSelection(false);
 		m_user.setText("");
+		m_user.setEnabled(false);
+		m_messageRetry.setText("10");
 		m_errorCondition.setSelection(true);
 		m_errorEndValue.setText(String
 				.valueOf(EndStatusConstant.INITIAL_VALUE_ABNORMAL));
@@ -457,15 +609,35 @@ public class CommandComposite extends Composite {
 				m_startCommand.setText(m_execute.getStartCommand());
 			}
 			//停止コマンド設定
+			if (m_execute.getStopType() == CommandStopTypeConstant.DESTROY_PROCESS) {
+				m_destroyProcess.setSelection(true);
+				m_executeStopCommand.setSelection(false);
+			} else {
+				m_destroyProcess.setSelection(false);
+				m_executeStopCommand.setSelection(true);
+				m_stopCommand.setEnabled(true);
+			}
 			if (m_execute.getStopCommand() != null
 					&& m_execute.getStopCommand().length() > 0) {
 				m_stopCommand.setText(m_execute.getStopCommand());
 			}
 			//ユーザー設定
+			if (m_execute.getSpecifyUser() == YesNoConstant.TYPE_YES) {
+				m_specifyUser.setSelection(true);
+				m_agentUser.setSelection(false);
+				m_user.setEnabled(true);
+			} else {
+				m_specifyUser.setSelection(false);
+				m_agentUser.setSelection(true);
+				m_user.setEnabled(false);
+			}
 			if (m_execute.getUser() != null && m_execute.getUser().length() > 0) {
 				m_user.setText(m_execute.getUser());
 			}
 
+			//リトライ回数
+			m_messageRetry.setText(String.valueOf(m_execute.getMessageRetry()));
+
 			//エラー時終了
 			m_errorCondition.setSelection(YesNoConstant.typeToBoolean(m_execute
 					.getErrorEndFlg()));
@@ -482,13 +654,13 @@ public class CommandComposite extends Composite {
 			m_scopeSelect.setEnabled(true);
 		}
 
-		//スキップ
+		//エラー時終了
 		if (m_errorCondition.getSelection()) {
-			m_errorEndConditionGroup.setEnabled(true);
 			m_errorEndValue.setEnabled(true);
+			m_messageRetry.setEnabled(true);
 		} else {
-			m_errorEndConditionGroup.setEnabled(false);
 			m_errorEndValue.setEnabled(false);
+			m_messageRetry.setEnabled(false);
 		}
 	}
 
@@ -564,24 +736,54 @@ public class CommandComposite extends Composite {
 		}
 
 		//停止コマンド取得
-		if (m_stopCommand.getText().length() > 0) {
-			m_execute.setStopCommand(m_stopCommand.getText());
+		if (m_destroyProcess.getSelection()) {
+			m_execute.setStopType(CommandStopTypeConstant.DESTROY_PROCESS);
 		} else {
-			result = new ValidateResult();
-			result.setValid(false);
-			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("message.job.4"));
-			return result;
+			if (m_stopCommand.getText().length() > 0) {
+				m_execute.setStopType(CommandStopTypeConstant.EXECUTE_COMMAND);
+				m_execute.setStopCommand(m_stopCommand.getText());
+			} else {
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				result.setMessage(Messages.getString("message.job.4"));
+				return result;
+			}
 		}
 
 		//ユーザー取得
-		if (m_user.getText().length() > 0) {
-			m_execute.setUser(m_user.getText());
+		if (m_agentUser.getSelection()) {
+			m_execute.setSpecifyUser(YesNoConstant.TYPE_NO);
 		} else {
+			if (m_user.getText().length() > 0) {
+				m_execute.setSpecifyUser(YesNoConstant.TYPE_YES);
+				m_execute.setUser(m_user.getText());
+			} else {
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				result.setMessage(Messages.getString("message.job.5"));
+				return result;
+			}
+		}
+
+		//リトライ回数
+		try {
+			if (m_messageRetry.getText().length() > 0) {
+				m_execute.setMessageRetry(Integer.parseInt(m_messageRetry.getText()));
+			} else {
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				//FIXME
+				result.setMessage(Messages.getString("message.job.87"));
+				return result;
+			}
+		} catch(NumberFormatException e) {
 			result = new ValidateResult();
 			result.setValid(false);
 			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("message.job.5"));
+			result.setMessage(Messages.getString("message.job.87"));
 			return result;
 		}
 
@@ -594,6 +796,12 @@ public class CommandComposite extends Composite {
 			if (m_errorEndValue.getText().length() > 0) {
 				m_execute.setErrorEndValue(Integer.parseInt(m_errorEndValue
 						.getText()));
+			} else {
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				result.setMessage(Messages.getString("message.job.21"));
+				return result;
 			}
 		} catch (NumberFormatException e) {
 			if (m_execute.getErrorEndValue() == YesNoConstant.TYPE_YES) {
@@ -607,4 +815,34 @@ public class CommandComposite extends Composite {
 
 		return null;
 	}
+
+	public void setOwnerRoleId(String ownerRoleId) {
+		this.m_ownerRoleId = ownerRoleId;
+		this.m_scope.setText("");
+		this.m_facilityId = null;
+	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		super.setEnabled(enabled);
+		m_scope.setEnabled(enabled);
+		m_startCommand.setEnabled(enabled);
+		m_executeStopCommand.setEnabled(enabled);
+		m_stopCommand.setEditable(enabled);
+		m_destroyProcess.setEnabled(enabled);
+		m_agentUser.setEnabled(enabled);
+		m_specifyUser.setEnabled(enabled);
+		m_user.setEnabled(enabled);
+		m_scopeJobParam.setEnabled(enabled);
+		m_scopeFixedValue.setEnabled(enabled);
+		m_scopeSelect.setEnabled(enabled);
+		m_allNode.setEnabled(enabled);
+		m_retry.setEnabled(enabled);
+		m_errorCondition.setEnabled(enabled);
+		m_errorEndValue.setEnabled(enabled);
+		m_messageRetry.setEnabled(enabled);
+	}
 }
\ No newline at end of file
