@@ -32,7 +32,7 @@ import com.clustercontrol.bean.EndStatusColorConstant;
 import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
-import com.clustercontrol.composite.NumberVerifyListener;
+import com.clustercontrol.composite.action.NumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
@@ -45,21 +45,21 @@ import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
  */
 public class EndStatusComposite extends Composite {
 	/** 正常終了値 */
-	protected Text m_normalValue = null;
+	private Text m_normalValue = null;
 	/** 正常終了値範囲(開始) */
-	protected Text m_normalStartRange = null;
+	private Text m_normalStartRange = null;
 	/** 正常終了値範囲(終了) */
-	protected Text m_normalEndRange = null;
+	private Text m_normalEndRange = null;
 	/** 警告終了値 */
-	protected Text m_warningValue = null;
+	private Text m_warningValue = null;
 	/** 警告終了値範囲(開始) */
-	protected Text m_warningStartRange = null;
+	private Text m_warningStartRange = null;
 	/** 警告終了値範囲(終了) */
-	protected Text m_warningEndRange = null;
+	private Text m_warningEndRange = null;
 	/** 異常終了値 */
-	protected Text m_abnormalValue = null;
+	private Text m_abnormalValue = null;
 	/** ジョブ終了値情報のリスト */
-	protected List<JobEndStatusInfo> m_end = null;
+	private List<JobEndStatusInfo> m_end = null;
 
 	/**
 	 * コンストラクタ
@@ -82,7 +82,7 @@ public class EndStatusComposite extends Composite {
 	private void initialize() {
 		RowLayout layout = new RowLayout();
 		layout.type = SWT.VERTICAL;
-		layout.spacing = 10;
+		layout.spacing = 1;
 		layout.marginWidth = 10;
 		layout.marginHeight = 10;
 		layout.fill = true;
@@ -98,7 +98,7 @@ public class EndStatusComposite extends Composite {
 		composite.setLayout(rowLayout);
 
 		Label dummy1 = new Label(composite, SWT.NONE);
-		dummy1.setLayoutData(new RowData(40, SizeConstant.SIZE_LABEL_HEIGHT));
+		dummy1.setLayoutData(new RowData(60, SizeConstant.SIZE_LABEL_HEIGHT));
 
 		Label endValueTitle = new Label(composite, SWT.CENTER);
 		endValueTitle.setText(Messages.getString("end.value"));
@@ -119,7 +119,7 @@ public class EndStatusComposite extends Composite {
 
 		Label normalTitle = new Label(composite, SWT.CENTER);
 		normalTitle.setText(EndStatusConstant.STRING_NORMAL + " : ");
-		normalTitle.setLayoutData(new RowData(40,
+		normalTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		normalTitle.setBackground(EndStatusColorConstant.COLOR_NORMAL);
 
@@ -174,7 +174,7 @@ public class EndStatusComposite extends Composite {
 
 		Label warningTitle = new Label(composite, SWT.CENTER);
 		warningTitle.setText(EndStatusConstant.STRING_WARNING + " : ");
-		warningTitle.setLayoutData(new RowData(40,
+		warningTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		warningTitle.setBackground(EndStatusColorConstant.COLOR_WARNING);
 
@@ -230,7 +230,7 @@ public class EndStatusComposite extends Composite {
 
 		Label abnormalTitle = new Label(composite, SWT.CENTER);
 		abnormalTitle.setText(EndStatusConstant.STRING_ABNORMAL + " : ");
-		abnormalTitle.setLayoutData(new RowData(40,
+		abnormalTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		abnormalTitle.setBackground(EndStatusColorConstant.COLOR_ABNORMAL);
 
@@ -505,4 +505,19 @@ public class EndStatusComposite extends Composite {
 
 		return null;
 	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		super.setEnabled(enabled);
+		m_normalValue.setEnabled(enabled);
+		m_normalStartRange.setEnabled(enabled);
+		m_normalEndRange.setEnabled(enabled);
+		m_warningValue.setEnabled(enabled);
+		m_warningStartRange.setEnabled(enabled);
+		m_warningEndRange.setEnabled(enabled);
+		m_abnormalValue.setEnabled(enabled);
+	}
 }
\ No newline at end of file
