@@ -21,6 +21,7 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.layout.RowData;
 import org.eclipse.swt.layout.RowLayout;
 import org.eclipse.swt.widgets.Button;
@@ -35,14 +36,15 @@ import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.NumberVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.bean.ProcessingMethodConstant;
 import com.clustercontrol.repository.FacilityPath;
-import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobFileInfo;
+import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
@@ -53,41 +55,51 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
  */
 public class FileComposite extends Composite {
 	/** 転送スコープ */
-	protected Text m_srcScope = null;
+	private Text m_srcScope = null;
 	/** 転送ファイル */
-	protected Text m_srcFile = null;
+	private Text m_srcFile = null;
 
 	/** 受信スコープ */
-	protected Text m_destScope = null;
+	private Text m_destScope = null;
 	/** 受信ディレクトリ */
-	protected Text m_destDirectory = null;
+	private Text m_destDirectory = null;
 
+	/** エージェント実行ユーザ用ラジオボタン */
+	private Button m_agentUser = null;
+	/** ユーザを指定する用ラジオボタン  */
+	private Button m_specifyUser = null;
 	/** 実効ユーザ */
-	protected Text m_user = null;
+	private Text m_user = null;
 	/** 転送スコープ参照ボタン */
-	protected Button m_srcScopeSelect = null;
+	private Button m_srcScopeSelect = null;
 	/** 受信スコープ参照ボタン */
-	protected Button m_destScopeSelect = null;
+	private Button m_destScopeSelect = null;
 	/** 全てのノードで受信用ラジオボタン */
-	protected Button m_allNode = null;
+	private Button m_allNode = null;
 	/** 1ノードで受信用ラジオボタン */
-	protected Button m_oneNode = null;
+	private Button m_oneNode = null;
 	/** ファイル転送時圧縮用チェックボタン */
-	protected Button m_compressionCondition = null;
+	private Button m_compressionCondition = null;
 	/** 転送ファイルチェック用チェックボタン */
-	protected Button m_checkFileCondition = null;
+	private Button m_checkFileCondition = null;
 	/** 転送ファシリティID */
-	protected String m_srcFacilityId = null;
+	private String m_srcFacilityId = null;
 	/** 転送ファシリティパス */
-	protected String m_srcFacilityPath = null;
+	private String m_srcFacilityPath = null;
 	/** 受信ファシリティID */
-	protected String m_destFacilityId = null;
+	private String m_destFacilityId = null;
 	/** 受信ファシリティパス */
-	protected String m_destFacilityPath = null;
+	private String m_destFacilityPath = null;
+	/** リトライ回数用グループ */
+	private Group m_messageRetryGroup;
+	/** リトライ回数用テキスト */
+	private Text m_messageRetry;
 	/** ジョブファイル転送情報 */
-	protected JobFileInfo m_jobFileInfo = null;
+	private JobFileInfo m_jobFileInfo = null;
 	/** シェル */
-	protected Shell m_shell = null;
+	private Shell m_shell = null;
+	/** オーナーロールID */
+	private String m_ownerRoleId = null;
 
 	/**
 	 * コンストラクタ
@@ -111,7 +123,7 @@ public class FileComposite extends Composite {
 	private void initialize() {
 		RowLayout layout = new RowLayout();
 		layout.type = SWT.VERTICAL;
-		layout.spacing = 10;
+		layout.spacing = 1;
 		layout.marginWidth = 10;
 		layout.marginHeight = 10;
 		layout.fill = true;
@@ -158,21 +170,17 @@ public class FileComposite extends Composite {
 		m_srcScopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_ownerRoleId);
+				// ノードのみ選択可能とする。
+				dialog.setSelectNodeOnly(true);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE ||
-							selectItem.getData().getFacilityType() == FacilityConstant.TYPE_SCOPE) {
-						m_srcFacilityPath = "";
-						m_srcFacilityId = "";
-					} else {
-						FacilityPath path = new FacilityPath(
-								ClusterControlPlugin.getDefault()
-								.getSeparator());
-						m_srcFacilityPath = path.getPath(selectItem);
-						m_srcFacilityId = selectItem.getData().getFacilityId();
-					}
-
+					FacilityInfo info = selectItem.getData();
+					FacilityPath path = new FacilityPath(
+							ClusterControlPlugin.getDefault()
+							.getSeparator());
+					m_srcFacilityPath = path.getPath(selectItem);
+					m_srcFacilityId = info.getFacilityId();
 					m_srcScope.setText(m_srcFacilityPath);
 				}
 			}
@@ -240,20 +248,15 @@ public class FileComposite extends Composite {
 		m_destScopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_ownerRoleId);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE) {
-						m_destFacilityPath = "";
-						m_destFacilityId = "";
-					} else {
-						FacilityPath path = new FacilityPath(
-								ClusterControlPlugin.getDefault()
-								.getSeparator());
-						m_destFacilityPath = path.getPath(selectItem);
-						m_destFacilityId = selectItem.getData().getFacilityId();
-					}
-
+					FacilityInfo info = selectItem.getData();
+					FacilityPath path = new FacilityPath(
+							ClusterControlPlugin.getDefault()
+							.getSeparator());
+					m_destFacilityPath = path.getPath(selectItem);
+					m_destFacilityId = info.getFacilityId();
 					m_destScope.setText(m_destFacilityPath);
 				}
 			}
@@ -263,7 +266,7 @@ public class FileComposite extends Composite {
 		Group methodGroup = new Group(group, SWT.NONE);
 		methodGroup.setText(Messages.getString("process.method"));
 		rowLayout = new RowLayout();
-		rowLayout.type = SWT.VERTICAL;
+		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
 		methodGroup.setLayout(rowLayout);
@@ -271,11 +274,11 @@ public class FileComposite extends Composite {
 		m_allNode = new Button(methodGroup, SWT.RADIO);
 		m_allNode.setText(Messages.getString("forward.all.nodes"));
 		m_allNode.setLayoutData(
-				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
+				new RowData(220, SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_oneNode = new Button(methodGroup, SWT.RADIO);
 		m_oneNode.setText(Messages.getString("forward.one.node"));
 		m_oneNode.setLayoutData(
-				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
+				new RowData(250, SizeConstant.SIZE_BUTTON_HEIGHT));
 
 		//転送先ディレクトリ用コンポジット
 		composite = new Composite(group, SWT.NONE);
@@ -312,31 +315,75 @@ public class FileComposite extends Composite {
 		m_compressionCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 
-		//ファイル整合性チェック用コンポジット
-		composite = new Composite(this, SWT.NONE);
-		rowLayout = new RowLayout();
-		rowLayout.type = SWT.HORIZONTAL;
-		composite.setLayout(rowLayout);
-
 		m_checkFileCondition = new Button(composite, SWT.CHECK);
 		m_checkFileCondition.setText(Messages.getString("forward.file.check"));
 		m_checkFileCondition.setLayoutData(new RowData(250,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 
-		//実効ユーザ用コンポジット
-		composite = new Composite(this, SWT.NONE);
+		group = new Group(this, SWT.NONE);
+		group.setText(Messages.getString("effective.user"));
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.VERTICAL;
+		rowLayout.marginWidth = 10;
+		rowLayout.marginHeight = 10;
+		group.setLayout(rowLayout);
+
+		composite = new Composite(group, SWT.NONE);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		composite.setLayout(rowLayout);
 
-		Label userTitle = new Label(composite, SWT.NONE);
-		userTitle.setText(Messages.getString("effective.user") + " : ");
-		userTitle
-		.setLayoutData(new RowData(100, SizeConstant.SIZE_LABEL_HEIGHT));
+		m_agentUser = new Button(composite, SWT.RADIO);
+		m_agentUser.setText(Messages.getString("agent.user"));
+		m_agentUser.setLayoutData(
+				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
+		m_agentUser.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					m_specifyUser.setSelection(false);
+					m_user.setEnabled(false);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
+
+		composite = new Composite(group, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+
+		m_specifyUser = new Button(composite, SWT.RADIO);
+		m_specifyUser.setText(Messages.getString("specified.user"));
+		m_specifyUser.setLayoutData(
+				new RowData(120, SizeConstant.SIZE_BUTTON_HEIGHT));
+		m_specifyUser.addSelectionListener(new SelectionListener() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				Button check = (Button) e.getSource();
+				if (check.getSelection()) {
+					m_agentUser.setSelection(false);
+					m_user.setEnabled(true);
+				}
+				update();
+			}
+
+			@Override
+			public void widgetDefaultSelected(SelectionEvent e) {
+
+			}
+		});
 
 		this.m_user = new Text(composite, SWT.BORDER);
-		this.m_user.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
+		this.m_user.setLayoutData(new RowData(300, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_user.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
 		this.m_user.addModifyListener(new ModifyListener(){
@@ -345,6 +392,37 @@ public class FileComposite extends Composite {
 				update();
 			}
 		});
+
+		// リトライ回数
+		m_messageRetryGroup = new Group(this, SWT.NONE);
+		m_messageRetryGroup.setText(Messages.getString("job.timeout"));
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.VERTICAL;
+		rowLayout.marginWidth = 5;
+		rowLayout.marginHeight = 5;
+		rowLayout.spacing = 1;
+		m_messageRetryGroup.setLayout(rowLayout);
+
+		composite = new Composite(m_messageRetryGroup, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		composite.setLayout(rowLayout);
+		Label messageRetryTitle = new Label(composite, SWT.LEFT);
+		messageRetryTitle.setText(Messages.getString("job.retries") + " : ");
+		messageRetryTitle.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_messageRetry= new Text(composite, SWT.BORDER);
+		m_messageRetry.setLayoutData(new RowData(300, SizeConstant.SIZE_TEXT_HEIGHT));
+		m_messageRetry.addVerifyListener(
+				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
+		m_messageRetry.addModifyListener(
+				new ModifyListener(){
+					@Override
+					public void modifyText(ModifyEvent arg0) {
+						update();
+					}
+				}
+				);
 	}
 
 	/**
@@ -364,7 +442,7 @@ public class FileComposite extends Composite {
 		}else{
 			this.m_srcFile.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
-		if("".equals(this.m_user.getText())){
+		if(m_specifyUser.getSelection() && "".equals(this.m_user.getText())){
 			this.m_user.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
 			this.m_user.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
@@ -374,11 +452,16 @@ public class FileComposite extends Composite {
 		}else{
 			this.m_destScope.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
-		if("".equals(this.m_destDirectory.getText()) || !m_destDirectory.getText().endsWith("/")){
+		if("".equals(this.m_destDirectory.getText())){
 			this.m_destDirectory.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 		}else{
 			this.m_destDirectory.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
+		if("".equals(this.m_messageRetry.getText())){
+			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		}else{
+			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
 
 	}
 
@@ -397,7 +480,11 @@ public class FileComposite extends Composite {
 		m_allNode.setSelection(true);
 		m_compressionCondition.setSelection(false);
 		m_checkFileCondition.setSelection(false);
+		m_agentUser.setSelection(true);
+		m_specifyUser.setSelection(false);
 		m_user.setText("");
+		m_user.setEnabled(false);
+		m_messageRetry.setText("10");
 
 		if (m_jobFileInfo != null) {
 			//転送元スコープ設定
@@ -437,9 +524,20 @@ public class FileComposite extends Composite {
 			m_checkFileCondition.setSelection(
 					YesNoConstant.typeToBoolean(m_jobFileInfo.getCheckFlg()));
 			//ユーザー設定
+			if (m_jobFileInfo.getSpecifyUser() == YesNoConstant.TYPE_YES) {
+				m_specifyUser.setSelection(true);
+				m_agentUser.setSelection(false);
+				m_user.setEnabled(true);
+			} else {
+				m_specifyUser.setSelection(false);
+				m_agentUser.setSelection(true);
+				m_user.setEnabled(false);
+			}
 			if (m_jobFileInfo.getUser() != null && m_jobFileInfo.getUser().length() > 0) {
 				m_user.setText(m_jobFileInfo.getUser());
 			}
+			//リトライ回数
+			m_messageRetry.setText(String.valueOf(m_jobFileInfo.getMessageRetry()));
 		}
 	}
 
@@ -516,7 +614,7 @@ public class FileComposite extends Composite {
 		}
 
 		//転送先ディレクトリ
-		if (m_destDirectory.getText().length() > 0 && m_destDirectory.getText().endsWith("/")) {
+		if (m_destDirectory.getText().length() > 0) {
 			m_jobFileInfo.setDestDirectory(m_destDirectory.getText());
 
 			// 転送先ディレクトリが指定されていない場合
@@ -528,15 +626,6 @@ public class FileComposite extends Composite {
 					Messages.getString("message.job.46"));
 			return result;
 
-			// 転送先ディレクトリ指定文字列の末尾が / でない場合
-		} else if (!m_destDirectory.getText().endsWith("/")) {
-			result = new ValidateResult();
-			result.setValid(false);
-			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("forward.destination") +
-					Messages.getString("message.job.62"));
-			return result;
-
 		}
 
 
@@ -561,16 +650,71 @@ public class FileComposite extends Composite {
 				YesNoConstant.booleanToType(m_checkFileCondition.getSelection()));
 
 		//ユーザー取得
-		if (m_user.getText().length() > 0) {
-			m_jobFileInfo.setUser(m_user.getText());
+		if (m_agentUser.getSelection()) {
+			m_jobFileInfo.setSpecifyUser(YesNoConstant.TYPE_NO);
 		} else {
+			if (m_user.getText().length() > 0) {
+				m_jobFileInfo.setSpecifyUser(YesNoConstant.TYPE_YES);
+				m_jobFileInfo.setUser(m_user.getText());
+			} else {
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				result.setMessage(Messages.getString("message.job.5"));
+				return result;
+			}
+		}
+
+		//リトライ回数
+		try {
+			if (m_messageRetry.getText().length() > 0) {
+				m_jobFileInfo.setMessageRetry(Integer.parseInt(m_messageRetry.getText()));
+			} else {
+				result = new ValidateResult();
+				result.setValid(false);
+				result.setID(Messages.getString("message.hinemos.1"));
+				//FIXME
+				result.setMessage(Messages.getString("message.job.87"));
+				return result;
+			}
+		} catch(NumberFormatException e) {
 			result = new ValidateResult();
 			result.setValid(false);
 			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("message.job.5"));
+			result.setMessage(Messages.getString("message.job.87"));
 			return result;
 		}
 
 		return null;
 	}
+
+	public void setOwnerRoleId(String ownerRoleId) {
+		this.m_ownerRoleId = ownerRoleId;
+		this.m_destScope.setText("");
+		this.m_destFacilityId = null;
+		this.m_srcScope.setText("");
+		this.m_srcFacilityId = null;
+	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		super.setEnabled(enabled);
+		m_srcScope.setEnabled(enabled);
+		m_srcFile.setEnabled(enabled);
+		m_destScope.setEnabled(enabled);
+		m_destDirectory.setEnabled(enabled);
+		m_agentUser.setEnabled(enabled);
+		m_specifyUser.setEnabled(enabled);
+		m_user.setEnabled(enabled);
+		m_srcScopeSelect.setEnabled(enabled);
+		m_destScopeSelect.setEnabled(enabled);
+		m_allNode.setEnabled(enabled);
+		m_oneNode.setEnabled(enabled);
+		m_compressionCondition.setEnabled(enabled);
+		m_checkFileCondition.setEnabled(enabled);
+		m_messageRetry.setEnabled(enabled);
+	}
 }
\ No newline at end of file
