@@ -33,7 +33,6 @@ import org.eclipse.swt.widgets.Table;
 import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.jobmanagement.action.GetHistoryTableDefine;
 import com.clustercontrol.jobmanagement.composite.action.HistorySelectionChangedListener;
 import com.clustercontrol.jobmanagement.composite.action.SessionJobDoubleClickListener;
@@ -42,6 +41,7 @@ import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
 import com.clustercontrol.jobmanagement.util.JobPropertyUtil;
 import com.clustercontrol.jobmanagement.view.JobHistoryView;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobHistory;
 import com.clustercontrol.ws.jobmanagement.JobHistoryList;
@@ -59,20 +59,20 @@ public class HistoryComposite extends Composite {
 	private static Log m_log = LogFactory.getLog( HistoryComposite.class );
 
 	/** テーブルビューア */
-	protected CommonTableViewer m_viewer = null;
+	private CommonTableViewer m_viewer = null;
 	/** ヘッダ用ラベル */
-	protected Label m_labelType = null;
+	private Label m_labelType = null;
 	/** 件数用ラベル */
-	protected Label m_labelCount = null;
+	private Label m_labelCount = null;
 	/** セッションID */
-	protected String m_sessionId = null;
+	private String m_sessionId = null;
 	/** 所属ジョブユニットのジョブID */
-	protected String m_jobunitId = null;
+	private String m_jobunitId = null;
 	/** ジョブID */
-	protected String m_jobId = null;
+	private String m_jobId = null;
+
+	private JobHistoryView m_view = null;
 
-	public JobHistoryView m_view = null;
-	
 	/**
 	 * コンストラクタ
 	 * 
@@ -87,15 +87,15 @@ public class HistoryComposite extends Composite {
 		super(parent, style);
 		initialize();
 	}
-
+	
 	public void setView(JobHistoryView view) {
 		m_view = view;
 	}
-	
+
 	public JobHistoryView getView() {
 		return m_view;
 	}
-	
+
 	/**
 	 * コンポジットを配置します。
 	 */
@@ -255,6 +255,7 @@ public class HistoryComposite extends Composite {
 			a.add(history.getJobType());
 			a.add(history.getFacilityId());
 			a.add(history.getScope());
+			a.add(history.getOwnerRoleId());
 			if (history.getScheduleDate() != null) {
 				a.add(new Date(history.getScheduleDate()));
 			} else {
