@@ -43,17 +43,17 @@ import com.clustercontrol.ws.notify.NotifyRelationInfo;
  */
 public class NotificationsComposite extends Composite {
 	/** 正常重要度用コンボボックス */
-	protected Combo m_normalPriority = null;
+	private Combo m_normalPriority = null;
 	/** 警告重要度用コンボボックス */
-	protected Combo m_warningPriority = null;
+	private Combo m_warningPriority = null;
 	/** 異常重要度用コンボボックス */
-	protected Combo m_abnormalPriority = null;
+	private Combo m_abnormalPriority = null;
 	/** 開始重要度用コンボボックス */
-	protected Combo m_startPriority = null;
+	private Combo m_startPriority = null;
 	/** 通知ID */
-	protected NotifyIdListComposite m_notifyId = null;
+	private NotifyIdListComposite m_notifyId = null;
 	/** ジョブ通知情報のリスト */
-	protected List m_notifications = null;
+	private List<JobNotificationsInfo> m_notifications = null;
 
 	/**
 	 * コンストラクタ
@@ -94,7 +94,7 @@ public class NotificationsComposite extends Composite {
 		composite.setLayout(rowLayout);
 
 		Label dummy = new Label(composite, SWT.NONE);
-		dummy.setLayoutData(new RowData(40, SizeConstant.SIZE_LABEL_HEIGHT));
+		dummy.setLayoutData(new RowData(60, SizeConstant.SIZE_LABEL_HEIGHT));
 
 		Label importanceDegreeTitle = new Label(composite, SWT.CENTER);
 		importanceDegreeTitle.setText(Messages.getString("priority"));
@@ -111,7 +111,7 @@ public class NotificationsComposite extends Composite {
 
 		Label beginningTitle = new Label(composite, SWT.CENTER);
 		beginningTitle.setText(EndStatusConstant.STRING_BEGINNING + " : ");
-		beginningTitle.setLayoutData(new RowData(50,
+		beginningTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
 		m_startPriority = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
@@ -133,7 +133,7 @@ public class NotificationsComposite extends Composite {
 
 		Label normalTitle = new Label(composite, SWT.CENTER);
 		normalTitle.setText(EndStatusConstant.STRING_NORMAL + " : ");
-		normalTitle.setLayoutData(new RowData(50,
+		normalTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		normalTitle.setBackground(EndStatusColorConstant.COLOR_NORMAL);
 
@@ -156,7 +156,7 @@ public class NotificationsComposite extends Composite {
 
 		Label warningTitle = new Label(composite, SWT.CENTER);
 		warningTitle.setText(EndStatusConstant.STRING_WARNING + " : ");
-		warningTitle.setLayoutData(new RowData(50,
+		warningTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		warningTitle.setBackground(EndStatusColorConstant.COLOR_WARNING);
 
@@ -179,7 +179,7 @@ public class NotificationsComposite extends Composite {
 
 		Label abnormalTitle = new Label(composite, SWT.CENTER);
 		abnormalTitle.setText(EndStatusConstant.STRING_ABNORMAL + " : ");
-		abnormalTitle.setLayoutData(new RowData(50,
+		abnormalTitle.setLayoutData(new RowData(60,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 		abnormalTitle.setBackground(EndStatusColorConstant.COLOR_ABNORMAL);
 
@@ -202,12 +202,10 @@ public class NotificationsComposite extends Composite {
 
 		Label notifyIdTitle = new Label(composite, SWT.CENTER);
 		notifyIdTitle.setText(Messages.getString("notify.id") + " : ");
-		notifyIdTitle.setLayoutData(new RowData(50,
+		notifyIdTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
-		m_notifyId = new NotifyIdListComposite(composite, SWT.NONE, false);
-		m_notifyId.setLayoutData(new RowData(330,
-				SizeConstant.SIZE_BUTTON_HEIGHT + 60 ));
+		m_notifyId = new NotifyIdListComposite(composite, SWT.CENTER, false);
 	}
 
 	/**
@@ -231,18 +229,18 @@ public class NotificationsComposite extends Composite {
 			JobNotificationsInfo infoStart = null;
 
 			for (int i = 0; i < m_notifications.size(); i++) {
-				if (((JobNotificationsInfo) m_notifications.get(i)).getType() == EndStatusConstant.TYPE_BEGINNING) {
-					infoStart = (JobNotificationsInfo) m_notifications.get(i);
-				} else if (((JobNotificationsInfo) m_notifications.get(i))
+				if (m_notifications.get(i).getType() == EndStatusConstant.TYPE_BEGINNING) {
+					infoStart = m_notifications.get(i);
+				} else if (m_notifications.get(i)
 						.getType() == EndStatusConstant.TYPE_NORMAL) {
-					infoNormal = (JobNotificationsInfo) m_notifications.get(i);
-				} else if (((JobNotificationsInfo) m_notifications.get(i))
+					infoNormal = m_notifications.get(i);
+				} else if (m_notifications.get(i)
 						.getType() == EndStatusConstant.TYPE_WARNING) {
-					infoWarning = (JobNotificationsInfo) m_notifications.get(i);
-				} else if (((JobNotificationsInfo) m_notifications.get(i))
+					infoWarning = m_notifications.get(i);
+				} else if (m_notifications.get(i)
 						.getType() == EndStatusConstant.TYPE_ABNORMAL) {
-					infoAbnormal = (JobNotificationsInfo) m_notifications
-					.get(i);
+					infoAbnormal = m_notifications
+							.get(i);
 				}
 			}
 
@@ -318,7 +316,6 @@ public class NotificationsComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobNotificationsInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public ValidateResult createNotificationsInfo() {
 		@SuppressWarnings("unused")
 		ValidateResult result = null;
@@ -329,7 +326,7 @@ public class NotificationsComposite extends Composite {
 		JobNotificationsInfo infoStart = null;
 
 		//メッセージ指定情報クラスのインスタンスを作成・取得
-		m_notifications = new ArrayList();
+		m_notifications = new ArrayList<JobNotificationsInfo>();
 		infoStart = new JobNotificationsInfo();
 		infoStart.setType(EndStatusConstant.TYPE_BEGINNING);
 		infoStart.setPriority(PriorityConstant.TYPE_CRITICAL);
@@ -440,4 +437,26 @@ public class NotificationsComposite extends Composite {
 
 		return -1;
 	}
+
+	public NotifyIdListComposite getNotifyId() {
+		return m_notifyId;
+	}
+
+	public void setNotifyId(NotifyIdListComposite notifyId) {
+		this.m_notifyId = notifyId;
+	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		// super.setEnabled(enabled); // スクロールバーを動かせるように、ここはコメントアウト
+		m_normalPriority.setEnabled(enabled);
+		m_warningPriority.setEnabled(enabled);
+		m_abnormalPriority.setEnabled(enabled);
+		m_startPriority.setEnabled(enabled);
+		m_notifyId.setButtonEnabled(enabled);
+	}
+
 }
\ No newline at end of file
