@@ -32,7 +32,6 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Table;
 
 import com.clustercontrol.bean.SizeConstant;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.action.GetParameterTableDefine;
 import com.clustercontrol.jobmanagement.bean.JobParamTypeConstant;
@@ -40,6 +39,7 @@ import com.clustercontrol.jobmanagement.bean.SystemParameterConstant;
 import com.clustercontrol.jobmanagement.composite.action.ParameterSelectionChangedListener;
 import com.clustercontrol.jobmanagement.dialog.ParameterDialog;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.jobmanagement.JobParameterInfo;
 
 /**
@@ -50,19 +50,19 @@ import com.clustercontrol.ws.jobmanagement.JobParameterInfo;
  */
 public class ParameterComposite extends Composite {
 	/** テーブルビューア */
-	protected CommonTableViewer m_viewer = null;
+	private CommonTableViewer m_viewer = null;
 	/** 追加ボタン */
-	protected Button m_createCondition = null;
+	private Button m_createCondition = null;
 	/** 変更ボタン */
-	protected Button m_modifyCondition = null;
+	private Button m_modifyCondition = null;
 	/** 削除ボタン */
-	protected Button m_deleteCondition = null;
+	private Button m_deleteCondition = null;
 	/** ジョブ変数情報のリスト */
-	protected List m_paramList = null;
+	private List<JobParameterInfo> m_paramList = null;
 	/** シェル */
-	protected Shell m_shell = null;
+	private Shell m_shell = null;
 	/** 選択アイテム */
-	protected ArrayList m_selectItem = null;
+	private ArrayList m_selectItem = null;
 	/** 初期時フラグ(初期時はデフォルトパラメータを投入する。) */
 	private boolean initFlag;
 
@@ -227,7 +227,7 @@ public class ParameterComposite extends Composite {
 			//パラメータ設定
 			ArrayList<ArrayList> tableData = new ArrayList<ArrayList>();
 			for (int i = 0; i < m_paramList.size(); i++) {
-				JobParameterInfo info = (JobParameterInfo) m_paramList.get(i);
+				JobParameterInfo info = m_paramList.get(i);
 				ArrayList tableLineData = new ArrayList();
 				tableLineData.add(info.getParamId());
 				tableLineData.add(new Integer(info.getType()));
@@ -249,7 +249,7 @@ public class ParameterComposite extends Composite {
 	 * 
 	 * @param paramList ジョブ変数情報のリスト
 	 */
-	public void setParamInfo(List paramList) {
+	public void setParamInfo(List<JobParameterInfo> paramList) {
 		m_paramList = paramList;
 	}
 
@@ -258,7 +258,7 @@ public class ParameterComposite extends Composite {
 	 * 
 	 * @return ジョブ変数情報のリスト
 	 */
-	public List getParamInfo() {
+	public List<JobParameterInfo> getParamInfo() {
 		return m_paramList;
 	}
 
@@ -283,8 +283,8 @@ public class ParameterComposite extends Composite {
 				ArrayList tableLineData = (ArrayList) tableData.get(i);
 				JobParameterInfo info = new JobParameterInfo();
 				Integer type =
-					(Integer) tableLineData.get(GetParameterTableDefine.TYPE);
-				info.setType(type.intValue());
+						(Integer) tableLineData.get(GetParameterTableDefine.TYPE);
+				info.setType(type);
 				if (info.getType() == JobParamTypeConstant.TYPE_SYSTEM) {
 					info.setParamId((String)tableLineData.get(
 							GetParameterTableDefine.PARAM_ID));
@@ -329,4 +329,15 @@ public class ParameterComposite extends Composite {
 	public void setSelectItem(ArrayList selectItem) {
 		m_selectItem = selectItem;
 	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		// super.setEnabled(enabled); // スクロールバーを動かせるように、ここはコメントアウト
+		m_createCondition.setEnabled(enabled);
+		m_modifyCondition.setEnabled(enabled);
+		m_deleteCondition.setEnabled(enabled);
+	}
 }
\ No newline at end of file
