@@ -31,7 +31,6 @@ import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
-import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
@@ -40,13 +39,14 @@ import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.NumberVerifyListener;
-import com.clustercontrol.composite.PositiveNumberVerifyListener;
-import com.clustercontrol.composite.TimeVerifyListener;
+import com.clustercontrol.composite.action.NumberVerifyListener;
+import com.clustercontrol.composite.action.PositiveNumberVerifyListener;
+import com.clustercontrol.composite.action.TimeVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.TimeTo48hConverter;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
@@ -57,37 +57,37 @@ import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
  */
 public class StartDelayComposite extends Composite {
 	/** 開始遅延セッション開始後の時間用チェックボタン */
-	protected Button m_sessionCondition = null;
+	private Button m_sessionCondition = null;
 	/** 開始遅延セッション開始後の時間の値用テキスト*/
-	protected Text m_sessionValue = null;
+	private Text m_sessionValue = null;
 	/** 開始遅延時刻用チェックボタン */
-	protected Button m_timeCondition = null;
+	private Button m_timeCondition = null;
 	/** 開始遅延時刻の値用テキスト */
-	protected Text m_timeValue = null;
+	private Text m_timeValue = null;
 	/** 開始遅延判定対象の条件関係 AND用ラジオボタン */
-	protected Button m_andCondition = null;
+	private Button m_andCondition = null;
 	/** 開始遅延判定対象の条件関係 OR用ラジオボタン */
-	protected Button m_orCondition = null;
+	private Button m_orCondition = null;
 	/**  開始遅延通知用チェックボタン */
-	protected Button m_notifyCondition = null;
+	private Button m_notifyCondition = null;
 	/**  開始遅延通知重要度用コンボボックス */
-	protected Combo m_notifyPriority = null;
+	private Combo m_notifyPriority = null;
 	/** 開始遅延操作用チェックボタン */
-	protected Button m_operationCondition = null;
+	private Button m_operationCondition = null;
 	/** 開始遅延操作用グループ */
-	protected Group m_operationConditionGroup = null;
+	private Group m_operationConditionGroup = null;
 	/** 開始遅延操作種別用コンボボックス */
-	protected Combo m_operationType = null;
+	private Combo m_operationType = null;
+	/** 開始遅延操作終了状態用テキスト */
+	private Combo m_operationStatus = null;
 	/** 開始遅延操作終了値用テキスト */
-	protected Text m_operationValue = null;
+	private Text m_operationValue = null;
 	/** 開始遅延用チェックボタン */
-	protected Button m_startDelayCondition = null;
+	private Button m_startDelayCondition = null;
 	/** 開始遅延用グループ */
-	protected Group m_startDelayConditionGroup = null;
+	private Group m_startDelayConditionGroup = null;
 	/** ジョブ待ち条件情報 */
-	protected JobWaitRuleInfo m_waitRule = null;
-	/** シェル */
-	protected Shell m_shell = null;
+	private JobWaitRuleInfo m_waitRule = null;
 
 	/**
 	 * コンストラクタ
@@ -102,7 +102,6 @@ public class StartDelayComposite extends Composite {
 	public StartDelayComposite(Composite parent, int style) {
 		super(parent, style);
 		initialize();
-		m_shell = this.getShell();
 	}
 
 	/**
@@ -173,7 +172,7 @@ public class StartDelayComposite extends Composite {
 		composite.setLayout(rowLayout);
 		m_sessionCondition = new Button(composite, SWT.CHECK);
 		m_sessionCondition.setText(Messages.getString("time.after.session.start") + " : ");
-		m_sessionCondition.setLayoutData(new RowData(180,
+		m_sessionCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_sessionCondition.addSelectionListener(new SelectionListener() {
 			@Override
@@ -205,7 +204,7 @@ public class StartDelayComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 
 		//時刻
 		composite = new Composite(group, SWT.NONE);
@@ -215,7 +214,7 @@ public class StartDelayComposite extends Composite {
 		composite.setLayout(rowLayout);
 		m_timeCondition = new Button(composite, SWT.CHECK);
 		m_timeCondition.setText(Messages.getString("wait.rule.time.example") + " : ");
-		m_timeCondition.setLayoutData(new RowData(180,
+		m_timeCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_timeCondition.addSelectionListener(new SelectionListener() {
 			@Override
@@ -246,7 +245,7 @@ public class StartDelayComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 		//判定対象の条件関係
 		group = new Group(m_startDelayConditionGroup, SWT.NONE);
 		group.setText(Messages.getString("condition.between.objects"));
@@ -335,13 +334,16 @@ public class StartDelayComposite extends Composite {
 
 					int type = getSelectOperationName(m_operationType);
 					if (type == OperationConstant.TYPE_STOP_SKIP) {
+						m_operationStatus.setEnabled(true);
 						m_operationValue.setEnabled(true);
 					} else if(type == OperationConstant.TYPE_STOP_WAIT){
+						m_operationStatus.setEnabled(false);
 						m_operationValue.setEnabled(false);
 					}
 					m_operationConditionGroup.setEnabled(true);
 				} else {
 					m_operationType.setEnabled(false);
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 					m_operationConditionGroup.setEnabled(false);
 				}
@@ -384,8 +386,10 @@ public class StartDelayComposite extends Composite {
 
 				int type = getSelectOperationName(check);
 				if (type == OperationConstant.TYPE_STOP_SKIP) {
+					m_operationStatus.setEnabled(true);
 					m_operationValue.setEnabled(true);
 				} else if(type == OperationConstant.TYPE_STOP_WAIT){
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 				}
 				update();
@@ -397,6 +401,23 @@ public class StartDelayComposite extends Composite {
 			}
 		});
 
+		//操作の終了状態
+		composite = new Composite(m_operationConditionGroup, SWT.NONE);
+		rowLayout = new RowLayout();
+		rowLayout.type = SWT.HORIZONTAL;
+		rowLayout.spacing = 10;
+		composite.setLayout(rowLayout);
+		label = new Label(composite, SWT.NONE);
+		label.setText(Messages.getString("end.status") + " : ");
+		label.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_LABEL_HEIGHT));
+		m_operationStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_operationStatus.setLayoutData(new RowData(100,
+				SizeConstant.SIZE_COMBO_HEIGHT));
+		m_operationStatus.add(EndStatusConstant.STRING_NORMAL);
+		m_operationStatus.add(EndStatusConstant.STRING_WARNING);
+		m_operationStatus.add(EndStatusConstant.STRING_ABNORMAL);
+
 		//操作の終了値
 		composite = new Composite(m_operationConditionGroup, SWT.NONE);
 		rowLayout = new RowLayout();
@@ -419,7 +440,7 @@ public class StartDelayComposite extends Composite {
 						update();
 					}
 				}
-		);
+				);
 		label = new Label(composite, SWT.NONE);
 		label.setLayoutData(new RowData(70, SizeConstant.SIZE_LABEL_HEIGHT));
 	}
@@ -453,21 +474,7 @@ public class StartDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
-	@SuppressWarnings("unchecked")
 	public void reflectWaitRuleInfo() {
-
-		// 初期値
-		m_startDelayCondition.setSelection(false);
-		m_sessionCondition.setSelection(false);
-		m_sessionValue.setText(String.valueOf(1));
-		m_timeCondition.setSelection(false);
-		m_andCondition.setSelection(true);
-		m_notifyCondition.setSelection(false);
-		m_notifyPriority.select(0);
-		m_operationCondition.setSelection(false);
-		m_operationType.select(0);
-		m_operationValue.setText(String.valueOf(0));
-
 		if (m_waitRule != null) {
 			//開始遅延
 			m_startDelayCondition.setSelection(YesNoConstant.typeToBoolean(m_waitRule
@@ -484,8 +491,7 @@ public class StartDelayComposite extends Composite {
 
 			//時刻の値
 			if (m_waitRule.getStartDelayTimeValue() != null) {
-				SimpleDateFormat formatter = new SimpleDateFormat("HH:mm:ss");
-				m_timeValue.setText(formatter.format(new Date(m_waitRule.getStartDelayTimeValue())));
+				m_timeValue.setText(TimeTo48hConverter.dateTo48hms(new Date(m_waitRule.getStartDelayTimeValue())));
 			}
 			else{
 				m_timeValue.setText("");
@@ -514,6 +520,10 @@ public class StartDelayComposite extends Composite {
 			setSelectOperationName(m_operationType,
 					m_waitRule.getStartDelayOperationType());
 
+			//操作の終了状態
+			setSelectOperationEndStatus(m_operationStatus,
+					m_waitRule.getStartDelayOperationEndStatus());
+
 			//操作の終了値
 			m_operationValue.setText(String.valueOf(m_waitRule.getStartDelayOperationEndValue()));
 		}
@@ -545,47 +555,9 @@ public class StartDelayComposite extends Composite {
 	 * 
 	 * @return 入力値の検証結果
 	 */
-	@SuppressWarnings("unchecked")
 	public ValidateResult createWaitRuleInfo() {
 		ValidateResult result = null;
 
-		//実行内容情報クラスのインスタンスを作成・取得
-		if (m_waitRule == null) {
-			m_waitRule = new JobWaitRuleInfo();
-			m_waitRule.setSuspend(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkip(YesNoConstant.TYPE_NO);
-			m_waitRule.setSkipEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCondition(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndCondition(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setCalendar(YesNoConstant.TYPE_NO);
-			m_waitRule.setCalendarEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setStartDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelaySessionValue(1);
-			m_waitRule.setStartDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setStartDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setStartDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setEndDelay(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySession(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelaySessionValue(1);
-			m_waitRule.setEndDelayJob(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayJobValue(1);
-			m_waitRule.setEndDelayTime(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
-			m_waitRule.setEndDelayNotify(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperation(YesNoConstant.TYPE_NO);
-			m_waitRule.setEndDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-			m_waitRule.setSkipEndStatus(0);
-			m_waitRule.setEndStatus(0);
-			m_waitRule.setStartDelayNotifyPriority(0);
-			m_waitRule.setStartDelayOperationType(0);
-			m_waitRule.setEndDelayNotifyPriority(0);
-			m_waitRule.setEndDelayOperationType(0);
-		}
-
 		//開始遅延
 		m_waitRule.setStartDelay(YesNoConstant.booleanToType(m_startDelayCondition
 				.getSelection()));
@@ -621,7 +593,7 @@ public class StartDelayComposite extends Composite {
 			Date date = null;
 			try {
 				from = formatter.parse("00:00:00");
-				to = formatter.parse("23:59:59");
+				to = formatter.parse("48:00:00");
 				date = formatter.parse(m_timeValue.getText());
 				check = true;
 			} catch (ParseException e) {
@@ -636,7 +608,7 @@ public class StartDelayComposite extends Composite {
 			if(check){
 				//範囲チェック
 				if(date.before(from) || date.after(to)){
-					String[] args = { formatter.format(from), formatter.format(to) };
+					String[] args = { formatter.format(from), TimeTo48hConverter.dateTo48hms(to) };
 					result = new ValidateResult();
 					result.setValid(false);
 					result.setID(Messages.getString("message.hinemos.1"));
@@ -679,10 +651,8 @@ public class StartDelayComposite extends Composite {
 		//操作の終了値
 		try {
 			// 開始遅延が有効であり、操作がスキップの場合のみ、入力されている終了値を確認する
-			if (m_waitRule.getStartDelayOperation() == YesNoConstant.TYPE_YES
-					&& m_waitRule.getStartDelayOperationType() == OperationConstant.TYPE_STOP_SKIP) {
-				m_waitRule.setStartDelayOperationEndValue(Integer.parseInt(m_operationValue.getText()));
-			}
+			m_waitRule.setStartDelayOperationEndStatus(getSelectOperationEndStatus(m_operationStatus));
+			m_waitRule.setStartDelayOperationEndValue(Integer.parseInt(m_operationValue.getText()));
 		} catch (NumberFormatException e) {
 			result = new ValidateResult();
 			result.setValid(false);
@@ -699,7 +669,7 @@ public class StartDelayComposite extends Composite {
 	 * 
 	 * @param enabled true：開始遅延を使用する、false：開始遅延を使用しない
 	 */
-	public void setStartDelayEnabled(boolean enabled) {
+	private void setStartDelayEnabled(boolean enabled) {
 		if (enabled) {
 			m_startDelayConditionGroup.setEnabled(true);
 
@@ -733,17 +703,21 @@ public class StartDelayComposite extends Composite {
 			m_operationCondition.setEnabled(true);
 			if(m_operationCondition.getSelection()){
 				m_operationType.setEnabled(true);
+				m_operationStatus.setEnabled(false);
 				m_operationValue.setEnabled(false);
 
 				int type = getSelectOperationName(m_operationType);
 				if (type == OperationConstant.TYPE_STOP_SKIP) {
+					m_operationStatus.setEnabled(true);
 					m_operationValue.setEnabled(true);
 				} else if(type == OperationConstant.TYPE_STOP_WAIT){
+					m_operationStatus.setEnabled(false);
 					m_operationValue.setEnabled(false);
 				}
 			}
 			else{
 				m_operationType.setEnabled(false);
+				m_operationStatus.setEnabled(false);
 				m_operationValue.setEnabled(false);
 			}
 		} else {
@@ -768,6 +742,7 @@ public class StartDelayComposite extends Composite {
 			//操作
 			m_operationCondition.setEnabled(false);
 			m_operationType.setEnabled(false);
+			m_operationStatus.setEnabled(false);
 			m_operationValue.setEnabled(false);
 			m_operationConditionGroup.setEnabled(false);
 		}
@@ -781,7 +756,7 @@ public class StartDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
-	public void setSelectPriority(Combo combo, int priority) {
+	private void setSelectPriority(Combo combo, int priority) {
 		String select = "";
 
 		if (priority == PriorityConstant.TYPE_CRITICAL) {
@@ -813,7 +788,7 @@ public class StartDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
-	public int getSelectPriority(Combo combo) {
+	private int getSelectPriority(Combo combo) {
 		String select = combo.getText();
 
 		if (select.equals(PriorityConstant.STRING_CRITICAL)) {
@@ -832,14 +807,14 @@ public class StartDelayComposite extends Composite {
 	}
 
 	/**
-	 * 指定したジョブ操作種別に該当する開始遅延操作用コンボボックスの項目を選択しまう。
+	 * 指定したジョブ操作種別に該当する開始遅延操作用コンボボックスの項目を選択します。
 	 * 
 	 * @param combo コンボボックスのインスタンス
 	 * @param operation ジョブ操作種別
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
-	public void setSelectOperationName(Combo combo, int operation) {
+	private void setSelectOperationName(Combo combo, int operation) {
 		String select = "";
 
 		if (operation == OperationConstant.TYPE_STOP_SKIP) {
@@ -865,7 +840,7 @@ public class StartDelayComposite extends Composite {
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.OperationConstant
 	 */
-	public int getSelectOperationName(Combo combo) {
+	private int getSelectOperationName(Combo combo) {
 		String select = combo.getText();
 
 		if (select.equals(OperationConstant.STRING_STOP_SKIP)) {
@@ -876,4 +851,52 @@ public class StartDelayComposite extends Composite {
 
 		return -1;
 	}
+
+	/**
+	 * 指定した重要度に該当する開始遅延終了状態用コンボボックスの項目を選択します。
+	 * 
+	 */
+	private void setSelectOperationEndStatus(Combo combo, int status) {
+		String select = "";
+
+		select = EndStatusConstant.typeToString(status);
+
+		combo.select(0);
+		for (int i = 0; i < combo.getItemCount(); i++) {
+			if (select.equals(combo.getItem(i))) {
+				combo.select(i);
+				break;
+			}
+		}
+	}
+
+	/**
+	 * 開始遅延通知終了状態用コンボボックスにて選択している項目を取得します。
+	 * 
+	 */
+	private int getSelectOperationEndStatus(Combo combo) {
+		String select = combo.getText();
+		return EndStatusConstant.stringToType(select);
+	}
+	
+	/**
+	 * 読み込み専用時にグレーアウトします。
+	 */
+	@Override
+	public void setEnabled(boolean enabled) {
+		super.setEnabled(enabled);
+		m_sessionCondition.setEnabled(enabled);
+		m_sessionValue.setEnabled(enabled);
+		m_timeCondition.setEnabled(enabled);
+		m_timeValue.setEnabled(enabled);
+		m_andCondition.setEnabled(enabled);
+		m_orCondition.setEnabled(enabled);
+		m_notifyCondition.setEnabled(enabled);
+		m_notifyPriority.setEnabled(enabled);
+		m_operationCondition.setEnabled(enabled);
+		m_operationType.setEnabled(enabled);
+		m_operationStatus.setEnabled(enabled);
+		m_operationValue.setEnabled(enabled);
+		m_startDelayCondition.setEnabled(enabled);
+	}
 }
\ No newline at end of file
