@@ -30,8 +30,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
-import com.clustercontrol.composite.PropertySheet;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.action.GetParameterTableDefine;
@@ -39,6 +38,7 @@ import com.clustercontrol.jobmanagement.action.ParameterProperty;
 import com.clustercontrol.jobmanagement.bean.JobParamTypeConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * ジョブ変数ダイアログクラスです。
@@ -48,7 +48,7 @@ import com.clustercontrol.util.PropertyUtil;
  */
 public class ParameterDialog extends CommonDialog {
 	/** プロパティシート */
-	protected PropertySheet m_viewer = null;
+	private PropertySheet m_viewer = null;
 	/** シェル */
 	private Shell m_shell = null;
 	/** ジョブ変数情報 */
@@ -106,6 +106,7 @@ public class ParameterDialog extends CommonDialog {
 		m_viewer.setInput(
 				new ParameterProperty().getProperty(
 						JobParamTypeConstant.TYPE_SYSTEM));
+		m_viewer.expandAll();
 
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
 		gridData = new GridData();
@@ -138,32 +139,31 @@ public class ParameterDialog extends CommonDialog {
 	private void reflectParameter() {
 		Property property = null;
 
-		if (m_parameter instanceof ArrayList) {
+		if (m_parameter != null) {
 			//パラメータを設定
 			Integer type = (Integer) m_parameter.get(
 					GetParameterTableDefine.TYPE);
 
-			if (type.intValue() == JobParamTypeConstant.TYPE_SYSTEM) {
+			if (type == JobParamTypeConstant.TYPE_SYSTEM) {
 				//種別がシステムの場合
 				property = new ParameterProperty().getProperty(JobParamTypeConstant.TYPE_SYSTEM);
-				ArrayList propertyList = PropertyUtil.getProperty(property,
-						ParameterProperty.ID_TYPE);
+				ArrayList<Property> propertyList = PropertyUtil.getProperty(property, ParameterProperty.ID_TYPE);
 				Property paramType = (Property) propertyList.get(0);
 				Object values[][] = paramType.getSelectValues();
 				paramType.setValue(JobParamTypeConstant.STRING_SYSTEM);
 
-				HashMap map = (HashMap) values[PropertyConstant.SELECT_VALUE][JobParamTypeConstant.TYPE_SYSTEM];
-				ArrayList list = (ArrayList) map.get("property");
+				HashMap map = (HashMap) values[PropertyDefineConstant.SELECT_VALUE][JobParamTypeConstant.TYPE_SYSTEM];
+				ArrayList<Property> list = (ArrayList<Property>) map.get("property");
 
 				//パラメータIDを設定
 				String paramId = (String) m_parameter.get(GetParameterTableDefine.PARAM_ID);
-				((Property) list.get(0)).setValue(paramId);
+				list.get(0).setValue(paramId);
 
 				//説明
 				String description = (String) m_parameter.get(GetParameterTableDefine.DESCRIPTION);
-				((Property) list.get(1)).setValue(description);
+				list.get(1).setValue(description);
 			}
-			else if (type.intValue() == JobParamTypeConstant.TYPE_USER) {
+			else if (type == JobParamTypeConstant.TYPE_USER) {
 				//種別がユーザの場合
 				property = new ParameterProperty().getProperty(JobParamTypeConstant.TYPE_USER);
 				ArrayList propertyList = PropertyUtil.getProperty(property,
@@ -172,7 +172,7 @@ public class ParameterDialog extends CommonDialog {
 				Object values[][] = paramType.getSelectValues();
 				paramType.setValue(JobParamTypeConstant.STRING_USER);
 
-				HashMap map = (HashMap) values[PropertyConstant.SELECT_VALUE][JobParamTypeConstant.TYPE_USER];
+				HashMap map = (HashMap) values[PropertyDefineConstant.SELECT_VALUE][JobParamTypeConstant.TYPE_USER];
 				ArrayList list = (ArrayList) map.get("property");
 
 				//パラメータIDを設定
