@@ -30,8 +30,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
-import com.clustercontrol.composite.PropertySheet;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.action.GetWaitRuleTableDefine;
@@ -39,6 +38,7 @@ import com.clustercontrol.jobmanagement.action.WaitRuleProperty;
 import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 
 /**
@@ -49,7 +49,7 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
  */
 public class WaitRuleDialog extends CommonDialog {
 	/** プロパティシート */
-	protected PropertySheet m_viewer = null;
+	private PropertySheet m_viewer = null;
 
 	/** ダイアログのサイズの初期値 */
 	//    private final int sizeX = 500;
@@ -87,8 +87,17 @@ public class WaitRuleDialog extends CommonDialog {
 	protected void customizeDialog(Composite parent) {
 		m_shell = this.getShell();
 
-		parent.getShell().setText(Messages.getString("wait.rule") + " : " +
-				m_jobTreeItem.getData().getName() + "(" + m_jobTreeItem.getData().getId() + ")");
+		// ダイアログタイトル
+		String displayJobId =  m_jobTreeItem.getData().getId();
+		String displayJobName =  m_jobTreeItem.getData().getName();
+		if(displayJobId != null && !"".equals(displayJobId)
+				&& displayJobName != null && !"".equals(displayJobName)){
+			parent.getShell().setText(Messages.getString("wait.rule") + " : " +
+					displayJobName + "(" + displayJobId + ")");
+		}else{
+			// ダイアログを一度も閉じていない状態ではJonInfoは生成されていないため
+			parent.getShell().setText(Messages.getString("wait.rule"));
+		}
 
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 10;
@@ -116,6 +125,7 @@ public class WaitRuleDialog extends CommonDialog {
 		m_viewer = new PropertySheet(table);
 
 		m_viewer.setInput(new WaitRuleProperty().getProperty(m_jobTreeItem, JudgmentObjectConstant.TYPE_JOB_END_STATUS));
+		m_viewer.expandAll();
 
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
 		gridData = new GridData();
@@ -154,68 +164,64 @@ public class WaitRuleDialog extends CommonDialog {
 		if (m_startCondition instanceof ArrayList) {
 			//判定対象を設定
 			Integer type = (Integer) m_startCondition
-			.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
+					.get(GetWaitRuleTableDefine.JUDGMENT_OBJECT);
 
-			if (type.intValue() == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
+			if (type == JudgmentObjectConstant.TYPE_JOB_END_STATUS) {
 				//判定対象がジョブの場合
 				property = new WaitRuleProperty().getProperty(m_jobTreeItem, JudgmentObjectConstant.TYPE_JOB_END_STATUS);
-				ArrayList propertyList = PropertyUtil.getProperty(property,
+				ArrayList<Property> propertyList = PropertyUtil.getProperty(property,
 						WaitRuleProperty.ID_JUDGMENT_OBJECT);
 				Property judgmentObject = (Property) propertyList.get(0);
 				Object values[][] = judgmentObject.getSelectValues();
 				judgmentObject.setValue(JudgmentObjectConstant.STRING_JOB_END_STATUS);
 
-				HashMap map = (HashMap) values[PropertyConstant.SELECT_VALUE][JudgmentObjectConstant.TYPE_JOB_END_STATUS];
-				ArrayList list = (ArrayList) map.get("property");
+				HashMap map = (HashMap) values[PropertyDefineConstant.SELECT_VALUE][JudgmentObjectConstant.TYPE_JOB_END_STATUS];
+				ArrayList<Property> list = (ArrayList<Property>) map.get("property");
 
 				//ジョブIDを設定
-				String jobId = (String) m_startCondition
-				.get(GetWaitRuleTableDefine.JOB_ID);
-				((Property) list.get(0)).setValue(jobId);
+				String jobId = (String) m_startCondition.get(GetWaitRuleTableDefine.JOB_ID);
+				list.get(0).setValue(jobId);
 
 				//条件値
-				String value = (String) m_startCondition
-				.get(GetWaitRuleTableDefine.START_VALUE);
-				((Property) list.get(1)).setValue(value);
+				String value = (String) m_startCondition.get(GetWaitRuleTableDefine.START_VALUE);
+				list.get(1).setValue(value);
 			}
-			else if (type.intValue() == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
+			else if (type == JudgmentObjectConstant.TYPE_JOB_END_VALUE) {
 				//判定対象がジョブの場合
 				property = new WaitRuleProperty().getProperty(m_jobTreeItem, JudgmentObjectConstant.TYPE_JOB_END_VALUE);
-				ArrayList propertyList = PropertyUtil.getProperty(property,
-						WaitRuleProperty.ID_JUDGMENT_OBJECT);
+				ArrayList<Property> propertyList = PropertyUtil.getProperty(property, WaitRuleProperty.ID_JUDGMENT_OBJECT);
 				Property judgmentObject = (Property) propertyList.get(0);
 				Object values[][] = judgmentObject.getSelectValues();
 				judgmentObject.setValue(JudgmentObjectConstant.STRING_JOB_END_VALUE);
 
-				HashMap map = (HashMap) values[PropertyConstant.SELECT_VALUE][JudgmentObjectConstant.TYPE_JOB_END_VALUE];
-				ArrayList list = (ArrayList) map.get("property");
+				HashMap map = (HashMap) values[PropertyDefineConstant.SELECT_VALUE][JudgmentObjectConstant.TYPE_JOB_END_VALUE];
+				ArrayList<Property> list = (ArrayList<Property>) map.get("property");
 
 				//ジョブIDを設定
 				String jobId = (String) m_startCondition
-				.get(GetWaitRuleTableDefine.JOB_ID);
+						.get(GetWaitRuleTableDefine.JOB_ID);
 				((Property) list.get(0)).setValue(jobId);
 
 				//条件値
 				Integer value = (Integer) m_startCondition
-				.get(GetWaitRuleTableDefine.START_VALUE);
+						.get(GetWaitRuleTableDefine.START_VALUE);
 				((Property) list.get(1)).setValue(value);
 			}
 			else {
 				//判定対象が時刻の場合
 				property = new WaitRuleProperty().getProperty(m_jobTreeItem, JudgmentObjectConstant.TYPE_TIME);
-				ArrayList propertyList = PropertyUtil.getProperty(property,
-						WaitRuleProperty.ID_JUDGMENT_OBJECT);
+				ArrayList<Property> propertyList = PropertyUtil.getProperty(property, WaitRuleProperty.ID_JUDGMENT_OBJECT);
 				Property judgmentObject = (Property) propertyList.get(0);
 				Object values[][] = judgmentObject.getSelectValues();
 				judgmentObject.setValue(JudgmentObjectConstant.STRING_TIME);
 
-				HashMap map = (HashMap) values[PropertyConstant.SELECT_VALUE][JudgmentObjectConstant.TYPE_TIME];
-				ArrayList list = (ArrayList) map.get("property");
+				HashMap map = (HashMap) values[PropertyDefineConstant.SELECT_VALUE][JudgmentObjectConstant.TYPE_TIME];
+				ArrayList<Property> list = (ArrayList<Property>) map.get("property");
 
 				//開始時刻
 				Date time = (Date) m_startCondition
-				.get(GetWaitRuleTableDefine.START_VALUE);
-				((Property) list.get(0)).setValue(time);
+						.get(GetWaitRuleTableDefine.START_VALUE);
+				list.get(0).setValue(time);
 			}
 			m_viewer.setInput(property);
 
@@ -302,15 +308,15 @@ public class WaitRuleDialog extends CommonDialog {
 			//条件値
 			values = PropertyUtil.getPropertyValue(property,
 					WaitRuleProperty.ID_CONDITION_END_VALUE);
-			Integer value = (Integer) values.get(0);
-			if (value == null ) {
+			Object value = values.get(0);
+			if (value == null || !(value instanceof Integer)) {
 				result = new ValidateResult();
 				result.setValid(false);
 				result.setID(Messages.getString("message.hinemos.1"));
 				result.setMessage(Messages.getString("message.job.17"));
 				return result;
 			}
-			m_startCondition.add(value);
+			m_startCondition.add((Integer) value);
 		}
 		else {
 			//ジョブID
