@@ -16,6 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.jobmanagement.factory;
 
 import java.util.ArrayList;
+import java.util.List;
 
 import javax.persistence.EntityExistsException;
 
@@ -24,6 +25,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.PriorityConstant;
@@ -46,6 +48,10 @@ import com.clustercontrol.jobmanagement.model.JobSessionEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionJobEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionNodeEntity;
 import com.clustercontrol.jobmanagement.model.JobStartJobInfoEntity;
+import com.clustercontrol.jobmanagement.util.QueryUtil;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
+import com.clustercontrol.notify.session.NotifyControllerBean;
+import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 
@@ -62,15 +68,24 @@ public class CreateHulftJob {
 	/** 配信管理情報の登録(utliupdtコマンド) */
 	public static final String UTILIUPDT_S = "_UTLIUPDT_S";
 	public static final String UTILIUPDT_S_SH = "utliupdt-s.sh";
+	public static final String UTILIUPDT_S_VBS = "utliupdt-s.vbs";
 	/** 集信管理情報の登録(utliupdtコマンド) */
 	public static final String UTILIUPDT_R = "_UTLIUPDT_R";
 	public static final String UTILIUPDT_R_SH = "utliupdt-r.sh";
+	public static final String UTILIUPDT_R_VBS = "utliupdt-r.vbs";
+	/** ホスト管理情報の登録(utliupdtコマンド) */
+	public static final String UTILIUPDT_H_SND = "_UTLIUPDT_H_SND";
+	public static final String UTILIUPDT_H_RCV = "_UTLIUPDT_H_RCV";
+	public static final String UTILIUPDT_H_SH = "utliupdt-h.sh";
+	public static final String UTILIUPDT_H_VBS = "utliupdt-h.vbs";
 	/** 配信要求(utlsendコマンド) */
 	public static final String UTLSEND = "_UTLSEND";
-	public static final String UTLSEND_SH = "utlsend.sh";
+	public static final String UTLSEND_SH = "utlsendfile.sh";
+	public static final String UTLSEND_VBS = "utlsendfile.vbs";
 	/** 履歴チェック(huloplcmdファイルのチェックとメッセージファイルへの照会) */
 	public static final String HULOPLCMD = "_HULOPLCMD";
 	public static final String HULOPLCMD_SH = "huloplcmd.sh";
+	public static final String HULOPLCMD_VBS = "huloplcmd.vbs";
 
 	/** 正常の終了値及び終了値の範囲 */
 	private static final int NORMAL = 0;
@@ -79,22 +94,34 @@ public class CreateHulftJob {
 	/** 異常の終了値及び終了値の範囲 */
 	private static final int ABNORMAL = -1;
 	
-	public static boolean hulftMode = false;
+	private static boolean hulftMode = false;
 	/** HULFT用のスクリプト配置ディレクトリ */
-	private static String SCRIPT_DIR = "../../hulft/sh/";
+	private static String SCRIPT_DIR_LINUX = "../../hulft/sh/";
+	/** HULFT用のスクリプト配置ディレクトリ */
+	private static String SCRIPT_DIR_WIN = "C:\\Program Files (x86)\\Hinemos\\Agent4.1.0\\hulft\\vbs\\";
 	
-	{
+	static {
 		String hulftModeStr = HinemosProperties.getProperty("job.hulft.mode");
 		if (hulftModeStr != null && "true".equals(hulftModeStr)) {
 			hulftMode = true;
 		}
 		m_log.info("hulftMode=" + hulftMode);
 
-		String dir = HinemosProperties.getProperty("job.hulft.script.dir", SCRIPT_DIR);
+		String dir = HinemosProperties.getProperty("job.hulft.script.dir.linux", SCRIPT_DIR_LINUX);
 		if (dir != null && dir.length() >0) {
-			SCRIPT_DIR = dir;
+			SCRIPT_DIR_LINUX = dir + "/";
 		}
-		m_log.info("job.hulft.script.dir=" + SCRIPT_DIR);
+		m_log.info("job.hulft.script.dir.linux=" + SCRIPT_DIR_LINUX);
+		
+		dir = HinemosProperties.getProperty("job.hulft.script.dir.windows", SCRIPT_DIR_WIN);
+		if (dir != null && dir.length() >0) {
+			SCRIPT_DIR_WIN = dir + "\\";
+		}
+		m_log.info("job.hulft.script.dir.windows=" + SCRIPT_DIR_WIN);
+	}
+	
+	public static boolean isHulftMode() {
+		return hulftMode;
 	}
 	
 	protected void createHulftDetailJob(JobInfoEntity parentJobInfo)throws FacilityNotFound, EntityExistsException, HinemosUnknown, JobInfoNotFound {
@@ -132,7 +159,14 @@ public class CreateHulftJob {
 		jobUtiliupdtS.setRegUser(parentJobInfo.getRegUser());
 		jobUtiliupdtS.setUpdateUser(parentJobInfo.getUpdateUser());
 		jobUtiliupdtS.setConditionType(ConditionTypeConstant.TYPE_AND);
-		String command = SCRIPT_DIR + UTILIUPDT_S_SH + " " + parentJobInfo.getId().getJobId();
+		String command;
+		if (repository.getNode(parentJobInfo.getSrcFacilityId()).getPlatformFamily().equals("WINDOWS")) {
+			// Windowsの場合の起動コマンド
+			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_S_VBS + "\" " + parentJobInfo.getId().getJobId();
+		} else {
+			// Linuxの場合の起動コマンド
+			command = SCRIPT_DIR_LINUX + UTILIUPDT_S_SH + " " + parentJobInfo.getId().getJobId();
+		}
 		m_log.info("startCommand=" + command);
 		jobUtiliupdtS.setStartCommand(command);
 		jobUtiliupdtS.setSpecifyUser(parentJobInfo.getSpecifyUser());
@@ -140,7 +174,7 @@ public class CreateHulftJob {
 		jobUtiliupdtS.setArgument(parentJobInfo.getSrcFile());
 		jobUtiliupdtS.setMessageRetry(parentJobInfo.getMessageRetry());
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobUtiliupdtS);
+		subCreateJobNoticeInfoEntity(jobUtiliupdtS, job.getId().getJobId());
 
 		//ジョブユニットのジョブIDは親のものと同じとする。
 		String jobunitId = parentSessionJob.getId().getJobunitId();
@@ -181,8 +215,6 @@ public class CreateHulftJob {
 			nodeJobInfoEntity.setMultiplicityNotify(job.getMultiplicityNotify());
 			nodeJobInfoEntity.setMultiplicityNotifyPriority(job.getMultiplicityNotifyPriority());
 			nodeJobInfoEntity.setMultiplicityOperation(job.getMultiplicityOperation());
-			// 通知の設定
-			nodeJobInfoEntity.setJobNoticeInfoEntities(job.getJobNoticeInfoEntities());
 			
 			//処理方法により待ち条件を作成する
 			if(fileData.getProcess_mode() == ProcessingMethodConstant.TYPE_ALL_NODE){
@@ -280,7 +312,7 @@ public class CreateHulftJob {
 			nodeJobSessionJob.setScopeText(repository.getFacilityPath(nodeIdList.get(i), null));
 
 			//通知メッセージを作成
-			subCreateJobNoticeInfoEntity(nodeJobInfoEntity);
+			subCreateJobNoticeInfoEntity(nodeJobInfoEntity, job.getId().getJobId());
 
 			//終了状態を作成
 			// インスタンス生成
@@ -327,6 +359,12 @@ public class CreateHulftJob {
 		//集信管理情報の登録(UTILIUPDT_R)
 		String waitJobId = utiliupdtR(nodeJobSessionJob, destFacilityId, fileInfo, parentJobId);
 
+		//配信側にホスト管理情報の登録(UTILIUPDT_H)
+		waitJobId = utliupdtH_snd(nodeJobSessionJob, waitJobId, destFacilityId, fileInfo);
+		
+		//配信側にホスト管理情報の登録(UTILIUPDT_H)
+		waitJobId = utliupdtH_rcv(nodeJobSessionJob, waitJobId, destFacilityId, fileInfo);
+		
 		//ファイル転送(UTLSEND)
 		waitJobId = utlsend(nodeJobSessionJob, waitJobId, destFacilityId,
 						filePath, String.valueOf(1), fileInfo, parentJobId);
@@ -356,6 +394,9 @@ public class CreateHulftJob {
 
 		//待ち条件を設定
 		jobInfoEntity.setConditionType(ConditionTypeConstant.TYPE_OR);
+		jobInfoEntity.setUnmatchEndFlg(YesNoConstant.TYPE_YES);
+		jobInfoEntity.setUnmatchEndValue(ABNORMAL);
+		jobInfoEntity.setUnmatchEndStatus(EndStatusConstant.TYPE_ABNORMAL);
 
 		//判定対象を作成
 		if(fileInfo.getCheck_flg() == YesNoConstant.TYPE_YES){
@@ -367,7 +408,7 @@ public class CreateHulftJob {
 					jobInfoEntity,
 					jobInfoEntity.getId().getJobunitId(),
 					waitJobId,
-					EndStatusConstant.TYPE_NORMAL,
+					JudgmentObjectConstant.TYPE_JOB_END_STATUS,
 					EndStatusConstant.TYPE_NORMAL);
 			// 重複チェック
 			jtm.checkEntityExists(JobStartJobInfoEntity.class, jobStartJobInfoEntity.getId());
@@ -386,10 +427,17 @@ public class CreateHulftJob {
 			jtm.checkEntityExists(JobStartJobInfoEntity.class, jobStartJobInfoEntity.getId());
 		}
 
-		NodeInfo info = repository.getNode(fileInfo.getSrc_facility_id());
+		NodeInfo info = repository.getNode(destFacilityId);
 
 		//実行コマンドを設定
-		String command = SCRIPT_DIR + UTLSEND_SH + " " + parentJobId + " " + filePath+ " " + info.getNodeName();
+		String command;
+		if (repository.getNode(fileInfo.getSrc_facility_id()).getPlatformFamily().equals("WINDOWS")) {
+			// Windowsの場合の起動コマンド
+			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTLSEND_VBS + "\" " + parentJobId + " \"" + filePath+ "\" " + info.getNodeName();
+		} else {
+			// Linuxの場合の起動コマンド
+			command = SCRIPT_DIR_LINUX + UTLSEND_SH + " " + parentJobId + " " + filePath+ " " + info.getNodeName();
+		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
 		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
@@ -398,7 +446,7 @@ public class CreateHulftJob {
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity);
+		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
@@ -409,15 +457,28 @@ public class CreateHulftJob {
 			JobFileInfoData fileInfo,
 			String parentJobId) throws EntityExistsException, FacilityNotFound, HinemosUnknown {
 
+		//リポジトリ(RepositoryControllerBean)を取得
+		RepositoryControllerBean repository = new RepositoryControllerBean();
+		
 		// インスタンス生成
 		JobInfoEntity jobInfoEntity = subCreateJobInfoEntityForJob (nodeJobSessionJob,
 				UTILIUPDT_R, destFacilityId);
 
 		//待ち条件を設定
 		jobInfoEntity.setConditionType(ConditionTypeConstant.TYPE_AND);
+		jobInfoEntity.setUnmatchEndFlg(YesNoConstant.TYPE_YES);
+		jobInfoEntity.setUnmatchEndValue(ABNORMAL);
+		jobInfoEntity.setUnmatchEndStatus(EndStatusConstant.TYPE_ABNORMAL);
 
 		//実行コマンドを設定
-		String command = SCRIPT_DIR + UTILIUPDT_R_SH + " " + parentJobId + " " + fileInfo.getDest_directory();
+		String command;
+		if (repository.getNode(destFacilityId).getPlatformFamily().equals("WINDOWS")) {
+			// Windowsの場合の起動コマンド
+			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_R_VBS + "\" " + parentJobId + " \"" + fileInfo.getDest_directory() + "\"";
+		} else {
+			// Linuxの場合の起動コマンド
+			command = SCRIPT_DIR_LINUX + UTILIUPDT_R_SH + " " + parentJobId + " " + fileInfo.getDest_directory();
+		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
 		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
@@ -425,7 +486,169 @@ public class CreateHulftJob {
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity);
+		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
+
+		return jobInfoEntity.getId().getJobId();
+	}
+	
+	private String utliupdtH_snd(
+			JobSessionJobEntity nodeJobSessionJob,
+			String waitJobId,
+			String destFacilityId,
+			JobFileInfoData fileInfo
+			) throws FacilityNotFound, HinemosUnknown {
+		
+		// 配信側に集信側のホスト管理情報を登録する
+		
+		JpaTransactionManager jtm = new JpaTransactionManager();
+
+		// インスタンス生成
+		JobInfoEntity jobInfoEntity = subCreateJobInfoEntityForJob (nodeJobSessionJob,
+				UTILIUPDT_H_SND, fileInfo.getSrc_facility_id());
+
+		//待ち条件を設定
+		jobInfoEntity.setConditionType(ConditionTypeConstant.TYPE_OR);
+		jobInfoEntity.setUnmatchEndFlg(YesNoConstant.TYPE_YES);
+		jobInfoEntity.setUnmatchEndValue(ABNORMAL);
+		jobInfoEntity.setUnmatchEndStatus(EndStatusConstant.TYPE_ABNORMAL);
+
+		if(waitJobId != null && waitJobId.length() > 0){
+			//JobStartJobInfoEntityを作成
+			// インスタンス生成
+			JobStartJobInfoEntity jobStartJobInfoEntity = new JobStartJobInfoEntity(
+					jobInfoEntity,
+					jobInfoEntity.getId().getJobunitId(),
+					waitJobId,
+					JudgmentObjectConstant.TYPE_JOB_END_STATUS,
+					EndStatusConstant.TYPE_NORMAL);
+			// 重複チェック
+			jtm.checkEntityExists(JobStartJobInfoEntity.class, jobStartJobInfoEntity.getId());
+		}
+
+		//リポジトリ(RepositoryControllerBean)を取得
+		RepositoryControllerBean repository = new RepositoryControllerBean();
+		NodeInfo info = repository.getNode(destFacilityId);
+		
+		// ホスト種を指定 (H:汎用機　U:UNIX  N:WindowsNT  W:Windows A:AS/400  K:富士通K)
+		String hosttype;
+		if (info.getPlatformFamily().equals("WINDOWS")) {
+			hosttype = "N";
+		} else {
+			hosttype = "U";
+		}
+		
+		// 漢字コード種 (S:SHIFT-JIS  E:EUC  8:UTF-8  J:JEF  I:IBM  K:KEIS  N:NEC)
+		String encoding = "";
+		if (info.getCharacterSet().contains("UTF")) {
+			encoding = "8";
+		} else if (info.getCharacterSet().contains("EUC")) {
+			encoding = "E";
+		} else if (info.getCharacterSet().contains("JIS")) {
+			encoding = "S";
+		} else if (info.getPlatformFamily().equals("WINDOWS")) {
+			encoding = "S";
+		} else {
+			encoding = "8";
+		}
+
+		//実行コマンドを設定
+		String command;
+		if (repository.getNode(fileInfo.getSrc_facility_id()).getPlatformFamily().equals("WINDOWS")) {
+			// Windowsの場合の起動コマンド
+			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_H_VBS + "\" " + info.getNodeName() + " " + hosttype + " " + encoding;
+		} else {
+			// Linuxの場合の起動コマンド
+			command = SCRIPT_DIR_LINUX + UTILIUPDT_H_SH + " " + info.getNodeName() + " " + hosttype + " " + encoding;
+		}
+		m_log.info("startCommand=" + command);
+		jobInfoEntity.setStartCommand(command);
+		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
+		jobInfoEntity.setEffectiveUser(fileInfo.getEffective_user());
+		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
+
+		//通知メッセージを作成
+		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
+
+		return jobInfoEntity.getId().getJobId();
+	}
+	
+	private String utliupdtH_rcv(
+			JobSessionJobEntity nodeJobSessionJob,
+			String waitJobId,
+			String destFacilityId,
+			JobFileInfoData fileInfo
+			) throws FacilityNotFound, HinemosUnknown {
+		
+		// 集信側に配信側のホスト管理情報を登録する
+		
+		JpaTransactionManager jtm = new JpaTransactionManager();
+
+		// インスタンス生成
+		JobInfoEntity jobInfoEntity = subCreateJobInfoEntityForJob (nodeJobSessionJob,
+				UTILIUPDT_H_RCV, destFacilityId);
+
+		//待ち条件を設定
+		jobInfoEntity.setConditionType(ConditionTypeConstant.TYPE_OR);
+		jobInfoEntity.setUnmatchEndFlg(YesNoConstant.TYPE_YES);
+		jobInfoEntity.setUnmatchEndValue(ABNORMAL);
+		jobInfoEntity.setUnmatchEndStatus(EndStatusConstant.TYPE_ABNORMAL);
+
+		if(waitJobId != null && waitJobId.length() > 0){
+			//JobStartJobInfoEntityを作成
+			// インスタンス生成
+			JobStartJobInfoEntity jobStartJobInfoEntity = new JobStartJobInfoEntity(
+					jobInfoEntity,
+					jobInfoEntity.getId().getJobunitId(),
+					waitJobId,
+					JudgmentObjectConstant.TYPE_JOB_END_STATUS,
+					EndStatusConstant.TYPE_NORMAL);
+			// 重複チェック
+			jtm.checkEntityExists(JobStartJobInfoEntity.class, jobStartJobInfoEntity.getId());
+		}
+
+		//リポジトリ(RepositoryControllerBean)を取得
+		RepositoryControllerBean repository = new RepositoryControllerBean();
+		NodeInfo info = repository.getNode(fileInfo.getSrc_facility_id());
+		
+		// ホスト種を指定 (H:汎用機　U:UNIX  N:WindowsNT  W:Windows A:AS/400  K:富士通K)
+		String hosttype;
+		if (info.getPlatformFamily().equals("WINDOWS")) {
+			hosttype = "N";
+		} else {
+			hosttype = "U";
+		}
+		
+		// 漢字コード種 (S:SHIFT-JIS  E:EUC  8:UTF-8  J:JEF  I:IBM  K:KEIS  N:NEC)
+		String encoding = "";
+		if (info.getCharacterSet().contains("UTF")) {
+			encoding = "8";
+		} else if (info.getCharacterSet().contains("EUC")) {
+			encoding = "E";
+		} else if (info.getCharacterSet().contains("JIS")) {
+			encoding = "S";
+		} else if (info.getPlatformFamily().equals("WINDOWS")) {
+			encoding = "S";
+		} else {
+			encoding = "8";
+		}
+
+		//実行コマンドを設定
+		String command;
+		if (repository.getNode(destFacilityId).getPlatformFamily().equals("WINDOWS")) {
+			// Windowsの場合の起動コマンド
+			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_H_VBS + "\" " + info.getNodeName() + " " + hosttype + " " + encoding;
+		} else {
+			// Linuxの場合の起動コマンド
+			command = SCRIPT_DIR_LINUX + UTILIUPDT_H_SH + " " + info.getNodeName() + " " + hosttype + " " + encoding;
+		}
+		m_log.info("startCommand=" + command);
+		jobInfoEntity.setStartCommand(command);
+		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
+		jobInfoEntity.setEffectiveUser(fileInfo.getEffective_user());
+		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
+
+		//通知メッセージを作成
+		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
@@ -445,40 +668,45 @@ public class CreateHulftJob {
 
 		//待ち条件を設定
 		jobInfoEntity.setConditionType(ConditionTypeConstant.TYPE_OR);
+		jobInfoEntity.setUnmatchEndFlg(YesNoConstant.TYPE_YES);
+		jobInfoEntity.setUnmatchEndValue(ABNORMAL);
+		jobInfoEntity.setUnmatchEndStatus(EndStatusConstant.TYPE_ABNORMAL);
 
 		if(waitJobId != null && waitJobId.length() > 0){
 			//JobStartJobInfoEntityを作成
-			Integer[] targetJobEndValues = {EndStatusConstant.TYPE_NORMAL,
-					EndStatusConstant.TYPE_WARNING,
-					EndStatusConstant.TYPE_ABNORMAL};
-			for (Integer targetJobEndValue : targetJobEndValues) {
-				// インスタンス生成
-				JobStartJobInfoEntity jobStartJobInfoEntity = new JobStartJobInfoEntity(
-						jobInfoEntity,
-						jobInfoEntity.getId().getJobunitId(),
-						waitJobId,
-						JudgmentObjectConstant.TYPE_JOB_END_STATUS,
-						targetJobEndValue);
-				// 重複チェック
-				jtm.checkEntityExists(JobStartJobInfoEntity.class, jobStartJobInfoEntity.getId());
-			}
+			// インスタンス生成
+			JobStartJobInfoEntity jobStartJobInfoEntity = new JobStartJobInfoEntity(
+					jobInfoEntity,
+					jobInfoEntity.getId().getJobunitId(),
+					waitJobId,
+					JudgmentObjectConstant.TYPE_JOB_END_STATUS,
+					EndStatusConstant.TYPE_NORMAL);
+			// 重複チェック
+			jtm.checkEntityExists(JobStartJobInfoEntity.class, jobStartJobInfoEntity.getId());
 		}
 
 		//リポジトリ(RepositoryControllerBean)を取得
 		RepositoryControllerBean repository = new RepositoryControllerBean();
-		NodeInfo info = repository.getNode(fileInfo.getSrc_facility_id());
 
 		//実行コマンドを設定
-		String command = SCRIPT_DIR + HULOPLCMD_SH + " " + info.getNodeName();
+		String command;
+		if (repository.getNode(fileInfo.getSrc_facility_id()).getPlatformFamily().equals("WINDOWS")) {
+			// Windowsの場合の起動コマンド
+			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + HULOPLCMD_VBS +"\"";
+		} else {
+			// Linuxの場合の起動コマンド
+			command = SCRIPT_DIR_LINUX + HULOPLCMD_SH;
+		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
 		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
 		jobInfoEntity.setEffectiveUser(fileInfo.getEffective_user());
 		jobInfoEntity.setArgument(filePath);
+		jobInfoEntity.setArgumentJobId(waitJobId);
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity);
+		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
@@ -534,10 +762,6 @@ public class CreateHulftJob {
 		jobInfoEntity.setMultiplicityNotify(jobInfo.getMultiplicityNotify());
 		jobInfoEntity.setMultiplicityNotifyPriority(jobInfo.getMultiplicityNotifyPriority());
 		jobInfoEntity.setMultiplicityOperation(jobInfo.getMultiplicityOperation());
-		// 通知の設定
-		jobInfoEntity.setJobNoticeInfoEntities(jobInfo.getJobNoticeInfoEntities());
-		
-		
 
 		//JobSessionNodeを作成
 		// インスタンス生成
@@ -583,23 +807,45 @@ public class CreateHulftJob {
 	 * 
 	 * @param jobInfoEntity 親のJobInfoEntity
 	 * @return
+	 * @throws HinemosUnknown 
 	 */
-	private void subCreateJobNoticeInfoEntity (JobInfoEntity jobInfoEntity) {
-
+	private void subCreateJobNoticeInfoEntity (JobInfoEntity jobInfoEntity, String parentJobId) throws HinemosUnknown {
 		JpaTransactionManager jtm = new JpaTransactionManager();
 
-		//JobNoticeInfoEntity(通知メッセージ)を作成
-		Integer[] noticeTypes = {EndStatusConstant.TYPE_BEGINNING,
-				EndStatusConstant.TYPE_NORMAL,
-				EndStatusConstant.TYPE_WARNING,
-				EndStatusConstant.TYPE_ABNORMAL};
-		for (Integer noticeType : noticeTypes) {
-			// インスタンス生成
-			JobNoticeInfoEntity jobNoticeInfoEntity = new JobNoticeInfoEntity(jobInfoEntity, noticeType);
-			// 重複チェック
-			jtm.checkEntityExists(JobNoticeInfoEntity.class, jobNoticeInfoEntity.getId());
-		}
+		String sessionId = jobInfoEntity.getId().getSessionId();
+		String jobunitId = jobInfoEntity.getId().getJobunitId();
+		String jobId = jobInfoEntity.getId().getJobId();
 
+		m_log.info("subCreateJobNoticeInfoEntity() : jobInfoEntity="+sessionId+",jobunitId="+jobunitId+",jobId="+jobId+",parentJobId="+parentJobId);
+		try {
+			 //JobNoticeInfoEntity(通知メッセージ)を作成 
+			JobInfoEntity parentJobInfoEntity = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, parentJobId).getJobInfoEntity();
+			List<JobNoticeInfoEntity> noticeInfoEntities = new ArrayList<JobNoticeInfoEntity>(parentJobInfoEntity.getJobNoticeInfoEntities());
+			for (JobNoticeInfoEntity notice : noticeInfoEntities) {
+				// インスタンス生成 
+				JobNoticeInfoEntity jobNoticeInfoEntity = new JobNoticeInfoEntity(jobInfoEntity, notice.getId().getNoticeType()); 
+				// 重複チェック 
+				jtm.checkEntityExists(JobNoticeInfoEntity.class, jobNoticeInfoEntity.getId()); 
+				
+				String infoNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(sessionId, jobunitId, jobId, 0);
+				jobNoticeInfoEntity.setNotifyGroupId(infoNotifyGroupId); 
+				jobNoticeInfoEntity.setPriority(notice.getPriority());
+			} 
+			String infoNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(
+					sessionId, jobunitId, jobId, 0);
+			// 取得したマスタ情報の通知グループIDで、通知関連情報を取得する
+			List<NotifyRelationInfo> ct = new NotifyControllerBean().getNotifyRelation(NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(sessionId, jobunitId, parentJobId, 0));
+			// JobNoticeInfo用の通知グループIDで、通知関連テーブルのコピーを作成する
+			for (NotifyRelationInfo relation : ct) {
+				relation.setNotifyGroupId(infoNotifyGroupId);
+			}
+			// JobからNotifyRelationInfoは１件のみ登録すればよい。
+			new NotifyControllerBean().addNotifyRelation(ct);
+		} catch (InvalidRole e) {
+			throw new HinemosUnknown(e.getMessage());
+		} catch (JobInfoNotFound e) {
+			throw new HinemosUnknown(e.getMessage());
+		}
 	}
 	private class JobFileInfoData
 	{
