@@ -18,14 +18,19 @@ package com.clustercontrol.jobmanagement.factory;
 import java.util.ArrayList;
 import java.util.Locale;
 
+import javax.persistence.EntityManager;
+
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
+import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
-import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobLocal;
-import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobPK;
-import com.clustercontrol.jobmanagement.ejb.entity.JobSessionJobUtil;
-import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeLocal;
-import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodePK;
-import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeUtil;
+import com.clustercontrol.jobmanagement.model.JobSessionJobEntity;
+import com.clustercontrol.jobmanagement.model.JobSessionNodeEntity;
+import com.clustercontrol.jobmanagement.model.JobSessionNodeEntityPK;
+import com.clustercontrol.jobmanagement.util.QueryUtil;
 
 /**
  * ジョブ操作用プロパティを作成するクラスです。
@@ -34,41 +39,52 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobSessionNodeUtil;
  * @since 1.0.0
  */
 public class JobOperationProperty {
+
+	private static Log m_log = LogFactory.getLog( JobOperationProperty.class );
+
 	//FIXME javadoc修正、操作用プロパティにjobunitIDが必要か確認。
-	@SuppressWarnings("unchecked")
 	public ArrayList<String> getAvailableStartOperation (String sessionId, String jobunitId, String jobId, String facilityId, Locale locale) {
+
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+
 		int status = 0;
 		int jobType = 0;
 
 		try {
 			if(facilityId != null && facilityId.length() > 0){
 				//セッションIDとジョブIDから、セッションジョブを取得
-				JobSessionJobLocal sessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
-						new JobSessionJobPK(sessionId, jobunitId, jobId));
-
+				JobSessionJobEntity sessionJob = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 				//ジョブタイプを取得
-				if(sessionJob.getJobInfo().getJob_type().intValue() == JobConstant.TYPE_FILEJOB){
+				if(sessionJob.getJobInfoEntity().getJobType() == JobConstant.TYPE_FILEJOB){
 					jobId = jobId + "_" + facilityId;
 					facilityId = null;
 
 					//セッションIDとジョブIDから、セッションジョブを取得
-					JobSessionJobLocal childSessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
-							new JobSessionJobPK(sessionId, jobunitId, jobId));
+					JobSessionJobEntity childSessionJob = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 
 					//実行状態を取得
-					status = childSessionJob.getStatus().intValue();
+					status = childSessionJob.getStatus();
 
 					//ジョブタイプを取得
 					jobType = JobOperationJudgment.TYPE_JOBNET;
 				}
 				else{
 					//セッションIDとジョブIDから、セッションジョブを取得
-					JobSessionNodeLocal sessionNode =
-						JobSessionNodeUtil.getLocalHome().findByPrimaryKey(
-								new JobSessionNodePK(sessionId, jobunitId, jobId, facilityId));
-
+					JobSessionNodeEntityPK sessionNodePk = new JobSessionNodeEntityPK(sessionId, jobunitId, jobId, facilityId);
+					JobSessionNodeEntity sessionNode = em.find(JobSessionNodeEntity.class, sessionNodePk);
+					if (sessionNode == null) {
+						JobInfoNotFound je = new JobInfoNotFound("JobSessionNodeEntity.findByPrimaryKey"
+								+ ", " + sessionNodePk.toString());
+						m_log.info("getAvailableStartOperation() : "
+								+ je.getClass().getSimpleName() + ", " + je.getMessage());
+						je.setSessionId(sessionId);
+						je.setJobunitId(jobunitId);
+						je.setJobId(jobId);
+						je.setFacilityId(facilityId);
+						throw je;
+					}
 					//実行状態を取得
-					status = sessionNode.getStatus().intValue();
+					status = sessionNode.getStatus();
 
 					//ジョブタイプを取得
 					jobType = JobOperationJudgment.TYPE_NODE;
@@ -76,22 +92,25 @@ public class JobOperationProperty {
 			}
 			else{
 				//セッションIDとジョブIDから、セッションジョブを取得
-				JobSessionJobLocal sessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
-						new JobSessionJobPK(sessionId, jobunitId, jobId));
+				JobSessionJobEntity sessionJob = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 
 				//実行状態を取得
-				status = sessionJob.getStatus().intValue();
+				status = sessionJob.getStatus();
 
 				//ジョブタイプを取得
-				if(sessionJob.getJobInfo().getJob_type().intValue() == JobConstant.TYPE_JOB){
+				if(sessionJob.getJobInfoEntity().getJobType() == JobConstant.TYPE_JOB){
 					jobType = JobOperationJudgment.TYPE_JOB;
 				}
 				else{
 					jobType = JobOperationJudgment.TYPE_JOBNET;
 				}
 			}
+		} catch (JobInfoNotFound e) {
+			// 何もしない・
 		} catch (Exception e) {
-
+			// 何もしない・
+			m_log.warn("getAvailableStartOperation() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 
 		ArrayList<String> values = new ArrayList<String>();
@@ -112,38 +131,47 @@ public class JobOperationProperty {
 	}
 
 	public ArrayList<String> getAvailableStopOperation(String sessionId, String jobunitId, String jobId, String facilityId, Locale locale) {
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+
 		int status = 0;
 		int jobType = 0;
 
 		try {
 			if(facilityId != null && facilityId.length() > 0){
 				//セッションIDとジョブIDから、セッションジョブを取得
-				JobSessionJobLocal sessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
-						new JobSessionJobPK(sessionId, jobunitId, jobId));
-
+				JobSessionJobEntity sessionJob = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 				//ジョブタイプを取得
-				if(sessionJob.getJobInfo().getJob_type().intValue() == JobConstant.TYPE_FILEJOB){
+				if(sessionJob.getJobInfoEntity().getJobType() == JobConstant.TYPE_FILEJOB){
 					jobId = jobId + "_" + facilityId;
 					facilityId = null;
 
 					//セッションIDとジョブIDから、セッションジョブを取得
-					JobSessionJobLocal childSessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
-							new JobSessionJobPK(sessionId, jobunitId, jobId));
+					JobSessionJobEntity childSessionJob = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 
 					//実行状態を取得
-					status = childSessionJob.getStatus().intValue();
+					status = childSessionJob.getStatus();
 
 					//ジョブタイプを取得
 					jobType = JobOperationJudgment.TYPE_JOBNET;
 				}
 				else{
 					//セッションIDとジョブIDから、セッションジョブを取得
-					JobSessionNodeLocal sessionNode =
-						JobSessionNodeUtil.getLocalHome().findByPrimaryKey(
-								new JobSessionNodePK(sessionId, jobunitId, jobId, facilityId));
+					JobSessionNodeEntityPK sessionNodePk = new JobSessionNodeEntityPK(sessionId, jobunitId, jobId, facilityId);
+					JobSessionNodeEntity sessionNode = em.find(JobSessionNodeEntity.class, sessionNodePk);
+					if (sessionNode == null) {
+						JobInfoNotFound je = new JobInfoNotFound("JobSessionNodeEntity.findByPrimaryKey"
+								+ ", " + sessionNodePk);
+						m_log.info("getAvailableStopOperation() : "
+								+ je.getClass().getSimpleName() + ", " + je.getMessage());
+						je.setSessionId(sessionId);
+						je.setJobunitId(jobunitId);
+						je.setJobId(jobId);
+						je.setFacilityId(facilityId);
+						throw je;
+					}
 
 					//実行状態を取得
-					status = sessionNode.getStatus().intValue();
+					status = sessionNode.getStatus();
 
 					//ジョブタイプを取得
 					jobType = JobOperationJudgment.TYPE_NODE;
@@ -151,21 +179,25 @@ public class JobOperationProperty {
 			}
 			else{
 				//セッションIDとジョブIDから、セッションジョブを取得
-				JobSessionJobLocal sessionJob = JobSessionJobUtil.getLocalHome().findByPrimaryKey(
-						new JobSessionJobPK(sessionId, jobunitId, jobId));
+				JobSessionJobEntity sessionJob = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 
 				//実行状態を取得
-				status = sessionJob.getStatus().intValue();
+				status = sessionJob.getStatus();
 
 				//ジョブタイプを取得
-				if(sessionJob.getJobInfo().getJob_type().intValue() == JobConstant.TYPE_JOB){
+				if(sessionJob.getJobInfoEntity().getJobType() == JobConstant.TYPE_JOB){
 					jobType = JobOperationJudgment.TYPE_JOB;
 				}
 				else{
 					jobType = JobOperationJudgment.TYPE_JOBNET;
 				}
 			}
+		} catch (JobInfoNotFound e) {
+			// 何もしない・
 		} catch (Exception e) {
+			// 何もしない・
+			m_log.warn("getAvailableStopOperation() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 
 		ArrayList<String> values = new ArrayList<String>();
