@@ -24,7 +24,8 @@ import com.clustercontrol.jobmanagement.view.JobDetailView;
 import com.clustercontrol.jobmanagement.view.JobHistoryView;
 import com.clustercontrol.jobmanagement.view.JobListView;
 import com.clustercontrol.jobmanagement.view.JobNodeDetailView;
-import com.clustercontrol.jobmanagement.view.ScheduleListView;
+import com.clustercontrol.jobmanagement.view.JobPlanListView;
+import com.clustercontrol.jobmanagement.view.JobKickListView;
 
 /**
  * ジョブ管理のパースペクティブを生成するクラスです。
@@ -55,9 +56,10 @@ public class JobManagementPerspective extends ClusterControlPerspectiveBase {
 		IFolderLayout bottom = layout.createFolder("bottom",
 				IPageLayout.BOTTOM, 0.34f, editorArea);
 		top.addView(JobListView.ID);
-		top.addView(ScheduleListView.ID);
+		top.addView(JobKickListView.ID);
 		top.addView(JobHistoryView.ID);
 		middle.addView(JobDetailView.ID);
+		middle.addView(JobPlanListView.ID);
 		bottom.addView(JobNodeDetailView.ID);
 		bottom.addView(ForwardFileView.ID);
 	}
