@@ -9,27 +9,35 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.util.EndpointManager;
 import com.clustercontrol.util.EndpointManager.EndpointSetting;
-import com.clustercontrol.ws.jobmanagement.CalendarNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.FacilityNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.HinemosUnknown_Exception;
+import com.clustercontrol.ws.jobmanagement.InvalidObjectPrivilege_Exception;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.InvalidSetting_Exception;
 import com.clustercontrol.ws.jobmanagement.InvalidUserPass_Exception;
 import com.clustercontrol.ws.jobmanagement.JobEndpoint;
+import com.clustercontrol.ws.jobmanagement.JobFileCheck;
 import com.clustercontrol.ws.jobmanagement.JobForwardFile;
 import com.clustercontrol.ws.jobmanagement.JobHistoryFilter;
 import com.clustercontrol.ws.jobmanagement.JobHistoryList;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
 import com.clustercontrol.ws.jobmanagement.JobInfoNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.JobInvalid_Exception;
+import com.clustercontrol.ws.jobmanagement.JobKick;
+import com.clustercontrol.ws.jobmanagement.JobKickDuplicate_Exception;
 import com.clustercontrol.ws.jobmanagement.JobMasterNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.JobNodeDetail;
+import com.clustercontrol.ws.jobmanagement.JobOperationInfo;
+import com.clustercontrol.ws.jobmanagement.JobPlan;
+import com.clustercontrol.ws.jobmanagement.JobPlanFilter;
 import com.clustercontrol.ws.jobmanagement.JobSchedule;
+import com.clustercontrol.ws.jobmanagement.JobSessionDuplicate_Exception;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 import com.clustercontrol.ws.jobmanagement.JobTriggerInfo;
-import com.clustercontrol.ws.jobmanagement.NodeOperationInfo;
 import com.clustercontrol.ws.jobmanagement.NotifyNotFound_Exception;
+import com.clustercontrol.ws.jobmanagement.OtherUserGetLock_Exception;
 import com.clustercontrol.ws.jobmanagement.OutputBasicInfo;
+import com.clustercontrol.ws.jobmanagement.UpdateTimeNotLatest_Exception;
 import com.clustercontrol.ws.jobmanagement.UserNotFound_Exception;
 import com.sun.xml.internal.ws.client.ClientTransportException;
 
@@ -46,7 +54,7 @@ public class JobEndpointWrapper {
 	private static Log m_log = LogFactory.getLog( JobEndpointWrapper.class );
 
 	public static void addSchedule(JobSchedule jobSchedule)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobKickDuplicate_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -62,8 +70,24 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
+	public static void addFileCheck(JobFileCheck jobFileCheck)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobKickDuplicate_Exception, InvalidObjectPrivilege_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				endpoint.addFileCheck(jobFileCheck);
+				return;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("addFileCheck(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
 	public static void modifySchedule(JobSchedule jobSchedule)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -79,8 +103,25 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
+	public static void modifyFileCheck(JobFileCheck jobFileCheck)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				endpoint.modifyFileCheck(jobFileCheck);
+				return;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("modifyFileCheck(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
 	public static void deleteSchedule(String scheduleId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -96,33 +137,81 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
-	public static void setScheduleStatus(String scheduleId, boolean validFlag)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+	public static void deleteFileCheck(String scheduleId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				endpoint.setScheduleStatus(scheduleId, validFlag);
+				endpoint.deleteFileCheck(scheduleId);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("setScheduleStatus(), " + e.getMessage(), e);
+				m_log.warn("deleteFileCheck(), " + e.getMessage(), e);
 				EndpointManager.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static List<String> getCalendarIdList()
-	throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public static JobSchedule getJobSchedule(String jobKickId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				return endpoint.getCalendarIdList();
+				return endpoint.getJobSchedule(jobKickId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getCalendarIdList(), " + e.getMessage(), e);
+				m_log.warn("getJobSchedule(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
+	public static JobFileCheck getJobFileCheck(String jobKickId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				return endpoint.getJobFileCheck(jobKickId);
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("getJobFileCheck(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
+	public static List<JobKick> getJobKickList()
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				return endpoint.getJobKickList();
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("getScheduleList(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+	public static void setJobKickStatus(String scheduleId, boolean validFlag)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				endpoint.setJobKickStatus(scheduleId, validFlag);
+				return;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("setJobKickStatus(), " + e.getMessage(), e);
 				EndpointManager.changeEndpoint();
 			}
 		}
@@ -130,7 +219,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static List<JobForwardFile> getForwardFileList(String sessionId, String jobunitId, String jobId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -146,7 +235,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static JobTreeItem getJobDetailList(String sessionId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -164,7 +253,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static List<String> getAvailableStartOperation(String sessionId, String jobunitId, String jobId, String facilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -180,7 +269,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static List<String> getAvailableStopOperation(String sessionId, String jobunitId, String jobId, String facilityId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -195,13 +284,13 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
-	public static JobTreeItem getJobTree(boolean treeOnly)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception, NotifyNotFound_Exception, UserNotFound_Exception {
+	public static JobTreeItem getJobTree(String ownerRoleId, boolean treeOnly)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception, NotifyNotFound_Exception, UserNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				JobTreeItem item = endpoint.getJobTree(treeOnly);
+				JobTreeItem item = endpoint.getJobTree(ownerRoleId, treeOnly);
 				setTreeParent(item);
 				return item;
 			} catch (WebServiceException e) {
@@ -213,6 +302,7 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
+	// ジョブマップからも利用します。
 	public static void setTreeParent(JobTreeItem item) {
 		List<JobTreeItem> children = item.getChildren();
 		for (JobTreeItem child : children) {
@@ -222,7 +312,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static List<JobNodeDetail> getNodeDetailList(String sessionId, String jobunitId, String jobId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -237,24 +327,10 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
-	public static List<JobSchedule> getScheduleList()
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
-		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
-			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				return endpoint.getScheduleList();
-			} catch (WebServiceException e) {
-				wse = e;
-				m_log.warn("getScheduleList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
-			}
-		}
-		throw wse;
-	}
+
 
 	public static JobTreeItem getSessionJobInfo(String sessionId, String jobunitId, String jobId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, NotifyNotFound_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, NotifyNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -270,7 +346,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static JobHistoryList getJobHistoryList(JobHistoryFilter filter, int histories)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -289,8 +365,24 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
-	public static void operationJob(NodeOperationInfo info)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
+	public static List<JobPlan> getPlanList(JobPlanFilter filter, int plans)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				return endpoint.getPlanList(filter, plans);
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("getPlanList(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
+	public static void operationJob(JobOperationInfo info)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -306,44 +398,32 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
-	public static void registerJob(JobTreeItem item)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception {
+	public static void registerJobunit(JobTreeItem jobunit)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			JobTreeItem top = null; // TOPを保存しておく
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				removeTreeParent(item);
-				endpoint.registerJob(item);
+				removeTreeParent(jobunit);
+				top = jobunit.getParent();
+				jobunit.setParent(null);
+				endpoint.registerJobunit(jobunit);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.warn("registerJob(), " + e.getMessage(), e);
 				EndpointManager.changeEndpoint();
-			}
-		}
-		throw wse;
-	}
-
-	public static void registerJobunit(JobTreeItem item)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception, NotifyNotFound_Exception {
-		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
-			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				removeTreeParent(item);
-				endpoint.registerJobunit(item);
-				return;
-			} catch (WebServiceException e) {
-				wse = e;
-				m_log.warn("registerJobunit(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+			} finally {
+				jobunit.setParent(top);
+				setTreeParent(jobunit);
 			}
 		}
 		throw wse;
 	}
 
 	public static void deleteJobunit(String jobunitId)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception, NotifyNotFound_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception, NotifyNotFound_Exception, InvalidObjectPrivilege_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -368,7 +448,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static void runJob(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo)
-	throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception {
+			throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception, JobSessionDuplicate_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -385,7 +465,7 @@ public class JobEndpointWrapper {
 	}
 
 	public static JobInfo getJobFull(JobInfo jobInfo)
-	throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception, NotifyNotFound_Exception, UserNotFound_Exception {
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception, NotifyNotFound_Exception, UserNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
 			try {
@@ -399,4 +479,72 @@ public class JobEndpointWrapper {
 		}
 		throw wse;
 	}
+
+
+	public static Long getUpdateTime(String jobunitId) throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				Long updateTime = endpoint.getUpdateTime(jobunitId);
+				m_log.debug("getUpdateTime() : jobunit=" + jobunitId + ", update=" + updateTime);
+				return updateTime;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("getJobunitUpdateTime(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
+	public static Integer getEditLock(String jobunitId, Long updateTime, boolean forceFlag)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, OtherUserGetLock_Exception, UpdateTimeNotLatest_Exception, JobInvalid_Exception, JobMasterNotFound_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				return endpoint.getEditLock(jobunitId, updateTime, forceFlag);
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("getEditLock(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
+	public static void checkEditLock(String jobunitId, Integer editSession)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, OtherUserGetLock_Exception, UpdateTimeNotLatest_Exception, JobInvalid_Exception, JobMasterNotFound_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				endpoint.checkEditLock(jobunitId, editSession);
+				return;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("checkEditLock(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
+	public static void releaseEditLock(Integer editSession)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+			try {
+				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				endpoint.releaseEditLock(editSession);
+				return;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("releaseEditLock(), " + e.getMessage(), e);
+				EndpointManager.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
 }
