@@ -96,8 +96,9 @@ public class JobValidator {
 		//p分かq分毎に繰り返し実行の場合
 		if(jobSchedule.getScheduleType() == ScheduleConstant.TYPE_REPEAT){
 			//「p分から」のバリデート
-			if (jobSchedule.getFromXminutes() != null) {
-				if (jobSchedule.getFromXminutes() < 0 || 60 < jobSchedule.getFromXminutes()) {
+			Integer pMinute = jobSchedule.getFromXminutes();
+			if (pMinute != null) {
+				if (pMinute < 0 || 60 <= pMinute) {
 					InvalidSetting e = new InvalidSetting(Messages.getString("message.job.94"));
 					m_log.info("validateJobSchedule() : "
 							+ e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -111,8 +112,11 @@ public class JobValidator {
 				throw e;
 			}
 			//「q分毎に」のバリデート
-			if (jobSchedule.getEveryXminutes() != null) {
-				if (jobSchedule.getEveryXminutes() < 0 || 60 < jobSchedule.getEveryXminutes()) {
+			Integer qMinute = jobSchedule.getEveryXminutes();
+			if (qMinute != null) {
+				if (qMinute <= 0 || 60 < qMinute || qMinute <= pMinute ||
+						!(qMinute == 5 || qMinute == 10 || qMinute == 15 ||
+						qMinute == 20 || qMinute == 30 )) { 
 					InvalidSetting e = new InvalidSetting(Messages.getString("message.job.95"));
 					m_log.info("validateJobSchedule() : "
 							+ e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -122,7 +126,7 @@ public class JobValidator {
 				// 分は必須。
 				InvalidSetting e = new InvalidSetting(Messages.getString("message.job.95"));
 				m_log.info("validateSchedule() : "
-						+ e.getClass().getSimpleName() + ", " + e.getMessage() + jobSchedule.getEveryXminutes());
+						+ e.getClass().getSimpleName() + ", " + e.getMessage() + qMinute);
 				throw e;
 			}
 		}
