@@ -30,7 +30,7 @@ import com.clustercontrol.ws.jobmanagement.JobTreeItem;
  */
 public class CopyJobAction extends Action {
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * コンストラクタ
