@@ -24,17 +24,13 @@ import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.jobmanagement.bean.JobConstant;
-import com.clustercontrol.bean.EndStatusConstant;
-import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
 import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
 import com.clustercontrol.jobmanagement.dialog.JobDialog;
+import com.clustercontrol.jobmanagement.util.JobEditStateUtil;
 import com.clustercontrol.jobmanagement.util.JobTreeItemUtil;
-import com.clustercontrol.jobmanagement.util.JobPropertyUtil;
 import com.clustercontrol.jobmanagement.view.JobListView;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
-import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 
 /**
  * ジョブ[一覧]ビューの「ジョブの作成」のクライアント側アクションクラス<BR>
@@ -46,7 +42,7 @@ public class CreateJobAction implements IViewActionDelegate {
 	/** アクションID */
 	public static final String ID = "com.clustercontrol.jobmanagement.view.action.CreateJobAction";
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
@@ -82,59 +78,17 @@ public class CreateJobAction implements IViewActionDelegate {
 
 		if (m_view instanceof JobListView) {
 			JobListView view = (JobListView) m_view
-			.getAdapter(JobListView.class);
+					.getAdapter(JobListView.class);
 			JobTreeComposite tree = view.getJobTreeComposite();
 			parent = view.getSelectJobTreeItem();
 
 			if (parent instanceof JobTreeItem) {
-
-				JobInfo jobInfo = new JobInfo();
-				jobInfo.setJobunitId(parent.getData().getJobunitId());
-				jobInfo.setId("");
-				jobInfo.setName("");
-				jobInfo.setType(JobConstant.TYPE_JOB);
+				JobInfo jobInfo = JobTreeItemUtil.getNewJobInfo(parent.getData().getJobunitId(),
+						JobConstant.TYPE_JOB);
 				item = new JobTreeItem();
 				item.setData(jobInfo);
-				JobPropertyUtil.setJobFull(item.getData()); // 不要？
-				item.getData().setUpdate(true);
-
-				JobWaitRuleInfo jobWaitRuleInfo = new JobWaitRuleInfo();
-				jobWaitRuleInfo.setSuspend(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setSkip(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setSkipEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-				jobWaitRuleInfo.setCondition(ConditionTypeConstant.TYPE_AND);
-				jobWaitRuleInfo.setEndCondition(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-				jobWaitRuleInfo.setCalendar(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setCalendarEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-				jobWaitRuleInfo.setStartDelay(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setStartDelaySession(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setStartDelaySessionValue(1);
-				jobWaitRuleInfo.setStartDelayTime(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setStartDelayConditionType(ConditionTypeConstant.TYPE_AND);
-				jobWaitRuleInfo.setStartDelayNotify(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setStartDelayOperation(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setStartDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-				jobWaitRuleInfo.setEndDelay(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setEndDelaySession(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setEndDelaySessionValue(1);
-				jobWaitRuleInfo.setEndDelayJob(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setEndDelayJobValue(1);
-				jobWaitRuleInfo.setEndDelayTime(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setEndDelayConditionType(ConditionTypeConstant.TYPE_AND);
-				jobWaitRuleInfo.setEndDelayNotify(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setEndDelayOperation(YesNoConstant.TYPE_NO);
-				jobWaitRuleInfo.setEndDelayOperationEndValue(EndStatusConstant.INITIAL_VALUE_NORMAL);
-				jobWaitRuleInfo.setSkipEndStatus(0);
-				jobWaitRuleInfo.setEndStatus(0);
-				jobWaitRuleInfo.setStartDelayNotifyPriority(0);
-				jobWaitRuleInfo.setStartDelayOperationType(0);
-				jobWaitRuleInfo.setEndDelayNotifyPriority(0);
-				jobWaitRuleInfo.setEndDelayOperationType(0);
-				item.getData().setWaitRule(jobWaitRuleInfo);
-
+				// JobPropertyUtil.setJobFull(item.getData()); // 不要？
 				JobTreeItemUtil.addChildren(parent, item);
-
 				JobDialog dialog = new JobDialog(
 						PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(),
 						false);
@@ -142,11 +96,12 @@ public class CreateJobAction implements IViewActionDelegate {
 
 				//ダイアログ表示
 				if (dialog.open() == IDialogConstants.OK_ID) {
-					view.setUpdate(true);
+					JobEditStateUtil.addEditedJobunit(item);
 				} else {
 					JobTreeItemUtil.removeChildren(parent, item);
 				}
-				tree.getTreeViewer().refresh(parent);
+				tree.getTreeViewer().sort(parent);
+				tree.refresh(parent);
 				tree.getTreeViewer().setSelection(
 						new StructuredSelection(parent), true);
 			}
