@@ -23,12 +23,15 @@ import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.ui.IViewPart;
 
 import com.clustercontrol.jobmanagement.bean.JobConstant;
+import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
+import com.clustercontrol.jobmanagement.util.JobEditStateUtil;
 import com.clustercontrol.jobmanagement.util.JobPropertyUtil;
 import com.clustercontrol.jobmanagement.util.JobTreeItemUtil;
 import com.clustercontrol.jobmanagement.util.JobUtil;
 import com.clustercontrol.jobmanagement.view.JobListView;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
+import com.clustercontrol.ws.jobmanagement.OtherUserGetLock_Exception;
 
 /**
  * ジョブ貼り付けするクライアント側アクションクラス<BR>
@@ -42,7 +45,7 @@ public class PasteJobAction extends Action {
 	private static Log m_log = LogFactory.getLog( PasteJobAction.class );
 
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * コンストラクタ
@@ -102,11 +105,16 @@ public class PasteJobAction extends Action {
 						selectItem.getData().getType() == JobConstant.TYPE_JOBNET){
 					copy = true;
 				}
+			}//参照ジョブ
+			else if(sourceItem.getData().getType() == JobConstant.TYPE_REFERJOB){
+				if(selectItem.getData().getType() == JobConstant.TYPE_JOBUNIT ||
+						selectItem.getData().getType() == JobConstant.TYPE_JOBNET){
+					copy = true;
+				}
 			}
 			if(copy){
-				view.setUpdate(true);
-
-				JobTreeItem top = (JobTreeItem)view.getJobTreeComposite().getTreeViewer().getInput();
+				JobTreeComposite tree = view.getJobTreeComposite();
+				JobTreeItem top = (JobTreeItem)tree.getTreeViewer().getInput();
 				//m_log.debug("run() setJobunitId = " + selectItem.getData().getJobunitId());
 				JobTreeItem copyItem = null;
 
@@ -114,16 +122,35 @@ public class PasteJobAction extends Action {
 				// ここでコピーしておく。
 				JobPropertyUtil.setJobFullTree(sourceItem);
 				if(sourceItem.getData().getType() == JobConstant.TYPE_JOBUNIT){
-					copyItem = JobUtil.copy(sourceItem, top, sourceItem.getData().getId());
-				}
-				else{
-					copyItem = JobUtil.copy(sourceItem, top, selectItem.getData().getJobunitId());
+					copyItem = JobUtil.copy(sourceItem, top, sourceItem.getData().getId(), sourceItem.getData().getOwnerRoleId());
+					Integer result = null;
+					try {
+						result =JobUtil.getEditLock(copyItem.getData().getJobunitId(), null, false);
+					} catch (OtherUserGetLock_Exception e) {
+						// 他のユーザがロックを取得している
+						String message = e.getMessage();
+						if (MessageDialog.openQuestion(
+								null,
+								Messages.getString("confirmed"),
+								message)) {
+							try {
+								result = JobUtil.getEditLock(copyItem.getData().getJobunitId(), null, true);
+							} catch (Exception e1) {
+								// ここには絶対にこないはず
+								m_log.error("run() : logical error");
+							}
+						}
+					}
+					JobEditStateUtil.addLockedJobunit(copyItem.getData(), null, result);
+				} else{
+					copyItem = JobUtil.copy(sourceItem, top, selectItem.getData().getJobunitId(),selectItem.getData().getOwnerRoleId());
 				}
 				JobTreeItemUtil.addChildren(selectItem, copyItem);
-				JobUtil.setEditFlg(selectItem);
+				JobEditStateUtil.addEditedJobunit(copyItem);
 
-				view.getJobTreeComposite().getTreeViewer().refresh(selectItem);
-				view.getJobTreeComposite().getTreeViewer().setSelection(
+				tree.getTreeViewer().sort(selectItem);
+				tree.refresh(selectItem);
+				tree.getTreeViewer().setSelection(
 						new StructuredSelection(selectItem), true);
 			} else {
 				MessageDialog.openError(null, Messages.getString("failed"),
