@@ -29,7 +29,7 @@ import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.PlatformUI;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.jobmanagement.action.OperationJob;
 import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
 import com.clustercontrol.jobmanagement.composite.DetailComposite;
@@ -57,7 +57,7 @@ public class StartJobAction implements IViewActionDelegate {
 	/** アクションID */
 	public static final String ID = "com.clustercontrol.jobmanagement.view.action.StartJobAction";
 	/** ビュー */
-	protected IViewPart m_view;
+	private IViewPart m_view;
 
 	/**
 	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
@@ -99,7 +99,7 @@ public class StartJobAction implements IViewActionDelegate {
 
 		if (m_view instanceof JobHistoryView) { // ボタンが押された場合
 			JobHistoryView view = (JobHistoryView) m_view
-			.getAdapter(JobHistoryView.class);
+					.getAdapter(JobHistoryView.class);
 			HistoryComposite historyComposite = view.getComposite();
 			//セッションID取得
 			sessionId = historyComposite.getSessionId();
@@ -109,7 +109,7 @@ public class StartJobAction implements IViewActionDelegate {
 			jobId = historyComposite.getJobId();
 		} else if (m_view instanceof JobDetailView) { // ボタンが押された場合
 			JobDetailView view = (JobDetailView) m_view
-			.getAdapter(JobDetailView.class);
+					.getAdapter(JobDetailView.class);
 			DetailComposite detailComposite = view.getComposite();
 			//セッションID取得
 			sessionId = detailComposite.getSessionId();
@@ -119,7 +119,7 @@ public class StartJobAction implements IViewActionDelegate {
 			jobId = detailComposite.getJobId();
 		} else if (m_view instanceof JobNodeDetailView) { // ボタンが押された場合
 			JobNodeDetailView view = (JobNodeDetailView) m_view
-			.getAdapter(JobNodeDetailView.class);
+					.getAdapter(JobNodeDetailView.class);
 			NodeDetailComposite nodeDetailComposite = view.getComposite();
 			//セッションID取得
 			sessionId = nodeDetailComposite.getSessionId();
@@ -180,19 +180,19 @@ public class StartJobAction implements IViewActionDelegate {
 		Locale locale = Locale.getDefault();
 		//セッションID
 		Property session =
-			new Property(JobOperationConstant.SESSION, Messages.getString("session.id", locale), PropertyConstant.EDITOR_TEXT);
+				new Property(JobOperationConstant.SESSION, Messages.getString("session.id", locale), PropertyDefineConstant.EDITOR_TEXT);
 		//ジョブユニットID
 		Property jobUnit =
-			new Property(JobOperationConstant.JOB_UNIT, Messages.getString("jobunit.id", locale), PropertyConstant.EDITOR_TEXT);
+				new Property(JobOperationConstant.JOB_UNIT, Messages.getString("jobunit.id", locale), PropertyDefineConstant.EDITOR_TEXT);
 		//ジョブID
 		Property job =
-			new Property(JobOperationConstant.JOB, Messages.getString("job.id", locale), PropertyConstant.EDITOR_TEXT);
+				new Property(JobOperationConstant.JOB, Messages.getString("job.id", locale), PropertyDefineConstant.EDITOR_TEXT);
 		//ファシリティID
 		Property facility =
-			new Property(JobOperationConstant.FACILITY, Messages.getString("facility.id", locale), PropertyConstant.EDITOR_TEXT);
+				new Property(JobOperationConstant.FACILITY, Messages.getString("facility.id", locale), PropertyDefineConstant.EDITOR_TEXT);
 		//制御
 		Property control =
-			new Property(JobOperationConstant.CONTROL, Messages.getString("control", locale), PropertyConstant.EDITOR_SELECT);
+				new Property(JobOperationConstant.CONTROL, Messages.getString("control", locale), PropertyDefineConstant.EDITOR_SELECT);
 
 		List<String> values = null;
 		try {
@@ -230,11 +230,11 @@ public class StartJobAction implements IViewActionDelegate {
 		}
 
 		//変更の可/不可を設定
-		session.setModify(PropertyConstant.MODIFY_NG);
-		jobUnit.setModify(PropertyConstant.MODIFY_NG);
-		job.setModify(PropertyConstant.MODIFY_NG);
-		facility.setModify(PropertyConstant.MODIFY_NG);
-		control.setModify(PropertyConstant.MODIFY_OK);
+		session.setModify(PropertyDefineConstant.MODIFY_NG);
+		jobUnit.setModify(PropertyDefineConstant.MODIFY_NG);
+		job.setModify(PropertyDefineConstant.MODIFY_NG);
+		facility.setModify(PropertyDefineConstant.MODIFY_NG);
+		control.setModify(PropertyDefineConstant.MODIFY_OK);
 
 		Property property = new Property(null, null, "");
 
