@@ -22,6 +22,7 @@ import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
+import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Point;
@@ -36,14 +37,19 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
 import com.clustercontrol.bean.DayOfWeekConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.Property;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ScheduleConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.calendar.composite.CalendarIdListComposite;
-import com.clustercontrol.composite.ComboModifyListener;
-import com.clustercontrol.composite.NumberKeyListener;
+import com.clustercontrol.composite.RoleIdListComposite;
+import com.clustercontrol.composite.RoleIdListComposite.Mode;
+import com.clustercontrol.composite.action.ComboModifyListener;
+import com.clustercontrol.composite.action.NumberKeyListener;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.maintenance.action.GetMaintenance;
@@ -72,6 +78,8 @@ public class MaintenanceDialog extends CommonDialog {
 
 	/** メンテナンスID用テキスト */
 	private Text m_textMaintenanceId = null;
+	/** ダイアログ表示時の処理タイプ */
+	private int mode;
 	/** 説明 */
 	private Text m_textDescription = null;
 	/** メンテナンス種別 */
@@ -102,6 +110,10 @@ public class MaintenanceDialog extends CommonDialog {
 	private String maintenanceId = null;
 	/** 通知情報 */
 	private NotifyInfoComposite notifyInfo = null;
+	/** オーナーロールID用テキスト */
+	// TODO: メンテナンス設定にオブジェクト権限を指定できるようななったら修正する
+//	private RoleIdListComposite m_ownerRoleId = null;
+	private String m_ownerRoleId = RoleIdConstant.ADMINISTRATORS;
 	/** この設定を有効にする */
 	private Button confirmValid = null;
 
@@ -114,12 +126,13 @@ public class MaintenanceDialog extends CommonDialog {
 	 */
 	public MaintenanceDialog(Shell parent) {
 		super(parent);
+		this.mode = PropertyDefineConstant.MODE_ADD;
 	}
 
-	public MaintenanceDialog(Shell parent, String maintenanceId, boolean referenceFlg) {
+	public MaintenanceDialog(Shell parent, String maintenanceId, int mode) {
 		super(parent);
-
 		this.maintenanceId = maintenanceId;
+		this.mode = mode;
 	}
 
 	/**
@@ -164,7 +177,8 @@ public class MaintenanceDialog extends CommonDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textMaintenanceId.setLayoutData(gridData);
-		if(this.maintenanceId != null && !"".equals(this.maintenanceId.trim())){
+		if(this.mode == PropertyDefineConstant.MODE_MODIFY
+				|| this.mode == PropertyDefineConstant.MODE_SHOW){
 			this.m_textMaintenanceId.setEnabled(false);
 		}
 		this.m_textMaintenanceId.addModifyListener(new ModifyListener(){
@@ -214,6 +228,45 @@ public class MaintenanceDialog extends CommonDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
+
+		/*
+		 * オーナーロールID
+		 */
+		// TODO: メンテナンス設定にオブジェクト権限を指定できるようななったら修正する
+//		Label labelRoleId = new Label(parent, SWT.LEFT);
+//		gridData = new GridData();
+//		gridData.horizontalSpan = WIDTH_TITLE;
+//		gridData.horizontalAlignment = GridData.FILL;
+//		gridData.grabExcessHorizontalSpace = true;
+//		labelRoleId.setLayoutData(gridData);
+//		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
+//		if (this.mode == PropertyDefineConstant.MODE_ADD
+//				|| this.mode == PropertyDefineConstant.MODE_COPY) {
+//			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, true, Mode.OWNER_ROLE);
+//			this.m_ownerRoleId.getComboRoleId().addSelectionListener(new SelectionAdapter() {
+//				@Override
+//				public void widgetSelected(SelectionEvent e) {
+//					m_calendarId.setOwnerRoleId(m_ownerRoleId.getText());
+//					notifyInfo.setOwnerRoleId(m_ownerRoleId.getText());
+//				}
+//			});
+//		} else {
+//			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, false, Mode.OWNER_ROLE);
+//		}
+//		gridData = new GridData();
+//		gridData.horizontalSpan = WIDTH_TEXT;
+//		gridData.horizontalAlignment = GridData.FILL;
+//		gridData.grabExcessHorizontalSpace = true;
+//		m_ownerRoleId.setLayoutData(gridData);
+//
+//		// 空白
+//		label = new Label(parent, SWT.NONE);
+//		gridData = new GridData();
+//		gridData.horizontalSpan = 2;
+//		gridData.horizontalAlignment = GridData.FILL;
+//		gridData.grabExcessHorizontalSpace = true;
+//		label.setLayoutData(gridData);
+
 		/*
 		 * 種別
 		 */
@@ -549,7 +602,7 @@ public class MaintenanceDialog extends CommonDialog {
 		Label labelMinutes = new Label(parent, SWT.NONE);
 		labelMinutes.setText(Messages.getString("minute"));
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		labelMinutes.setLayoutData(gridData);
@@ -557,7 +610,7 @@ public class MaintenanceDialog extends CommonDialog {
 		// 空白
 		Label label = new Label(parent, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -597,20 +650,20 @@ public class MaintenanceDialog extends CommonDialog {
 
 			}
 		});
-
-		Label labelDayOfWeek = new Label(parent, SWT.NONE);
-		labelDayOfWeek.setText(Messages.getString("weekday"));
+		
+		Label labelDummy = new Label(parent, SWT.NONE);
+		labelDummy.setText("");
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		labelDayOfWeek.setLayoutData(gridData);
+		labelDummy.setLayoutData(gridData);
 
 		m_comboDayOfWeek = new Combo(parent, SWT.READ_ONLY);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		gridData.horizontalSpan = 4;
+		gridData.horizontalSpan = 5;
 		m_comboDayOfWeek.setLayoutData(gridData);
 		m_comboDayOfWeek.setTextLimit(3);
 		m_comboDayOfWeek.setVisibleItemCount(10);
@@ -628,7 +681,7 @@ public class MaintenanceDialog extends CommonDialog {
 			}
 		});
 
-		Label labelDummy = new Label(parent, SWT.NONE);
+		Label labelDummy2 = new Label(parent, SWT.NONE);
 		labelDummy.setText("");
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -691,7 +744,7 @@ public class MaintenanceDialog extends CommonDialog {
 		Label labelMinutes = new Label(parent, SWT.NONE);
 		labelMinutes.setText(Messages.getString("minute"));
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		labelMinutes.setLayoutData(gridData);
@@ -699,7 +752,7 @@ public class MaintenanceDialog extends CommonDialog {
 		// 空白
 		Label label = new Label(parent, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -865,6 +918,14 @@ public class MaintenanceDialog extends CommonDialog {
 			maintenanceInfo.setMaintenanceId(m_textMaintenanceId.getText());
 		}
 
+		//オーナーロールID
+//		if (m_ownerRoleId.getText().length() > 0) {
+//			maintenanceInfo.setOwnerRoleId(m_ownerRoleId.getText());
+//		}
+		if (m_ownerRoleId.length() > 0) {
+			maintenanceInfo.setOwnerRoleId(m_ownerRoleId);
+		}
+
 		//説明取得
 		if (m_textDescription.getText().length() > 0) {
 			maintenanceInfo.setDescription(m_textDescription.getText());
@@ -976,7 +1037,21 @@ public class MaintenanceDialog extends CommonDialog {
 		return result;
 	}
 
-	private void setInputData(MaintenanceInfo info) {
+	protected void setInputData(MaintenanceInfo info) {
+
+		// オーナーロールID設定
+		// TODO: メンテナンス設定にオブジェクト権限を指定できるようななったら修正する
+//		if (info != null && info.getOwnerRoleId() != null) {
+//			this.m_ownerRoleId.setText(info.getOwnerRoleId());
+//		}
+		
+		// 他CompositeへのオーナーロールIDの設定
+//		this.m_calendarId.setOwnerRoleId(m_ownerRoleId.getText());
+//		this.notifyInfo.setOwnerRoleId(m_ownerRoleId.getText());
+		this.m_calendarId.setOwnerRoleId(m_ownerRoleId);
+		this.notifyInfo.setOwnerRoleId(m_ownerRoleId);
+		
+
 		if(info != null){
 			if (info.getMaintenanceId() != null) {
 				this.maintenanceId = info.getMaintenanceId();
@@ -993,7 +1068,7 @@ public class MaintenanceDialog extends CommonDialog {
 
 			if (info.getCalendarId() != null) {
 				if (!m_calendarId.getEnabled()) {
-					// カレンダー参照権限がない場合
+					// カレンダー参照権限が無い場合
 					m_calendarId.addText(info.getCalendarId());
 				}
 				this.m_calendarId.setText(info.getCalendarId());
@@ -1017,6 +1092,7 @@ public class MaintenanceDialog extends CommonDialog {
 				this.confirmValid.setSelection(ValidConstant.typeToBoolean(info.getValidFlg().intValue()));
 			}
 		}
+
 		// 各項目が必須項目であることを明示
 		this.update();
 
@@ -1074,7 +1150,7 @@ public class MaintenanceDialog extends CommonDialog {
 		boolean result = false;
 
 		if(this.maintenanceInfo != null){
-			if(this.maintenanceId == null){
+			if(this.mode == PropertyDefineConstant.MODE_ADD){
 				// 作成の場合
 				String[] args = { maintenanceInfo.getMaintenanceId() };
 				try {
@@ -1107,7 +1183,7 @@ public class MaintenanceDialog extends CommonDialog {
 							Messages.getString("message.maintenance.2", args) + errMessage);
 				}
 
-			} else{
+			} else if (this.mode == PropertyDefineConstant.MODE_MODIFY) {
 				// 変更の場合
 				result = new ModifyMaintenance().modify(maintenanceInfo);
 			}
