@@ -75,6 +75,9 @@ public class GetEventListTableDefine {
 	/** コメント */
 	public static final int COMMENT = 13;
 
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 14;
+
 	/** 初期表示時ソートカラム。 */
 	public static final int SORT_COLUMN_INDEX = RECEIVE_TIME;
 
@@ -90,13 +93,12 @@ public class GetEventListTableDefine {
 	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
 	 * @see com.clustercontrol.monitor.bean.EventTableDefine
 	 */
-	@SuppressWarnings("unchecked")
-	public static ArrayList getEventListTableDefine() {
+	public static ArrayList<TableColumnInfo> getEventListTableDefine() {
 
 		Locale locale = Locale.getDefault();
 
 		/** テーブル情報定義配列 */
-		ArrayList tableDefine = new ArrayList();
+		ArrayList<TableColumnInfo> tableDefine = new ArrayList<TableColumnInfo>();
 
 		tableDefine.add(PRIORITY,
 				new TableColumnInfo(Messages.getString("priority", locale), TableColumnInfo.PRIORITY, 55, SWT.LEFT));
@@ -126,6 +128,8 @@ public class GetEventListTableDefine {
 				new TableColumnInfo(Messages.getString("confirm.user", locale), TableColumnInfo.NONE, 80, SWT.LEFT));
 		tableDefine.add(COMMENT,
 				new TableColumnInfo(Messages.getString("comment", locale), TableColumnInfo.NONE, 200, SWT.LEFT));
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
 
 		return tableDefine;
 	}
