@@ -32,13 +32,13 @@ import org.eclipse.swt.widgets.Table;
 import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.monitor.action.GetStatusListTableDefine;
 import com.clustercontrol.monitor.util.ConvertListUtil;
 import com.clustercontrol.monitor.util.MonitorEndpointWrapper;
 import com.clustercontrol.monitor.util.StatusFilterPropertyUtil;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.monitor.HinemosUnknown_Exception;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorNotFound_Exception;
@@ -332,7 +332,7 @@ public class StatusListComposite extends Composite {
 	 * 
 	 * @param list ステータス情報一覧
 	 */
-	protected void updateStatus(ArrayList list) {
+	private void updateStatus(ArrayList list) {
 		int[] status = new int[4];
 
 		if (list != null) {
