@@ -26,12 +26,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.action.GetEventBatchConfirmProperty;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * 監視[一括確認]ダイアログクラス<BR>
@@ -68,7 +68,7 @@ public class EventBatchConfirmDialog extends CommonDialog {
 	 */
 	@Override
 	protected Point getInitialSize() {
-		return new Point(400, 500);
+		return new Point(400, 600);
 	}
 
 	/**
@@ -122,6 +122,7 @@ public class EventBatchConfirmDialog extends CommonDialog {
 		//        this.propertySheet.setInput(property);
 		this.confirmProperty = new GetEventBatchConfirmProperty().getProperty();
 		this.propertySheet.setInput(this.confirmProperty);
+		this.propertySheet.expandAll();
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
@@ -153,7 +154,7 @@ public class EventBatchConfirmDialog extends CommonDialog {
 	 * 
 	 * @return プロパティ
 	 * 
-	 * @see com.clustercontrol.composite.PropertySheet#getInput()
+	 * @see com.clustercontrol.viewer.PropertySheet#getInput()
 	 */
 	public Property getInputData() {
 		//        return (Property) this.propertySheet.getInput();
