@@ -29,12 +29,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.action.GetEventFilterProperty;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * 監視[イベントのフィルタ処理]ダイアログクラス<BR>
@@ -55,7 +55,7 @@ public class EventFilterDialog extends CommonDialog {
 
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 500;
-	private final int sizeY = 500;
+	private final int sizeY = 600;
 
 	/**
 	 * インスタンスを返します。
@@ -127,6 +127,7 @@ public class EventFilterDialog extends CommonDialog {
 			filterProperty = new GetEventFilterProperty().getProperty();
 		}
 		this.propertySheet.setInput(filterProperty);
+		this.propertySheet.expandAll();
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
