@@ -29,12 +29,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.action.GetStatusFilterProperty;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * 監視[ステータスのフィルタ処理]ダイアログクラス<BR>
@@ -127,6 +127,7 @@ public class StatusFilterDialog extends CommonDialog {
 			filterProperty = new GetStatusFilterProperty().getProperty();
 		}
 		this.propertySheet.setInput(filterProperty);
+		this.propertySheet.expandAll();
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
