@@ -493,7 +493,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 	 * 
 	 * @see #setValidateResult(String, String)
 	 */
-	protected MonitorStringValueInfo createInputData() {
+	private MonitorStringValueInfo createInputData() {
 		MonitorStringValueInfo info = new MonitorStringValueInfo();
 
 		info.setIdentifier(this.m_identifier);
@@ -609,7 +609,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 	 * 
 	 * @param enable 選択可の場合、<code> true </code>
 	 */
-	private void setEnabled(boolean enable) {
+	protected void setEnabled(boolean enable) {
 		this.m_comboPriority.setEnabled(enable);
 		this.m_textMessage.setEnabled(enable);
 	}
@@ -620,7 +620,7 @@ public class StringValueInfoCreateDialog extends CommonDialog {
 	 * @param id ID
 	 * @param message メッセージ
 	 */
-	private void setValidateResult(String id, String message) {
+	protected void setValidateResult(String id, String message) {
 
 		this.m_validateResult = new ValidateResult();
 		this.m_validateResult.setValid(false);
