@@ -17,7 +17,6 @@ package com.clustercontrol.monitor.run.factory;
 
 import java.io.File;
 import java.io.FileInputStream;
-import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
@@ -29,19 +28,7 @@ import java.util.TreeMap;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.ejb.RemoveException;
-import javax.ejb.TransactionRolledbackLocalException;
-import javax.naming.NamingException;
-import javax.transaction.HeuristicMixedException;
-import javax.transaction.HeuristicRollbackException;
-import javax.transaction.InvalidTransactionException;
-import javax.transaction.NotSupportedException;
-import javax.transaction.RollbackException;
-import javax.transaction.SystemException;
-import javax.transaction.Transaction;
-import javax.transaction.TransactionManager;
+import javax.persistence.EntityExistsException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -49,29 +36,26 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ProcessConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.calendar.ejb.session.CalendarControllerLocal;
-import com.clustercontrol.calendar.ejb.session.CalendarControllerUtil;
-import com.clustercontrol.commons.util.JmsPersistenceConfig;
+import com.clustercontrol.calendar.session.CalendarControllerBean;
 import com.clustercontrol.monitor.run.bean.MonitorJudgementInfo;
 import com.clustercontrol.monitor.run.bean.MonitorRunResultInfo;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoLocal;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
 import com.clustercontrol.monitor.run.util.CallableTask;
-import com.clustercontrol.monitor.run.util.MonitorTransactionManager;
 import com.clustercontrol.monitor.run.util.ParallelExecution;
+import com.clustercontrol.monitor.run.util.QueryUtil;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
-import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
-import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
+import com.clustercontrol.notify.session.NotifyControllerBean;
 import com.clustercontrol.performance.bean.CollectedDataErrorTypeConstant;
 import com.clustercontrol.performance.bean.Sample;
 import com.clustercontrol.performance.util.PerformanceDataUtil;
 import com.clustercontrol.repository.bean.NodeInfo;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.apllog.AplLogger;
 
@@ -85,8 +69,6 @@ import com.clustercontrol.util.apllog.AplLogger;
  */
 abstract public class RunMonitor {
 
-	private static final int RETRY_MAX = 1;
-
 	/** ログ出力のインスタンス。 */
 	private static Log m_log = LogFactory.getLog( RunMonitor.class );
 
@@ -103,10 +85,7 @@ abstract public class RunMonitor {
 	protected static int RETRY_INTERVAL = 1000;
 
 	/** 監視情報のローカルコンポーネント。 */
-	protected MonitorInfoLocal m_monitor;
-
-	/** 通知処理のローカルコンポーネント。 */
-	protected NotifyControllerLocal m_notifyController;
+	protected MonitorInfoEntity m_monitor;
 
 	/** 監視対象ID。 */
 	protected String m_monitorTypeId;
@@ -141,9 +120,6 @@ abstract public class RunMonitor {
 	/** ノード 監視結果取得時刻。 */
 	protected long m_nodeDate;
 
-	/** リポジトリ情報のローカルコンポーネント。 */
-	protected RepositoryControllerLocal m_repository;
-
 	/** 監視単位。 */
 	protected int m_monitorBlock;
 
@@ -158,6 +134,12 @@ abstract public class RunMonitor {
 
 	private static final String DISPLAY_NAME_STRING = "";
 
+	/** カレンダの期間内か否かのフラグ */
+	protected boolean m_isInCalendarTerm;
+
+	/** 次の監視タイミングがカレンダの期間内か否かのフラグ */
+	protected boolean m_isInNextCalendarTerm;
+
 	/**
 	 * 判定情報マップ。
 	 * <p>
@@ -190,7 +172,8 @@ abstract public class RunMonitor {
 			new ParallelExecution(properties);	// スレッド数の設定
 
 		} catch (Exception e) {
-			m_log.error(e.getMessage(), e);
+			m_log.warn("static() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 	}
 
@@ -201,7 +184,7 @@ abstract public class RunMonitor {
 	 * 
 	 * @see #initialize()
 	 */
-	protected RunMonitor() throws NamingException, CreateException{
+	protected RunMonitor() {
 
 		// 初期化処理
 		//		this.initialize();
@@ -212,144 +195,35 @@ abstract public class RunMonitor {
 	 * 
 	 * @param monitorTypeId 監視対象ID
 	 * @param monitorId 監視項目ID
-	 * @throws FinderException
-	 * @throws CreateException
-	 * @throws RemoveException
-	 * @throws JMSException
-	 * @throws NamingException
-	 * @throws NotSupportedException
-	 * @throws HeuristicMixedException
-	 * @throws HeuristicRollbackException
-	 * @throws RollbackException
-	 * @throws InvalidTransactionException
-	 * @throws IllegalStateException
-	 * @throws SystemException
+	 * @throws FacilityNotFound
+	 * @throws MonitorNotFound
+	 * @throws InvalidRole
+	 * @throws EntityExistsException
 	 * @throws HinemosUnknown
 	 * 
 	 * @see #runMonitorInfo()
 	 */
-	public void run(String monitorTypeId, String monitorId) throws FinderException, RemoveException, NamingException, NotSupportedException, HeuristicMixedException, HeuristicRollbackException, RollbackException, InvalidTransactionException, IllegalStateException, SystemException, CreateException, HinemosUnknown {
+	public void run(String monitorTypeId, String monitorId) throws FacilityNotFound, MonitorNotFound, InvalidRole, EntityExistsException, HinemosUnknown {
 
 		this.initialize(monitorTypeId);
 
 		m_monitorTypeId = monitorTypeId;
 		m_monitorId = monitorId;
 
-		TransactionManager tm = null;
-		Transaction oldTx = null;
 		boolean result = false;
 
-		int count = 0;
-		boolean deadlock = false;
-
 		try
 		{
-			// TransactionManagerを取得
-			tm = MonitorTransactionManager.getInstance().getTransactionManager();
-
-			// 実行中のスレッドがトランザクションに関連付けられている場合は、トランザクションを退避
-			if(tm.getTransaction() != null){
-				oldTx = tm.suspend();
+			// 監視実行
+			result = runMonitorInfo();
+		} finally {
+			if(!result){
+				AplLogger apllog = new AplLogger("MON", "mon");
+				String[] args = {m_monitorTypeId,m_monitorId};
+				apllog.put("SYS", "012", args);
 			}
-
-			try{
-
-				do {
-					try
-					{
-						count++;
-						result = false;
-						deadlock = false;
-
-						// トランザクション開始
-						if(tm.getTransaction() == null){
-							tm.begin();
-						}
-
-						// 監視実行
-						result = runMonitorInfo();
-
-						if(result){
-							// コミット
-							tm.commit();
-						}
-
-					} catch (TransactionRolledbackLocalException e) {
-
-						// デッドロックが発生した場合はリトライ
-						if(e.getCausedByException() instanceof org.jboss.util.deadlock.ApplicationDeadlockException){
-
-							deadlock = true;
-							if(count <= RETRY_MAX){
-								m_log.debug("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-							}
-							else{
-								m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-							}
-
-							if(tm.getTransaction() != null){
-								if(!result){
-									tm.rollback();
-								}
-							}
-						}
-						else{
-							m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-							throw e;
-						}
-					}
-
-				} while (deadlock && count <= RETRY_MAX);
-
-			} catch(NotSupportedException e){
-				m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-				throw e;
-			} catch (RollbackException e) {
-				m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-				throw e;
-			} catch (HeuristicMixedException e) {
-				m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-				throw e;
-			} catch(HeuristicRollbackException e){
-				m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-				throw e;
-			} catch(SystemException e){
-				m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-				throw e;
-			}
-			finally{
-				// トランザクション関連の例外が発生した場合は、ロールバック
-				if(tm.getTransaction() != null){
-					if(!result){
-						AplLogger apllog = new AplLogger("MON", "mon");
-						String[] args = {m_monitorTypeId,m_monitorId};
-						apllog.put("SYS", "012", args);
-						tm.rollback();
-					}
-				}
-			}
-		}
-		finally{
-
 			// 終了処理
 			this.terminate();
-
-			// 一時停止していたトランザクションを再開
-			if(oldTx != null){
-				try{
-					tm.resume(oldTx);
-
-				} catch(InvalidTransactionException e){
-					m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-					throw e;
-				} catch(IllegalStateException e){
-					m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-					throw e;
-				} catch(SystemException e){
-					m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-					throw e;
-				}
-			}
 		}
 	}
 
@@ -367,11 +241,10 @@ abstract public class RunMonitor {
 	 * </ol>
 	 * 
 	 * @return 実行に成功した場合、</code> true </code>
-	 * @throws FinderException
-	 * @throws RemoveException
-	 * @throws JMSException
-	 * @throws NamingException
-	 * @throws CreateException
+	 * @throws FacilityNotFound
+	 * @throws MonitorNotFound
+	 * @throws InvalidRole
+	 * @throws EntityExistsException
 	 * @throws HinemosUnknown
 	 * 
 	 * @see #setMonitorInfo(String, String)
@@ -382,7 +255,7 @@ abstract public class RunMonitor {
 	 * @see #getPriority(int)
 	 * @see #notify(boolean, String, int, Date)
 	 */
-	protected boolean runMonitorInfo()throws FinderException, RemoveException, NamingException, CreateException, HinemosUnknown {
+	protected boolean runMonitorInfo() throws FacilityNotFound, MonitorNotFound, InvalidRole, EntityExistsException, HinemosUnknown {
 
 		m_now = new Date();
 
@@ -409,22 +282,22 @@ abstract public class RunMonitor {
 
 			// ファシリティIDの配下全ての一覧を取得
 			// 有効/無効フラグがtrueとなっているファシリティIDを取得する
-			ArrayList<String> facilityList = m_repository.getExecTargetFacilityIdList(m_facilityId);
+			ArrayList<String> facilityList = new RepositoryControllerBean().getExecTargetFacilityIdList(m_facilityId, m_monitor.getOwnerRoleId());
 			if (facilityList.size() == 0) {
 				return true;
 			}
 
-			m_isNode = m_repository.isNode(m_facilityId);
+			m_isNode = new RepositoryControllerBean().isNode(m_facilityId);
 
 			// 監視対象となっているノードの変数を取得
 			nodeInfo = new HashMap<String, NodeInfo>();
 			for (String facilityId : facilityList) {
 				try {
 					synchronized (this) {
-						nodeInfo.put(facilityId, m_repository.getNode(facilityId));
+						nodeInfo.put(facilityId, new RepositoryControllerBean().getNode(facilityId));
 					}
 				} catch (FacilityNotFound e) {
-					m_log.warn("targeted faicility not found. (facilityId = " + facilityId + ")");
+					// 何もしない
 				}
 			}
 
@@ -455,7 +328,6 @@ abstract public class RunMonitor {
 					runMonitor.setMonitorInfo(m_monitorTypeId, m_monitorId);
 					runMonitor.m_priorityMap = this.m_priorityMap;
 					runMonitor.setJudgementInfo();
-					runMonitor.m_repository = this.m_repository;
 					runMonitor.nodeInfo = this.nodeInfo;
 					runMonitor.setCheckInfo();
 
@@ -557,22 +429,14 @@ abstract public class RunMonitor {
 			return true;
 
 		} catch (FacilityNotFound e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-			throw new FinderException(e.getMessage());
-		} catch (FinderException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-			throw e;
-		} catch (CreateException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-			throw e;
-		} catch (NamingException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
 			throw e;
 		} catch (InterruptedException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
+			m_log.info("runMonitorInfo() monitorTypeId = " + m_monitorTypeId + ", monitorId  = " + m_monitorId + " : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			return false;
 		} catch (ExecutionException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
+			m_log.info("runMonitorInfo() monitorTypeId = " + m_monitorTypeId + ", monitorId  = " + m_monitorId + " : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			return false;
 		}
 	}
@@ -591,10 +455,9 @@ abstract public class RunMonitor {
 	 * 各監視管理のサブクラスで実装します。
 	 * 監視情報よりチェック条件情報を取得し、保持します。
 	 * 
-	 * @throws FinderException
-	 * @throws NamingException
+	 * @throws MonitorNotFound
 	 */
-	protected abstract void setCheckInfo() throws FinderException, NamingException;
+	protected abstract void setCheckInfo() throws MonitorNotFound ;
 
 	/**
 	 * 監視対象に対する監視を実行し、値を収集します。
@@ -606,8 +469,9 @@ abstract public class RunMonitor {
 	 * @param facilityId 監視対象のファシリティID
 	 * @return 値取得に成功した場合、</code> true </code>
 	 * @throws FacilityNotFound
+	 * @throws HinemosUnknown
 	 */
-	public abstract boolean collect(String facilityId) throws FacilityNotFound;
+	public abstract boolean collect(String facilityId) throws FacilityNotFound, HinemosUnknown;
 
 	/**
 	 * マルチスレッドを実現するCallableTaskに渡すためのインスタンスを作成するメソッドです。
@@ -628,11 +492,9 @@ abstract public class RunMonitor {
 	 * @see com.clustercontrol.monitor.run.util.CallableTask
 	 * 
 	 * @return
-	 * @throws NamingException
-	 * @throws JMSException
-	 * @throws CreateException
+	 * @throws HinemosUnknown
 	 */
-	protected abstract RunMonitor createMonitorInstance() throws NamingException, CreateException ;
+	protected abstract RunMonitor createMonitorInstance() throws HinemosUnknown;
 
 	/**
 	 * 判定結果を返します。
@@ -853,23 +715,24 @@ abstract public class RunMonitor {
 	 * <p>
 	 * 引数で指定された監視対象と監視項目の監視情報を取得し、保持します。<BR>
 	 * 通知IDが指定されていない場合は、処理を終了します。<BR>
-	 * カレンダIDが指定されていた場合は、稼動日か否かチェックします（{@link com.clustercontrol.calendar.ejb.session.CalendarControllerBean#isRun(java.lang.String, java.util.Date)}）。非稼動日の場合は、処理を終了します。
+	 * カレンダIDが指定されていた場合は、稼動日か否かチェックします（{@link com.clustercontrol.calendar.session.CalendarControllerBean#isRun(java.lang.String, java.util.Date)}）。非稼動日の場合は、処理を終了します。
 	 * 
 	 * @param monitorTypeId 監視対象ID
 	 * @param monitorId 監視項目ID
 	 * @return 監視を実行する場合、</code> true </code>
-	 * @throws NamingException
-	 * @throws CreateException
-	 * @throws FinderException
+	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
+	 * 
 	 * @since 2.0.0
 	 * 
-	 * @see com.clustercontrol.calendar.ejb.session.CalendarControllerBean#isRun(java.lang.String, java.util.Date)
+	 * @see com.clustercontrol.calendar.session.CalendarControllerBean#isRun(java.lang.String, java.util.Date)
 	 */
-	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws NamingException, CreateException, FinderException, HinemosUnknown{
+	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws MonitorNotFound, HinemosUnknown {
+		m_isInCalendarTerm = true;
+		m_isInNextCalendarTerm = false;
 
 		// 監視基本情報を取得
-		m_monitor = MonitorInfoUtil.getLocalHome().findByPrimaryKey(monitorId);
+		m_monitor = QueryUtil.getMonitorInfoPK_NONE(monitorId);
 
 		// 通知ID
 		m_notifyGroupId = m_monitor.getNotifyGroupId();
@@ -880,33 +743,43 @@ abstract public class RunMonitor {
 			}
 		}
 
-		// カレンダID
-		String calendarId = m_monitor.getCalendarId();
-		if(calendarId != null && !"".equals(calendarId)){
-			// 稼働日か否かチェック
-			CalendarControllerLocal calendar = CalendarControllerUtil.getLocalHome().create();
-
-			try {
-				if(!calendar.isRun(calendarId, m_now==null?null:m_now.getTime()).booleanValue()){
-					// 非稼働日の場合は、処理終了
-					m_log.debug("setMonitorInfo() : monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ",calenderId:" + calendarId + ". The monitor is not executed because of non-operating day.");
-					return false;
-				}
-			} catch (CalendarNotFound e) {
-				// 指定されたカレンダIDがすでに存在しない場合は、処理終了
-				m_log.info("setMonitorInfo() : monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ". calenderId = " + calendarId + " is not exists");
-				return false;
-			}
-		}
-
 		// 監視対象ファシリティID
 		m_facilityId = m_monitor.getFacilityId();
 		// 値取得失敗時の重要度
 		m_failurePriority = m_monitor.getFailurePriority().intValue();
 		// 収集間隔
 		m_runInterval = m_monitor.getRunInterval().intValue();
-		// ジョブ実行
-		//m_jobRun = m_monitor.getJobRun().intValue();
+
+		// カレンダID
+		String calendarId = m_monitor.getCalendarId();
+		if(calendarId != null && !"".equals(calendarId)){
+			// 稼働日か否かチェック
+			try {
+				CalendarControllerBean calendar = new CalendarControllerBean();
+				if(!calendar.isRun(calendarId, m_now==null?null:m_now.getTime()).booleanValue()){
+					// 非稼働日の場合は、処理終了
+					m_log.debug("setMonitorInfo() monitorTypeId = " + m_monitorTypeId + ", monitorId = " + m_monitorId  + ", calenderId = " + calendarId
+							+ ". The monitor is not executed because of non-operating day.");
+					m_isInCalendarTerm = false;
+
+					// 次回の監視契機が稼働日か
+					if(calendar.isRun(calendarId, m_now==null?null:(m_now.getTime() + (m_runInterval*1000))).booleanValue()){
+						m_log.debug("setMonitorInfo() : monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ",calenderId:" + calendarId + ". Next term is operating day.");
+						m_isInNextCalendarTerm = true;
+					}
+
+					return false;
+				}
+			} catch (InvalidRole e) {
+				// 指定されたカレンダIDの参照権限がない場合は、処理終了
+				// 手動でない限りここは通らない。
+				// （ADMINISTRATORSロールのユーザ、もしくはユーザ未指定の場合はオブジェクト権限をしないため）
+				return false;
+			} catch (CalendarNotFound e) {
+				// 指定されたカレンダIDがすでに存在しない場合は、処理終了
+				return false;
+			}
+		}
 
 		return true;
 	}
@@ -927,14 +800,11 @@ abstract public class RunMonitor {
 	 * @param facilityId 通知対象のファシリティID
 	 * @param result 判定結果
 	 * @param generationDate ログ出力日時（監視を実行した日時）
-	 * @throws FinderException
-	 * @throws JMSException
-	 * @throws NamingException
+	 * @throws HinemosUnknown
 	 * @since 2.0.0
 	 * 
 	 * @see com.clustercontrol.monitor.message.LogOutputNotifyInfo
-	 * @see com.clustercontrol.repository.ejb.session.RepositoryControllerBean#getFacilityPath(java.lang.String, java.lang.String)
-	 * @see com.clustercontrol.monitor.run.util.SendQueue#put(Serializable)
+	 * @see com.clustercontrol.repository.session.RepositoryControllerBean#getFacilityPath(java.lang.String, java.lang.String)
 	 * @see #getNotifyId()
 	 * @see #getPriority(int)
 	 * @see #getMessageId(int)
@@ -950,7 +820,7 @@ abstract public class RunMonitor {
 			boolean isNode,
 			String facilityId,
 			int result,
-			Date generationDate) throws FinderException, NamingException{
+			Date generationDate) throws HinemosUnknown {
 		// for debug
 		if (m_log.isDebugEnabled()) {
 			m_log.debug("notify() isNode = " + isNode + ", facilityId = " + facilityId
@@ -977,7 +847,7 @@ abstract public class RunMonitor {
 		notifyInfo.setMonitorId(m_monitorId);
 		notifyInfo.setApplication(m_monitor.getApplication());
 
-		String facilityPath = m_repository.getFacilityPath(facilityId, null);
+		String facilityPath = new RepositoryControllerBean().getFacilityPath(facilityId, null);
 		notifyInfo.setFacilityId(facilityId);
 		notifyInfo.setScopeText(facilityPath);
 
@@ -1016,10 +886,9 @@ abstract public class RunMonitor {
 					+ ", generationDate = " + generationDate);
 		}
 
-		int jmsPersistence = JmsPersistenceConfig.getJmsPersistence(notifyInfo.getPluginId());
 		// ログ出力情報を送信
 		if (m_log.isDebugEnabled()) {
-			m_log.debug("sending message to jms. (" + " " + JmsPersistenceConfig.getPersistenceString(jmsPersistence) + ")"
+			m_log.debug("sending message"
 					+ " : priority=" + notifyInfo.getPriority()
 					+ " generationDate=" + notifyInfo.getGenerationDate() + " pluginId=" + notifyInfo.getPluginId()
 					+ " monitorId=" + notifyInfo.getMonitorId() + " facilityId=" + notifyInfo.getFacilityId()
@@ -1027,7 +896,7 @@ abstract public class RunMonitor {
 					+ ")");
 		}
 
-		m_notifyController.notify(notifyInfo, notifyGroupId);
+		new NotifyControllerBean().notify(notifyInfo, notifyGroupId);
 	}
 
 	/**
@@ -1047,14 +916,11 @@ abstract public class RunMonitor {
 	 * @param result 判定結果
 	 * @param generationDate ログ出力日時（監視を実行した日時）
 	 * @param resultList 並列実行時の情報
-	 * @throws FinderException
-	 * @throws JMSException
-	 * @throws NamingException
+	 * @throws HinemosUnknown
 	 * @since 2.0.0
 	 * 
 	 * @see com.clustercontrol.monitor.message.LogOutputNotifyInfo
-	 * @see com.clustercontrol.repository.ejb.session.RepositoryControllerBean#getFacilityPath(java.lang.String, java.lang.String)
-	 * @see com.clustercontrol.monitor.run.util.SendQueue#put(Serializable)
+	 * @see com.clustercontrol.repository.session.RepositoryControllerBean#getFacilityPath(java.lang.String, java.lang.String)
 	 * @see #getNotifyId()
 	 * @see #getPriority(int)
 	 * @see #getMessageId(int)
@@ -1071,7 +937,7 @@ abstract public class RunMonitor {
 			String facilityId,
 			int result,
 			Date generationDate,
-			MonitorRunResultInfo resultInfo) throws FinderException, NamingException{
+			MonitorRunResultInfo resultInfo) throws HinemosUnknown {
 
 		// for debug
 		if (m_log.isDebugEnabled()) {
@@ -1082,14 +948,7 @@ abstract public class RunMonitor {
 
 		Integer monitorFlg = 0;
 
-		// 通知のタイミングで監視設定を削除すると、NoSuchObjectLocalExceptionが発生する。
-		try {
-			monitorFlg = m_monitor.getMonitorFlg();
-		} catch (javax.ejb.NoSuchObjectLocalException e) {
-			m_log.info("monitorFlg not found, monitorId=" + m_monitorId +
-					", " + e.getMessage());
-			return;
-		}
+		monitorFlg = m_monitor.getMonitorFlg();
 
 		// 監視無効の場合、通知しない
 		if(monitorFlg == ValidConstant.TYPE_INVALID){
@@ -1111,7 +970,7 @@ abstract public class RunMonitor {
 		notifyInfo.setMonitorId(m_monitorId);
 		notifyInfo.setApplication(m_monitor.getApplication());
 
-		String facilityPath = m_repository.getFacilityPath(facilityId, null);
+		String facilityPath = new RepositoryControllerBean().getFacilityPath(facilityId, null);
 		notifyInfo.setFacilityId(facilityId);
 		notifyInfo.setScopeText(facilityPath);
 
@@ -1158,17 +1017,16 @@ abstract public class RunMonitor {
 					+ ", generationDate = " + generationDate);
 		}
 
-		int jmsPersistence = JmsPersistenceConfig.getJmsPersistence(notifyInfo.getPluginId());
 		// ログ出力情報を送信
 		if (m_log.isDebugEnabled()) {
-			m_log.debug("sending message to jms. (" + " " + JmsPersistenceConfig.getPersistenceString(jmsPersistence) + ")"
+			m_log.debug("sending message"
 					+ " : priority=" + notifyInfo.getPriority()
 					+ " generationDate=" + notifyInfo.getGenerationDate() + " pluginId=" + notifyInfo.getPluginId()
 					+ " monitorId=" + notifyInfo.getMonitorId() + " facilityId=" + notifyInfo.getFacilityId()
 					+ " subKey=" + notifyInfo.getSubKey()
 					+ ")");
 		}
-		m_notifyController.notify(notifyInfo, notifyGroupId);
+		new NotifyControllerBean().notify(notifyInfo, notifyGroupId);
 	}
 
 	/**
@@ -1180,17 +1038,15 @@ abstract public class RunMonitor {
 	 * 
 	 * @param priority 重要度
 	 * @param facilityId ファシリティ名
-	 * @throws NamingException
-	 * @throws FinderException
+	 * @throws HinemosUnknown
 	 */
-	@SuppressWarnings("unchecked")
-	protected void setPriorityMap(Integer priority, String facilityId) throws NamingException, FinderException{
+	protected void setPriorityMap(Integer priority, String facilityId) throws HinemosUnknown {
 
-		ArrayList list = m_priorityMap.get(priority);
+		ArrayList<String> list = m_priorityMap.get(priority);
 		if(list != null){
 
 			// ファシリティ名を取得
-			String facilityName = m_repository.getFacilityPath(facilityId, null);
+			String facilityName = new RepositoryControllerBean().getFacilityPath(facilityId, null);
 
 			list.add(facilityName);
 			m_priorityMap.put(priority, list);
@@ -1237,47 +1093,14 @@ abstract public class RunMonitor {
 	 * 監視を実行するrunメソッドの最初の部分でcallしてください。
 	 * runメソッド終了部分で、terminatteメソッドをcallし、キューのコネクションをクローズする必要があります。
 	 * 
-	 * @throws NamingException
-	 * @throws JMSException
-	 * @throws CreateException
 	 */
-	private void initialize(String monitorTypeId) throws NamingException, CreateException{
-		try{
-			// リポジトリ
-			m_repository = RepositoryControllerUtil.getLocalHome().create();
-
-			// 通知
-			m_notifyController = NotifyControllerUtil.getLocalHome().create();
-		} catch(CreateException e){
-			m_log.error("initialize():" + e.getMessage(), e);
-			throw e;
-		} catch(NamingException e){
-			m_log.error("initialize():" + e.getMessage(), e);
-			throw e;
-		}
+	private void initialize(String monitorTypeId) {
 	}
 
 	/**
 	 * 監視実行の終了処理を行います。
 	 * 
-	 * @throws JMSException
-	 * @throws RemoveException
 	 */
-	private void terminate() throws RemoveException{
-
-		try{
-			if(m_repository != null){
-				m_repository.remove();
-			}
-			m_repository = null;
-
-			if(m_notifyController != null){
-				m_notifyController.remove();
-			}
-			m_notifyController = null;
-		} catch (RemoveException e) {
-			m_log.error("terminate():" + e.getMessage(), e);
-			throw e;
-		}
+	private void terminate() {
 	}
 }
