@@ -46,6 +46,7 @@ public class ConvertListUtil {
 			event.add(GetEventListTableDefine.CONFIRMED, eventLogData.getConfirmed());
 			event.add(GetEventListTableDefine.CONFIRM_USER, eventLogData.getConfirmUser());
 			event.add(GetEventListTableDefine.COMMENT, eventLogData.getComment());
+			event.add(GetEventListTableDefine.OWNER_ROLE, eventLogData.getOwnerRoleId());
 
 			ret.add(event);
 		}
@@ -87,6 +88,7 @@ public class ConvertListUtil {
 			Integer confirmFlg = (Integer) event.get(GetEventListTableDefine.CONFIRMED);
 			String confirmUser = (String) event.get(GetEventListTableDefine.CONFIRM_USER);
 			String comment = (String) event.get(GetEventListTableDefine.COMMENT);
+			String ownerRoleId = (String) event.get(GetEventListTableDefine.OWNER_ROLE);
 			Timestamp commentDate = null;
 
 			EventDataInfo eventLogData = new EventDataInfo();
@@ -104,6 +106,7 @@ public class ConvertListUtil {
 			eventLogData.setConfirmed(confirmFlg);
 			eventLogData.setConfirmUser(confirmUser);
 			eventLogData.setComment(comment);
+			eventLogData.setOwnerRoleId(ownerRoleId);
 
 			eventLogDataList.add(eventLogData);
 
@@ -133,6 +136,7 @@ public class ConvertListUtil {
 			status.add(GetStatusListTableDefine.OUTPUT_TIME, new Date(statusInfoData.getGenerationDate()));
 			status.add(GetStatusListTableDefine.MESSAGE_ID, statusInfoData.getMessageId());
 			status.add(GetStatusListTableDefine.MESSAGE, statusInfoData.getMessage());
+			status.add(GetStatusListTableDefine.OWNER_ROLE, statusInfoData.getOwnerRoleId());
 
 			ret.add(status);
 		}
@@ -160,6 +164,7 @@ public class ConvertListUtil {
 			String messageId = (String) status.get(GetStatusListTableDefine.MESSAGE_ID);
 			String message = (String) status.get(GetStatusListTableDefine.MESSAGE);
 			Integer priority = (Integer) status.get(GetStatusListTableDefine.PRIORITY);
+			String ownerRoleId = (String) status.get(GetStatusListTableDefine.OWNER_ROLE);
 
 			StatusDataInfo info = new StatusDataInfo();
 			info.setMonitorId(monitorId);
@@ -171,6 +176,7 @@ public class ConvertListUtil {
 			info.setMessageId(messageId);
 			info.setMessage(message);
 			info.setPriority(priority);
+			info.setOwnerRoleId(ownerRoleId);
 
 			ret.add(info);
 		}
