@@ -89,7 +89,11 @@ public class CollectorDisableAction implements IViewActionDelegate {
 
 			targetIdList.put(monitorId, monitorTypeId);
 
-			targetList.append(monitorId + "\n");
+			if (targetList.length() > 0) {
+				targetList.append(", ");
+				
+			}
+			targetList.append(monitorId);
 		}
 
 		// 実行確認(NG→終了)
@@ -110,21 +114,29 @@ public class CollectorDisableAction implements IViewActionDelegate {
 
 			try{
 				MonitorSettingEndpointWrapper.setStatusCollector(monitorId, monitorTypeId, false);
-				successList.append(targetId + "\n");
-			}catch (InvalidRole_Exception e) {
-				failureList.append(targetId + "\n");
+				if (successList.length() > 0) {
+					successList.append(", ");
+				}
+				successList.append(targetId);
+			} catch (InvalidRole_Exception e) {
+				if (failureList.length() > 0) {
+					failureList.append(", ");
+				}
+				failureList.append(targetId + "(" + e.getMessage() + ")");
 				m_log.warn("run() setStatusCollector monitorId=" + monitorId + ", " + e.getMessage(), e);
 				hasRole = false;
 			}catch (Exception e) {
-				failureList.append(targetId + "\n");
+				if (failureList.length() > 0) {
+					failureList.append(", ");
+				}
+				failureList.append(targetId + "(" + e.getMessage() + ")");
 				m_log.warn("run() setStatusCollector monitorId=" + monitorId + ", " + e.getMessage(), e);
 			}
 		}
-		
+
 		if (!hasRole) {
-			// 権限がない場合にはエラーメッセージを表示する
-			MessageDialog.openInformation(null, Messages.getString("message"),
-					Messages.getString("message.accesscontrol.16"));
+			// 権限が無い場合にはエラーダイアログを表示する
+			MessageDialog.openInformation(null, Messages.getString("message"), Messages.getString("message.accesscontrol.16"));
 		}
 
 		// 成功ダイアログ
