@@ -56,7 +56,7 @@ public class NotifyInfoComposite extends NotifyIdListComposite {
 	private Text textApplication = null;
 
 	/** 入力値チェック用 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 
 	/**
