@@ -204,7 +204,7 @@ public class NotifyInitialComposite extends Composite {
 	 * @param message メッセージ
 	 * @return 認証結果
 	 */
-	private ValidateResult setValidateResult(String id, String message) {
+	protected ValidateResult setValidateResult(String id, String message) {
 
 		ValidateResult validateResult = new ValidateResult();
 		validateResult.setValid(false);
