@@ -28,23 +28,25 @@ import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
 
+import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.notify.action.GetNotify;
-import com.clustercontrol.notify.action.GetNotifyTableDefine;
+import com.clustercontrol.notify.action.GetNotifyTableDefineCheckBox;
+import com.clustercontrol.notify.action.GetNotifyTableDefineNoCheckBox;
+import com.clustercontrol.notify.composite.action.NotifyDoubleClickListener;
+import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
+import com.clustercontrol.ws.notify.InvalidRole_Exception;
 import com.clustercontrol.ws.notify.NotifyInfo;
 import com.clustercontrol.ws.notify.NotifyRelationInfo;
 
 /**
  * 通知一覧コンポジットクラス<BR>
  * 
- * TODO
- * com.clustercontrol.notify.composite.NotifyListCompositeと
- * com.clustercontrol.monitor.composite.NotifyListCompositeは
- * ほとんど同じコードなので、集約すること。
  * 
  * @version 3.0.0
  * @since 2.0.0
@@ -57,28 +59,20 @@ public class NotifyListComposite extends Composite {
 	/***/
 	private boolean isSelect = false;
 
-	private int notifyIdType = 0;
+	/** 合計ラベル */
+	private Label totalLabel = null;
+
+	/** 検索条件 */
+	private Property condition = null;
 
 	/**/
 	private List<NotifyRelationInfo> notify;
 
-	/**
-	 * インスタンスを返します。
-	 * <p>
-	 * 初期処理を呼び出し、コンポジットを配置します。
-	 * 
-	 * @param parent 親のコンポジット
-	 * @param style スタイル
-	 * 
-	 * @see org.eclipse.swt.SWT
-	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
-	 * @see #initialize()
-	 */
-	public NotifyListComposite(Composite parent, int style ){
-		super(parent, style);
-
-		this.initialize(false);
-	}
+	// オーナーロールID
+	private String ownerRoleId = null;
+	
+	// 表示用フラグ
+	private boolean showFlg = true;
 
 	/**
 	 * インスタンスを返します。
@@ -92,26 +86,20 @@ public class NotifyListComposite extends Composite {
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
 	 */
-	public NotifyListComposite(Composite parent, int style,boolean flg) {
+	public NotifyListComposite(Composite parent, int style,boolean isSelect, String ownerRoleId) {
 		super(parent, style);
-
-		this.initialize(flg);
-	}
-
-	public NotifyListComposite(Composite parent, int style,boolean flg, int notifyIdType) {
-		super(parent, style);
-
-		this.notifyIdType = notifyIdType;
-		this.initialize(flg);
+		this.isSelect =isSelect;
+		this.ownerRoleId = ownerRoleId;
+		this.initialize();
 	}
 
 	/**
 	 * コンポジットを配置します。
 	 * 
-	 * @see com.clustercontrol.notify.action.GetNotifyTableDefine#get()
+	 * @see com.clustercontrol.notify.action.GetNotifyTableDefineCheckBox#get()
 	 * @see #update()
 	 */
-	private void initialize(boolean flg) {
+	private void initialize() {
 		GridLayout layout = new GridLayout(1, true);
 		this.setLayout(layout);
 		layout.marginHeight = 0;
@@ -131,18 +119,23 @@ public class NotifyListComposite extends Composite {
 
 		// テーブルビューアの作成
 		this.tableViewer = new CommonTableViewer(table);
-		this.tableViewer.createTableColumn(GetNotifyTableDefine.get(),
-				GetNotifyTableDefine.SORT_COLUMN_INDEX,
-				GetNotifyTableDefine.SORT_ORDER);
+		if (this.isSelect) {
+			this.tableViewer.createTableColumn(GetNotifyTableDefineCheckBox.get(),
+					GetNotifyTableDefineCheckBox.SORT_COLUMN_INDEX,
+					GetNotifyTableDefineCheckBox.SORT_ORDER);
+		} else {
+			this.tableViewer.createTableColumn(GetNotifyTableDefineNoCheckBox.get(),
+					GetNotifyTableDefineNoCheckBox.SORT_COLUMN_INDEX,
+					GetNotifyTableDefineNoCheckBox.SORT_ORDER);
+			// ダブルクリックリスナの追加
+			this.tableViewer.addDoubleClickListener(new NotifyDoubleClickListener(this));
+		}
 
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 
-
-		if(flg){
-
-			isSelect =flg;
+		if(this.isSelect){
 
 			/**テーブルのレコードを選択するリスナー*/
 			table.addSelectionListener(new SelectionAdapter(){
@@ -157,10 +150,10 @@ public class NotifyListComposite extends Composite {
 						al = (ArrayList)ti[i].getData();
 						if((Boolean)al.get(0)){
 							//YESならNO
-							al.set(GetNotifyTableDefine.SELECTION, YesNoConstant.BOOLEAN_NO);
+							al.set(GetNotifyTableDefineCheckBox.SELECTION, YesNoConstant.BOOLEAN_NO);
 						}else{
 							//NOならYES
-							al.set(GetNotifyTableDefine.SELECTION, YesNoConstant.BOOLEAN_YES);
+							al.set(GetNotifyTableDefineCheckBox.SELECTION, YesNoConstant.BOOLEAN_YES);
 
 						}
 					}
@@ -168,9 +161,15 @@ public class NotifyListComposite extends Composite {
 					tableViewer.refresh();
 				}
 			});
+		} else {
+			// 合計ラベルの作成
+			this.totalLabel = new Label(this, SWT.RIGHT);
+			gridData = new GridData();
+			gridData.horizontalAlignment = GridData.FILL;
+			gridData.verticalAlignment = GridData.FILL;
+			this.totalLabel.setLayoutData(gridData);
 		}
 
-		this.update();
 	}
 
 	/**
@@ -182,6 +181,15 @@ public class NotifyListComposite extends Composite {
 		return this.tableViewer;
 	}
 
+	/**
+	 * このコンポジットが利用するテーブルを返します。
+	 * 
+	 * @return テーブル
+	 */
+	public Table getTable() {
+		return this.tableViewer.getTable();
+	}
+
 	/**
 	 * コンポジットを更新します。<BR>
 	 * 通知一覧情報を取得し、テーブルビューアーにセットします。
@@ -195,18 +203,45 @@ public class NotifyListComposite extends Composite {
 		List<NotifyInfo> list = null;
 		ArrayList<ArrayList<Object>> listInput = new ArrayList<ArrayList<Object>>();
 
-		list = new GetNotify().getNotifyList();
+		if (this.isSelect) {
+			if (this.ownerRoleId != null && !this.ownerRoleId.equals("")) {
+				
+				try {
+					list = new GetNotify().getNotifyListByOwnerRole(this.ownerRoleId);
+				} catch (InvalidRole_Exception e) {
+					// 通知一覧のシステム権限（参照）がない場合
+					setShowFlg(false);
+					return;
+				}
+				
+			}
+		} else {
+			list = new GetNotify().getNotifyList();
+		}
+		if(list == null)
+		{
+			//通知一覧に設定されている通知がない場合
+			list = new ArrayList<NotifyInfo>();
+		}
 		for(NotifyInfo info : list){
 			ArrayList<Object> a = new ArrayList<Object>();
-			a.add(YesNoConstant.BOOLEAN_NO);
-			a.add(info.getValidFlg());
-			a.add(info.getNotifyId());
-			a.add(info.getDescription());
-			a.add(info.getNotifyType());
+			if (this.isSelect) {
+				a.add(YesNoConstant.BOOLEAN_NO);
+				a.add(info.getValidFlg());
+				a.add(info.getNotifyId());
+				a.add(info.getDescription());
+				a.add(info.getNotifyType());
+			} else {
+				a.add(info.getNotifyId());
+				a.add(info.getDescription());
+				a.add(info.getNotifyType());
+				a.add(info.getValidFlg());
+			}
+			a.add(info.getOwnerRoleId());
 			a.add(info.getRegUser());
-			a.add(new Date(info.getRegDate()));
+			a.add(info.getRegDate() == null ? null:new Date(info.getRegDate()));
 			a.add(info.getUpdateUser());
-			a.add(new Date(info.getUpdateDate()));
+			a.add(info.getUpdateDate() == null ? null:new Date(info.getUpdateDate()));
 			listInput.add(a);
 		}
 
@@ -215,13 +250,7 @@ public class NotifyListComposite extends Composite {
 			notify = new ArrayList<NotifyRelationInfo>();
 		}
 
-
-		if(list == null)
-		{
-			//通知一覧に設定されている通知がない場合
-			list = new ArrayList<NotifyInfo>();
-
-		}else if(isSelect){
+		if(isSelect){
 			//素の通知一覧ではなく、監視から選択可能な通知一覧の場合
 			String tableNotifyId;
 			boolean flg = false;
@@ -240,17 +269,18 @@ public class NotifyListComposite extends Composite {
 					tableNotifyId = info.getNotifyId();
 
 					if(tableNotifyId.equals(nri.getNotifyId())){
-						objList.set(GetNotifyTableDefine.SELECTION, YesNoConstant.BOOLEAN_YES);
+						objList.set(GetNotifyTableDefineCheckBox.SELECTION, YesNoConstant.BOOLEAN_YES);
 						flg=true;
 					}
-					objList.set(GetNotifyTableDefine.VALID_FLG, info.getValidFlg());
-					objList.set(GetNotifyTableDefine.NOTIFY_ID, info.getNotifyId());
-					objList.set(GetNotifyTableDefine.DESCRIPTION, info.getDescription());
-					objList.set(GetNotifyTableDefine.NOTIFY_TYPE, info.getNotifyType());
-					objList.set(GetNotifyTableDefine.CREATE_USER, info.getRegUser());
-					objList.set(GetNotifyTableDefine.CREATE_TIME, new Date(info.getRegDate()));
-					objList.set(GetNotifyTableDefine.UPDATE_USER, info.getUpdateUser());
-					objList.set(GetNotifyTableDefine.UPDATE_TIME, new Date(info.getUpdateDate()));
+					objList.set(GetNotifyTableDefineCheckBox.VALID_FLG, info.getValidFlg());
+					objList.set(GetNotifyTableDefineCheckBox.NOTIFY_ID, info.getNotifyId());
+					objList.set(GetNotifyTableDefineCheckBox.DESCRIPTION, info.getDescription());
+					objList.set(GetNotifyTableDefineCheckBox.NOTIFY_TYPE, info.getNotifyType());
+					objList.set(GetNotifyTableDefineCheckBox.OWNER_ROLE, info.getOwnerRoleId());
+					objList.set(GetNotifyTableDefineCheckBox.CREATE_USER, info.getRegUser());
+					objList.set(GetNotifyTableDefineCheckBox.CREATE_TIME, new Date(info.getRegDate()));
+					objList.set(GetNotifyTableDefineCheckBox.UPDATE_USER, info.getUpdateUser());
+					objList.set(GetNotifyTableDefineCheckBox.UPDATE_TIME, new Date(info.getUpdateDate()));
 					listInput.set(i, objList);
 				}
 
@@ -261,6 +291,16 @@ public class NotifyListComposite extends Composite {
 					}
 				}
 			}
+		} else {
+			// 合計欄更新
+			String[] args = { String.valueOf(list.size()) };
+			String message = null;
+			if (this.condition == null) {
+				message = Messages.getString("records", args);
+			} else {
+				message = Messages.getString("filtered.records", args);
+			}
+			this.totalLabel.setText(message);
 		}
 		// テーブル更新
 		this.tableViewer.setInput(listInput);
@@ -300,18 +340,24 @@ public class NotifyListComposite extends Composite {
 		ArrayList<Object> al;
 		Collection<NotifyRelationInfo> ct = new ArrayList<NotifyRelationInfo>();;
 
-		for (int i = 0; i<ti.length; i++){
-			al = (ArrayList<Object>)ti[i].getData();
+		if (this.isSelect) {
+			for (int i = 0; i<ti.length; i++){
+				al = (ArrayList<Object>)ti[i].getData();
 
-			if((Boolean)al.get(GetNotifyTableDefine.SELECTION)){
+				if((Boolean)al.get(GetNotifyTableDefineCheckBox.SELECTION)){
 
-				NotifyRelationInfo nri = new NotifyRelationInfo();
-				nri.setNotifyGroupId(null);
-				nri.setNotifyId((String)al.get(GetNotifyTableDefine.NOTIFY_ID));
-				nri.setNotifyType((Integer)al.get(GetNotifyTableDefine.NOTIFY_TYPE));
-				nri.setNotifyFlg(0);
+					NotifyRelationInfo nri = new NotifyRelationInfo();
+					nri.setNotifyGroupId(null);
+					nri.setNotifyId((String)al.get(GetNotifyTableDefineCheckBox.NOTIFY_ID));
+					nri.setNotifyType((Integer)al.get(GetNotifyTableDefineCheckBox.NOTIFY_TYPE));
+					nri.setNotifyFlg(0);
 
-				ct.add(nri);
+					ct.add(nri);
+				}
+			}
+		} else {
+			for (int i = 0; i<ti.length; i++){
+				al = (ArrayList<Object>)ti[i].getData();
 			}
 		}
 
@@ -333,7 +379,7 @@ public class NotifyListComposite extends Composite {
 
 		//選択されたアイテムを取得
 		StructuredSelection selection =
-			(StructuredSelection)tableViewer.getSelection();
+				(StructuredSelection)tableViewer.getSelection();
 		List list = selection.toList();
 
 		if (list != null) {
@@ -342,7 +388,7 @@ public class NotifyListComposite extends Composite {
 
 				ArrayList info = (ArrayList)list.get(index);
 				if (info != null && info.size() > 0) {
-					String notifyId = (String)info.get(GetNotifyTableDefine.NOTIFY_ID);
+					String notifyId = (String)info.get(GetNotifyTableDefineCheckBox.NOTIFY_ID);
 					data.add(notifyId);
 				}
 			}
@@ -350,4 +396,12 @@ public class NotifyListComposite extends Composite {
 
 		return data;
 	}
+	
+	public boolean isShowFlg() {
+		return showFlg;
+	}
+
+	private void setShowFlg(boolean showFlg) {
+		this.showFlg = showFlg;
+	}
 }
\ No newline at end of file
