@@ -58,19 +58,16 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	// これらのカラム数の合計は、15でないといけない。
 
 	/** カラム数（重要度）。 */
-	private static final int WIDTH_PRIORITY = 1;
+	private static final int WIDTH_PRIORITY = 2;
 
 	/** カラム数（チェックボックス）。 */
-	private static final int WIDTH_CHECK = 1;
+	private static final int WIDTH_CHECK = 2;
 
 	/** カラム数（ユーザ入力欄）。 */
 	private static final int WIDTH_COMMAND_USER = 2;
 
 	/** カラム数（コマンド入力欄）。 */
-	private static final int WIDTH_COMMAND_TEXT = 10;
-
-	/** カラム数（空欄）。 */
-	private static final int WIDTH_BLANK = 1;
+	private static final int WIDTH_COMMAND_TEXT = 9;
 
 	// ----- instance フィールド ----- //
 
@@ -85,7 +82,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	private NotifyInfo inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト。 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 	/** 実行（重要度：通知） チェックボックス。 */
 	private Button m_checkExecInfo = null;
@@ -137,12 +134,12 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            親のシェルオブジェクト
 	 * @param notifyId
 	 *            変更する通知情報の通知ID
-	 * @param referenceFlg
-	 *            参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param updateFlg
+	 *            更新フラグ（true:更新する）
 	 */
 	public NotifyCommandCreateDialog(Shell parent, String notifyId,
-			boolean referenceFlg) {
-		super(parent, notifyId, referenceFlg);
+			boolean updateFlg) {
+		super(parent, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
@@ -256,14 +253,6 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("command"));
 
-		// ラベル（空欄）
-		label = new Label(groupComamnd, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
 		// 重要度：通知
 		label = this.getLabelPriority(groupComamnd, Messages.getString("info"),
 				PriorityColorConstant.COLOR_INFO);
@@ -278,13 +267,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 				update();
 			}
 		});
-		// ラベル（空欄）
-		label = new Label(groupComamnd, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		setEnabled(false, m_textUserInfo, m_textCommandInfo);
 
 		// 重要度：警告
 		label = this.getLabelPriority(groupComamnd, Messages
@@ -300,14 +283,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 				update();
 			}
 		});
-
-		// ラベル（空欄）
-		label = new Label(groupComamnd, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		setEnabled(false, m_textUserWarning, m_textCommandWarning);
 
 		// 重要度：危険
 		label = this.getLabelPriority(groupComamnd, Messages
@@ -324,13 +300,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 				update();
 			}
 		});
-		// ラベル（空欄）
-		label = new Label(groupComamnd, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		setEnabled(false, m_textUserCritical, m_textCommandCritical);
 
 		// 重要度：不明
 		label = this.getLabelPriority(groupComamnd, Messages
@@ -347,14 +317,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 				update();
 			}
 		});
-
-		// ラベル（空欄）
-		label = new Label(groupComamnd, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		setEnabled(false, m_textUserUnknown, m_textCommandUnknown);
 
 	}
 
@@ -461,7 +424,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 		this.inputData = notify;
 
 		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify);
+		super.m_notifyBasic.setInputData(notify, this.updateFlg);
 
 		// 初回通知情報
 		super.m_notifyInitial.setInputData(notify);
@@ -522,13 +485,6 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 			this.m_confirmValid.setSelection(true);
 		}
 
-		// 入力制御
-		if (this.referenceFlg) {
-			this.setEnabled(false);
-		} else {
-			this.setEnabled(true);
-		}
-
 		// 必須項目を可視化
 		this.update();
 	}
@@ -551,9 +507,14 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 			Text textUser,
 			TextWithParameterComposite textCommand) {
 		// コマンド通知
-		if (info.getValidFlg() != null
-				&& info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
-			checkBox.setSelection(true);
+		if (info.getValidFlg() != null) {
+			if (info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
+				checkBox.setSelection(true);
+				setEnabled(true, textUser, textCommand);
+			} else {
+				checkBox.setSelection(false);
+				setEnabled(false, textUser, textCommand);
+			}
 		}
 		// 実効ユーザ
 		if (info.getCommand() != null) {
@@ -656,7 +617,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 * @return 通知コマンド情報
 	 * 
 	 */
-	protected List<NotifyCommandInfo> createInputData(
+	private List<NotifyCommandInfo> createInputData(
 			List<NotifyCommandInfo> list,
 			String notifyId,
 			int priority,
@@ -731,7 +692,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 
 		NotifyInfo info = this.getInputData();
 		if (info != null) {
-			if (this.notifyId == null) {
+			if (!this.updateFlg) {
 				// 作成の場合
 				result = new AddNotify().add(info);
 			} else {
@@ -786,7 +747,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @see #setEnabledDetail(boolean, Button, Text, Button)
 	 */
-	private void setEnabledDetails(boolean enable) {
+	protected void setEnabledDetails(boolean enable) {
 
 		// 通知関連
 		this.setEnabledDetail(enable,this.m_checkExecInfo,
@@ -811,7 +772,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 * @param checkExecInhibition
 	 *            抑制チェックボックス
 	 */
-	private void setEnabledDetail(boolean enable, Button checkBox,
+	protected void setEnabledDetail(boolean enable, Button checkBox,
 			Text textUser, TextWithParameterComposite textCommand) {
 
 		if (enable) {
@@ -839,7 +800,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 * @param checkInhibitionFlg
 	 *            設定対象の抑制チェックボックス
 	 */
-	public void setEnabled(boolean enabled, Text textUser,
+	private void setEnabled(boolean enabled, Text textUser,
 			TextWithParameterComposite textCommand) {
 		textUser.setEnabled(enabled);
 		textCommand.setEnabled(enabled);
@@ -894,7 +855,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            ラベルの背景色
 	 * @return 生成されたラベル
 	 */
-	protected Label getLabelPriority(Composite parent, String text,
+	private Label getLabelPriority(Composite parent, String text,
 			Color background) {
 
 		// ラベル（重要度）
@@ -917,7 +878,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckBox(Composite parent) {
+	private Button getCheckBox(Composite parent) {
 
 		// チェックボックス（実行）
 		Button button = new Button(parent, SWT.CHECK);
@@ -937,7 +898,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            親のインスタンス
 	 * @return 生成されたテキストボックス
 	 */
-	protected Text getTextUser(Composite parent) {
+	private Text getTextUser(Composite parent) {
 
 		// テキスト
 		Text text = new Text(parent, SWT.BORDER);
@@ -963,7 +924,7 @@ public class NotifyCommandCreateDialog extends NotifyBasicCreateDialog {
 	 *            親のインスタンス
 	 * @return 生成されたテキストボックス
 	 */
-	protected TextWithParameterComposite getTextCommand(Composite parent) {
+	private TextWithParameterComposite getTextCommand(Composite parent) {
 
 		// テキスト
 		TextWithParameterComposite text = new TextWithParameterComposite(parent, SWT.BORDER | SWT.SINGLE);
