@@ -43,16 +43,16 @@ import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
-import com.clustercontrol.jobmanagement.common.composite.JobIdSelectionListener;
+import com.clustercontrol.jobmanagement.composite.action.JobIdSelectionListener;
 import com.clustercontrol.notify.action.AddNotify;
 import com.clustercontrol.notify.action.GetNotify;
 import com.clustercontrol.notify.action.ModifyNotify;
 import com.clustercontrol.notify.bean.ExecFacilityConstant;
 import com.clustercontrol.repository.FacilityPath;
-import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.notify.NotifyInfo;
 import com.clustercontrol.ws.notify.NotifyJobInfo;
+import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
@@ -64,28 +64,23 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/** カラム数（重要度）。 */
-	private static final int WIDTH_PRIORITY 		= 1;
+	private static final int WIDTH_PRIORITY 		= 2;
 
 	/** カラム数（ジョブ実行）。 */
-	private static final int WIDTH_JOB_RUN	 		= 1;
+	private static final int WIDTH_JOB_RUN	 		= 2;
 
 	/** カラム数（ジョブユニットID）。 */
-	private static final int WIDTH_JOBUNIT_ID	 		= 4;
+	private static final int WIDTH_JOBUNIT_ID	 		= 3;
 
 	/** カラム数（ジョブID）。 */
 	private static final int WIDTH_JOB_ID	 		= 4;
 
 	/** カラム数（参照ボタン）。 */
-	private static final int WIDTH_REF_BTN 			= 2;
-
-	/** カラム数（通知抑制と連動）。 */
-	private static final int WIDTH_INHIBITION_FLG 	= 0;
+	private static final int WIDTH_REF_BTN 			= 1;
 
 	/** カラム数（呼出失敗時）。 */
-	private static final int WIDTH_FAILURE_PRIORITY = 2;
+	private static final int WIDTH_FAILURE_PRIORITY = 3;
 
-	/** カラム数（空欄）。 */
-	private static final int WIDTH_BLANK 			= 1;
 
 	// ----- instance フィールド ----- //
 
@@ -98,7 +93,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	private NotifyInfo inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト。 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 	/** スコープ用テキスト */
 	private Text m_textScope = null;
@@ -183,10 +178,10 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
-	 * @param referenceFlg 参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyJobCreateDialog(Shell parent, String notifyId, boolean referenceFlg) {
-		super(parent, notifyId, referenceFlg);
+	public NotifyJobCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
+		super(parent, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
@@ -214,7 +209,6 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 			info = new NotifyInfo();
 		}
 		this.setInputData(info);
-
 	}
 
 	/**
@@ -343,19 +337,15 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		this.m_scopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(shell);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, m_notifyBasic.getRoleIdList().getText());
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE) {
-						m_facilityPath = "";
-						m_facilityId = "";
-					} else {
-						FacilityPath path = new FacilityPath(
-								ClusterControlPlugin.getDefault()
-								.getSeparator());
-						m_facilityPath = path.getPath(selectItem);
-						m_facilityId = selectItem.getData().getFacilityId();
-					}
+					FacilityInfo info = selectItem.getData();
+					FacilityPath path = new FacilityPath(
+							ClusterControlPlugin.getDefault()
+							.getSeparator());
+					m_facilityPath = path.getPath(selectItem);
+					m_facilityId = info.getFacilityId();
 					m_textScope.setText(m_facilityPath);
 					update();
 				}
@@ -435,81 +425,41 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("failure.call.value"));
 
-		// 空欄
-		label = new Label(groupJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
-		//　ジョブ　重要度：情報
+		// ジョブ 重要度：情報
 		label = this.getLabelPriority(groupJob, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
 		this.m_checkJobRunInfo = this.getCheckJobRun(groupJob);
 		this.m_textJobunitIdInfo = this.getTextJobunitId(groupJob);
 		this.m_textJobIdInfo = this.getTextJobId(groupJob);
 		this.m_buttonReferInfo = this.getButtonJobRefer(groupJob);
 		this.m_comboFailurePriorityInfo = this.getComboPriority(groupJob);
-		this.m_buttonReferInfo.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdInfo, m_textJobIdInfo));
+		this.m_buttonReferInfo.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdInfo, m_textJobIdInfo, m_notifyBasic.getRoleIdList()));
 
-		// 空欄
-		label = new Label(groupJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
-		//　ジョブ　重要度：警告
+		// ジョブ 重要度：警告
 		label = this.getLabelPriority(groupJob, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
 		this.m_checkJobRunWarning = this.getCheckJobRun(groupJob);
 		this.m_textJobunitIdWarning = this.getTextJobunitId(groupJob);
 		this.m_textJobIdWarning = this.getTextJobId(groupJob);
 		this.m_buttonReferWarning = this.getButtonJobRefer(groupJob);
 		this.m_comboFailurePriorityWarning = this.getComboPriority(groupJob);
-		this.m_buttonReferWarning.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdWarning, m_textJobIdWarning));
+		this.m_buttonReferWarning.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdWarning, m_textJobIdWarning, m_notifyBasic.getRoleIdList()));
 
-		// 空欄
-		label = new Label(groupJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
-		//　ジョブ　重要度：危険
+		// ジョブ 重要度：危険
 		label = this.getLabelPriority(groupJob, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
 		this.m_checkJobRunCritical = this.getCheckJobRun(groupJob);
 		this.m_textJobunitIdCritical = this.getTextJobunitId(groupJob);
 		this.m_textJobIdCritical = this.getTextJobId(groupJob);
 		this.m_buttonReferCritical = this.getButtonJobRefer(groupJob);
 		this.m_comboFailurePriorityCritical = this.getComboPriority(groupJob);
-		this.m_buttonReferCritical.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdCritical, m_textJobIdCritical));
+		this.m_buttonReferCritical.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdCritical, m_textJobIdCritical, m_notifyBasic.getRoleIdList()));
 
-		// 空欄
-		label = new Label(groupJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
-		//　ジョブ　重要度：不明
+		// ジョブ 重要度：不明
 		label = this.getLabelPriority(groupJob, Messages.getString("unknown"),PriorityColorConstant.COLOR_UNKNOWN);
 		this.m_checkJobRunUnknown = this.getCheckJobRun(groupJob);
 		this.m_textJobunitIdUnknown = this.getTextJobunitId(groupJob);
 		this.m_textJobIdUnknown = this.getTextJobId(groupJob);
 		this.m_buttonReferUnknown = this.getButtonJobRefer(groupJob);
 		this.m_comboFailurePriorityUnknown = this.getComboPriority(groupJob);
-		this.m_buttonReferUnknown.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdUnknown, m_textJobIdUnknown));
-
-		// 空欄
-		label = new Label(groupJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		this.m_buttonReferUnknown.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdUnknown, m_textJobIdUnknown, m_notifyBasic.getRoleIdList()));
 
 	}
 
@@ -581,7 +531,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		this.inputData = notify;
 
 		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify);
+		super.m_notifyBasic.setInputData(notify, this.updateFlg);
 
 		// 初回通知情報
 		super.m_notifyInitial.setInputData(notify);
@@ -639,15 +589,6 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		else {
 			this.m_confirmValid.setSelection(true);
 		}
-
-		// 入力制御
-		if(this.referenceFlg){
-			this.setEnabled(false);
-		}
-		else{
-			this.setEnabled(true);
-		}
-
 	}
 
 	/**
@@ -659,12 +600,12 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @param checkInhibition 抑制チェックボックス
 	 * @param comboFailurePriority 呼出失敗時の重要度
 	 */
-	private void setInputDataForJob(NotifyJobInfo info,
+	protected void setInputDataForJob(NotifyJobInfo info,
 			Button checkJobRun,
 			Text textJobunitId,
 			Text textJobId,
 			Combo comboFailurePriority
-	) {
+			) {
 		// ジョブ実行
 		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
 			checkJobRun.setSelection(true);
@@ -718,8 +659,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 			return null;
 		}
 
-		//　ジョブ情報
-
+		// ジョブ情報
 		ArrayList<NotifyJobInfo> list = new ArrayList<NotifyJobInfo>();
 		list = this.createInputDataForJob(list, PriorityConstant.TYPE_INFO,			this.m_checkJobRunInfo,			this.m_textJobunitIdInfo,			this.m_textJobIdInfo,			this.m_comboFailurePriorityInfo);
 		list = this.createInputDataForJob(list, PriorityConstant.TYPE_WARNING,		this.m_checkJobRunWarning,		this.m_textJobunitIdWarning,		this.m_textJobIdWarning,		this.m_comboFailurePriorityWarning);
@@ -751,13 +691,13 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @return 通知ジョブ情報
 	 * 
 	 */
-	protected ArrayList<NotifyJobInfo> createInputDataForJob(ArrayList<NotifyJobInfo> list,
+	private ArrayList<NotifyJobInfo> createInputDataForJob(ArrayList<NotifyJobInfo> list,
 			int priority,
 			Button checkJobRun,
 			Text textJobunitId,
 			Text textJobId,
 			Combo comboFailurePriority
-	) {
+			) {
 
 		if(list == null)
 			return null;
@@ -840,7 +780,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		NotifyInfo info = this.getInputData();
 		if(info != null){
-			if(this.notifyId == null){
+			if (!this.updateFlg) {
 				// 作成の場合
 				result = new AddNotify().add(info);
 			}
@@ -927,10 +867,10 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @param background ラベルの背景色
 	 * @return 生成されたラベル
 	 */
-	protected Label getLabelPriority(Composite parent,
+	private Label getLabelPriority(Composite parent,
 			String text,
 			Color background
-	) {
+			) {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
@@ -951,7 +891,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckJobRun(Composite parent) {
+	private Button getCheckJobRun(Composite parent) {
 
 		// チェックボックス（実行）
 		Button button = new Button(parent, SWT.CHECK);
@@ -981,7 +921,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Text getTextJobunitId(Composite parent) {
+	private Text getTextJobunitId(Composite parent) {
 
 		// テキストボックス（ジョブユニットID）
 		Text text = new Text(parent, SWT.BORDER | SWT.READ_ONLY);
@@ -1006,7 +946,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Text getTextJobId(Composite parent) {
+	private Text getTextJobId(Composite parent) {
 
 		// テキストボックス（ジョブID）
 		Text text = new Text(parent, SWT.BORDER | SWT.READ_ONLY);
@@ -1025,7 +965,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getButtonJobRefer(Composite parent) {
+	private Button getButtonJobRefer(Composite parent) {
 
 		// チェックボックス（参照）
 		Button button = new Button(parent, SWT.NONE);
@@ -1046,7 +986,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 * @param horizontalSpan コンボボックスのカラム数
 	 * @return コンボボックス
 	 */
-	protected Combo getComboPriority(Composite parent) {
+	private Combo getComboPriority(Composite parent) {
 
 		Combo combo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
 		GridData gridData = new GridData();
@@ -1063,4 +1003,21 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		return combo;
 	}
 
+	@Override
+	public void setOwnerRoleId(String ownerRoleId) {
+		super.setOwnerRoleId(ownerRoleId);
+		this.m_facilityPath = "";
+		this.m_facilityId = "";
+		this.m_textScope.setText(m_facilityPath);
+
+		this.m_textJobunitIdInfo.setText("");
+		this.m_textJobunitIdWarning.setText("");
+		this.m_textJobunitIdCritical.setText("");
+		this.m_textJobunitIdUnknown.setText("");
+		this.m_textJobIdInfo.setText("");
+		this.m_textJobIdWarning.setText("");
+		this.m_textJobIdCritical.setText("");
+		this.m_textJobIdUnknown.setText("");
+	}
+
 }
\ No newline at end of file
