@@ -43,7 +43,7 @@ import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.notify.action.DeleteNotify;
 import com.clustercontrol.notify.action.GetNotify;
 import com.clustercontrol.notify.action.ModifyNotify;
-import com.clustercontrol.notify.action.GetNotifyTableDefine;
+import com.clustercontrol.notify.action.GetNotifyTableDefineCheckBox;
 import com.clustercontrol.notify.composite.NotifyListComposite;
 import com.clustercontrol.notify.view.action.NotifyModifyAction;
 import com.clustercontrol.util.Messages;
@@ -63,7 +63,7 @@ public class NotifyListDialog extends CommonDialog {
 
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 800;
-	private final int sizeY = 400;
+	private final int sizeY = 450;
 
 	/** 通知一覧 コンポジット。 */
 	private NotifyListComposite notifyList = null;
@@ -86,6 +86,8 @@ public class NotifyListDialog extends CommonDialog {
 	/*通知を選択するかのフラグ*/
 	boolean isSelect = false;
 
+	String ownerRoleId = null;
+
 	/***/
 	List<NotifyRelationInfo> notify;
 
@@ -99,28 +101,14 @@ public class NotifyListDialog extends CommonDialog {
 		setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
 	}
 
-
-	/**
-	 * ダイアログのインスタンスを返します。
-	 * 
-	 * @param parent 親のシェルオブジェクト
-	 */
-	public NotifyListDialog(Shell parent, boolean isSelect) {
-
-		super(parent);
-		setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
-
-		/**監視などから呼ばれる場合にはtrue*/
-		this.isSelect = isSelect;
-	}
-
-	public NotifyListDialog(Shell parent, boolean isSelect, int notifyIdType) {
+	public NotifyListDialog(Shell parent, boolean isSelect, int notifyIdType, String ownerRoleId) {
 
 		super(parent);
 		setShellStyle(getShellStyle() | SWT.RESIZE | SWT.MAX);
 
 		/**監視などから呼ばれる場合にはtrue*/
 		this.isSelect = isSelect;
+		this.ownerRoleId = ownerRoleId;
 	}
 
 	/**
@@ -158,18 +146,21 @@ public class NotifyListDialog extends CommonDialog {
 		 * ログ一覧
 		 */
 
-		this.notifyList = new NotifyListComposite(parent, SWT.BORDER, isSelect);
+		this.notifyList = new NotifyListComposite(parent, SWT.BORDER, isSelect, this.ownerRoleId);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.grabExcessVerticalSpace = true;
 		gridData.horizontalSpan = 7;
+		gridData.heightHint = SWT.MIN;
 		this.notifyList.setLayoutData(gridData);
-
-		if(this.notify != null){
-			this.notifyList.setSelectNotify(this.notify);
-			this.notifyList.update();
+		this.notifyList.setSelectNotify(this.notify);
+		this.notifyList.update();
+		// アクセス権限がなく、通知一覧が取得できなかった場合は、本ダイアログを閉じる
+		if(!this.notifyList.isShowFlg()) {
+			this.close();
+			return ;
 		}
 
 
@@ -191,7 +182,7 @@ public class NotifyListDialog extends CommonDialog {
 
 		// 追加ボタン
 		this.buttonAdd = this
-		.createButton(composite, Messages.getString("add"));
+				.createButton(composite, Messages.getString("add"));
 		this.buttonAdd.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -215,8 +206,8 @@ public class NotifyListDialog extends CommonDialog {
 
 				if(item != null && item.length>0){
 					try{
-						notifyId = (String)((ArrayList)item[0].getData()).get(GetNotifyTableDefine.NOTIFY_ID);
-						notifyType = (Integer)((ArrayList)item[0].getData()).get(GetNotifyTableDefine.NOTIFY_TYPE);
+						notifyId = (String)((ArrayList)item[0].getData()).get(GetNotifyTableDefineCheckBox.NOTIFY_ID);
+						notifyType = (Integer)((ArrayList)item[0].getData()).get(GetNotifyTableDefineCheckBox.NOTIFY_TYPE);
 					}
 					catch(Exception ex){
 					}
@@ -225,7 +216,7 @@ public class NotifyListDialog extends CommonDialog {
 				if (notifyId != null && notifyType != null) {
 					NotifyModifyAction action = new NotifyModifyAction();
 					if (action.openDialog(getParentShell(), notifyId, notifyType) ==
-						IDialogConstants.OK_ID) {
+							IDialogConstants.OK_ID) {
 						int selectIndex = table.getSelectionIndex();
 						notifyList.update();
 						table.setSelection(selectIndex);
@@ -254,7 +245,7 @@ public class NotifyListDialog extends CommonDialog {
 
 				if(item != null && item.length>0){
 					try{
-						notifyId = (String)((ArrayList)item[0].getData()).get(GetNotifyTableDefine.NOTIFY_ID);
+						notifyId = (String)((ArrayList)item[0].getData()).get(GetNotifyTableDefineCheckBox.NOTIFY_ID);
 					}
 					catch(Exception ex){
 					}
@@ -444,7 +435,7 @@ public class NotifyListDialog extends CommonDialog {
 	 */
 	public void setValid(int valid) {
 
-		//選択された監視項目IDを取得
+		//選択された通知IDを取得
 		ArrayList<String> list = notifyList.getSelectionData();
 		if (list != null && list.size() > 0) {
 
@@ -459,9 +450,9 @@ public class NotifyListDialog extends CommonDialog {
 			String[] confirmArgs = { notifyIds.toString() };
 			String message;
 			if(valid == YesNoConstant.TYPE_YES)
-				message = Messages.getString("message.monitor.47",confirmArgs);
+				message = Messages.getString("message.notify.34",confirmArgs);
 			else
-				message = Messages.getString("message.monitor.48",confirmArgs);
+				message = Messages.getString("message.notify.37",confirmArgs);
 			if (!MessageDialog.openConfirm(
 					null,
 					Messages.getString("confirmed"),
@@ -473,21 +464,14 @@ public class NotifyListDialog extends CommonDialog {
 				String notifyId = list.get(i);
 
 				if(notifyId != null && !notifyId.equals("")){
-					//監視情報を取得
+					//通知情報を取得
 					NotifyInfo info = new GetNotify().getNotify(notifyId);
 
 					//有効・無効を設定
 					info.setValidFlg(valid);
 
-					//監視情報を更新
-					boolean result = new ModifyNotify().modify(info);
-					if(!result){
-						String[] args = { notifyId };
-						MessageDialog.openError(
-								null,
-								Messages.getString("failed"),
-								Messages.getString("message.monitor.36", args));
-					}
+					//通知情報を更新
+					new ModifyNotify().modify(info);
 				}
 			}
 
@@ -499,9 +483,8 @@ public class NotifyListDialog extends CommonDialog {
 			MessageDialog.openWarning(
 					null,
 					Messages.getString("warning"),
-					Messages.getString("message.monitor.1"));
+					Messages.getString("message.notify.10"));
 		}
 	}
 
-
 }
\ No newline at end of file
