@@ -52,10 +52,10 @@ import com.clustercontrol.notify.bean.ExecFacilityConstant;
 import com.clustercontrol.notify.bean.SyslogFacilityConstant;
 import com.clustercontrol.notify.bean.SyslogSeverityConstant;
 import com.clustercontrol.repository.FacilityPath;
-import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.notify.NotifyInfo;
 import com.clustercontrol.ws.notify.NotifyLogEscalateInfo;
+import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
@@ -67,20 +67,16 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 
 	/** カラム数（重要度）。 */
-	private static final int WIDTH_PRIORITY 		= 1;
+	private static final int WIDTH_PRIORITY 		= 2;
 
 	/** カラム数（チェックボックス）。 */
-	private static final int WIDTH_CHECK 			= 1;
+	private static final int WIDTH_CHECK 			= 2;
 
 	/** カラム数（コンボボックス）。 */
-	private static final int WIDTH_COMBO 			= 3;
+	private static final int WIDTH_COMBO 			= 2;
 
 	/** カラム数（メッセージ）。 */
-	private static final int WIDTH_MESSAGE			= 5;
-
-	/** カラム数（抑制）。 */
-	private static final int WIDTH_INHIBITION_FLG	= 2;
-
+	private static final int WIDTH_MESSAGE			= 7;
 
 
 	// ----- instance フィールド ----- //
@@ -94,7 +90,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	private NotifyInfo inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト。 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 	/** スコープ用テキスト */
 	private Text m_textScope = null;
@@ -173,10 +169,10 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
-	 * @param referenceFlg 参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyLogEscalateCreateDialog(Shell parent, String notifyId, boolean referenceFlg) {
-		super(parent, notifyId, referenceFlg);
+	public NotifyLogEscalateCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
+		super(parent, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
@@ -204,7 +200,6 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 			info = new NotifyInfo();
 		}
 		this.setInputData(info);
-
 	}
 
 	/**
@@ -341,20 +336,15 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		this.m_scopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(shell);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, m_notifyBasic.getRoleIdList().getText());
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE) {
-						m_facilityPath = "";
-						m_facilityId = "";
-					} else {
-						FacilityPath path = new FacilityPath(
-								ClusterControlPlugin.getDefault()
-								.getSeparator());
-						m_facilityPath = path.getPath(selectItem);
-						m_facilityId = selectItem.getData().getFacilityId();
-					}
-
+					FacilityInfo info = selectItem.getData();
+					FacilityPath path = new FacilityPath(
+							ClusterControlPlugin.getDefault()
+							.getSeparator());
+					m_facilityPath = path.getPath(selectItem);
+					m_facilityId = info.getFacilityId();
 					m_textScope.setText(m_facilityPath);
 					update();
 				}
@@ -455,28 +445,27 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("message"));
 
-		// 空欄
-		label = new Label(groupLogEscalate, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
 		//　ログエスカレーション　重要度：通知
 		label = this.getLabelPriority(groupLogEscalate, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
 		this.m_checkLogEscalateRunInfo = this.getCheckLogEscalateRun(groupLogEscalate);
 		this.m_comboLogEscalateFacilityInfo = this.getComboLogEscalateFacility(groupLogEscalate);
 		this.m_comboLogEscalateSeverityInfo = this.getComboLogEscalateSeverity(groupLogEscalate);
 		this.m_textLogEscalateMessageInfo = this.getStyledTextMessage(groupLogEscalate);
-
-		// 空欄
-		label = new Label(groupLogEscalate, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		this.m_checkLogEscalateRunInfo
+		.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				setEnabled(m_checkLogEscalateRunInfo.getSelection(), 
+						m_comboLogEscalateFacilityInfo, 
+						m_comboLogEscalateSeverityInfo, 
+						m_textLogEscalateMessageInfo);
+				update();
+			}
+		});
+		setEnabled(false, 
+				m_comboLogEscalateFacilityInfo, 
+				m_comboLogEscalateSeverityInfo, 
+				m_textLogEscalateMessageInfo);
 
 		//　ログエスカレーション　重要度：警告
 		label = this.getLabelPriority(groupLogEscalate, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
@@ -484,14 +473,21 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		this.m_comboLogEscalateFacilityWarning = this.getComboLogEscalateFacility(groupLogEscalate);
 		this.m_comboLogEscalateSeverityWarning = this.getComboLogEscalateSeverity(groupLogEscalate);
 		this.m_textLogEscalateMessageWarning = this.getStyledTextMessage(groupLogEscalate);
-
-		// 空欄
-		label = new Label(groupLogEscalate, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		this.m_checkLogEscalateRunWarning
+		.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				setEnabled(m_checkLogEscalateRunWarning.getSelection(), 
+						m_comboLogEscalateFacilityWarning, 
+						m_comboLogEscalateSeverityWarning, 
+						m_textLogEscalateMessageWarning);
+				update();
+			}
+		});
+		setEnabled(false, 
+				m_comboLogEscalateFacilityWarning, 
+				m_comboLogEscalateSeverityWarning, 
+				m_textLogEscalateMessageWarning);
 
 		//　ログエスカレーション　重要度：危険
 		label = this.getLabelPriority(groupLogEscalate, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
@@ -499,14 +495,22 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		this.m_comboLogEscalateFacilityCritical = this.getComboLogEscalateFacility(groupLogEscalate);
 		this.m_comboLogEscalateSeverityCritical = this.getComboLogEscalateSeverity(groupLogEscalate);
 		this.m_textLogEscalateMessageCritical = this.getStyledTextMessage(groupLogEscalate);
-
-		// 空欄
-		label = new Label(groupLogEscalate, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
+		this.m_checkLogEscalateRunCritical
+		.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				setEnabled(m_checkLogEscalateRunCritical.getSelection(), 
+						m_comboLogEscalateFacilityCritical, 
+						m_comboLogEscalateSeverityCritical, 
+						m_textLogEscalateMessageCritical);
+				update();
+			}
+		});
+		setEnabled(false, 
+				m_comboLogEscalateFacilityCritical, 
+				m_comboLogEscalateSeverityCritical, 
+				m_textLogEscalateMessageCritical);
+		
 
 		//　ログエスカレーション　重要度：不明
 		label = this.getLabelPriority(groupLogEscalate, Messages.getString("unknown"),PriorityColorConstant.COLOR_UNKNOWN);
@@ -514,15 +518,21 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		this.m_comboLogEscalateFacilityUnknown = this.getComboLogEscalateFacility(groupLogEscalate);
 		this.m_comboLogEscalateSeverityUnknown = this.getComboLogEscalateSeverity(groupLogEscalate);
 		this.m_textLogEscalateMessageUnknown = this.getStyledTextMessage(groupLogEscalate);
-
-		// 空欄
-		label = new Label(groupLogEscalate, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-
+		this.m_checkLogEscalateRunUnknown
+		.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				setEnabled(m_checkLogEscalateRunUnknown.getSelection(), 
+						m_comboLogEscalateFacilityUnknown, 
+						m_comboLogEscalateSeverityUnknown, 
+						m_textLogEscalateMessageUnknown);
+				update();
+			}
+		});
+		setEnabled(false, 
+				m_comboLogEscalateFacilityUnknown, 
+				m_comboLogEscalateSeverityUnknown, 
+				m_textLogEscalateMessageUnknown);
 	}
 
 	/**
@@ -545,6 +555,35 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		}else{
 			this.m_textEscalatePort.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
+		
+		if(this.m_checkLogEscalateRunInfo.getSelection()) {
+			if("".equals(this.m_textLogEscalateMessageInfo.getText())) {
+				this.m_textLogEscalateMessageInfo.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			} else {
+				this.m_textLogEscalateMessageInfo.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}
+		if(this.m_checkLogEscalateRunWarning.getSelection()) {
+			if("".equals(this.m_textLogEscalateMessageWarning.getText())) {
+				this.m_textLogEscalateMessageWarning.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			} else {
+				this.m_textLogEscalateMessageWarning.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}
+		if(this.m_checkLogEscalateRunCritical.getSelection()) {
+			if("".equals(this.m_textLogEscalateMessageCritical.getText())) {
+				this.m_textLogEscalateMessageCritical.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			} else {
+				this.m_textLogEscalateMessageCritical.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}
+		if (this.m_checkLogEscalateRunUnknown.getSelection()) {
+			if("".equals(this.m_textLogEscalateMessageUnknown.getText())) {
+				this.m_textLogEscalateMessageUnknown.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			} else {
+				this.m_textLogEscalateMessageUnknown.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
+		}
 	}
 
 	/**
@@ -568,7 +607,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		this.inputData = notify;
 
 		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify);
+		super.m_notifyBasic.setInputData(notify, this.updateFlg);
 
 		// 初回通知情報
 		super.m_notifyInitial.setInputData(notify);
@@ -629,15 +668,6 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		else {
 			this.m_confirmValid.setSelection(true);
 		}
-
-		// 入力制御
-		if(this.referenceFlg){
-			this.setEnabled(false);
-		}
-		else{
-			this.setEnabled(true);
-		}
-
 	}
 
 	/**
@@ -650,15 +680,24 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * @param textLogEscalateMessage メッセージテキストボックス
 	 * @param checkLogEscalateInhibition 抑制チェックボックス
 	 */
-	private void setInputDataForLogEscalate(NotifyLogEscalateInfo info,
+	protected void setInputDataForLogEscalate(NotifyLogEscalateInfo info,
 			Button checkLogEscalateRun,
 			Combo comboLogEscalateFacility,
 			Combo comboLogEscalatePriority,
 			TextWithParameterComposite textLogEscalateMessage
-	) {
+			) {
 		// ログエスカレーション実行
-		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
-			checkLogEscalateRun.setSelection(true);
+		if (info.getValidFlg() != null) {
+			boolean flag;
+			if (info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
+				flag = true;
+			} else {
+				flag = false;
+			}
+			checkLogEscalateRun.setSelection(flag);
+			comboLogEscalateFacility.setEnabled(flag);
+			comboLogEscalatePriority.setEnabled(flag); 
+			textLogEscalateMessage.setEnabled(flag);
 		}
 		// ファシリティ
 		if (info.getSyslogFacility() != null) {
@@ -708,7 +747,6 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		}
 
 		// ログエスカレーション情報
-
 		ArrayList<NotifyLogEscalateInfo> list = new ArrayList<NotifyLogEscalateInfo>();
 		list = this.createInputDataForLogEscalate(list, PriorityConstant.TYPE_INFO,		this.m_checkLogEscalateRunInfo,			this.m_comboLogEscalateFacilityInfo, 		this.m_comboLogEscalateSeverityInfo, 		this.m_textLogEscalateMessageInfo, null);
 		list = this.createInputDataForLogEscalate(list, PriorityConstant.TYPE_WARNING,	this.m_checkLogEscalateRunWarning,		this.m_comboLogEscalateFacilityWarning, 	this.m_comboLogEscalateSeverityWarning, 	this.m_textLogEscalateMessageWarning, null);
@@ -741,14 +779,14 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * @return 通知ログエスカレーション情報
 	 * 
 	 */
-	protected ArrayList<NotifyLogEscalateInfo> createInputDataForLogEscalate(ArrayList<NotifyLogEscalateInfo> list,
+	private ArrayList<NotifyLogEscalateInfo> createInputDataForLogEscalate(ArrayList<NotifyLogEscalateInfo> list,
 			int priority,
 			Button checkLogEscalateRun,
 			Combo comboLogEscalateFacility,
 			Combo comboLogEscalatePriority,
 			TextWithParameterComposite textLogEscalateMessage,
 			Button checkLogEscalateInhibition
-	) {
+			) {
 
 		if(list == null)
 			return null;
@@ -838,7 +876,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 
 		NotifyInfo info = this.getInputData();
 		if(info != null){
-			if(this.notifyId == null){
+			if (!this.updateFlg) {
 				// 作成の場合
 				result = new AddNotify().add(info);
 			}
@@ -916,6 +954,27 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		super.m_notifyBasic.setEnabled(enable);
 		super.m_notifyInhibition.setEnabled(enable);
 	}
+	
+	/**
+	 * 引数で指定されたコンポジットの選択可/不可を設定します。
+	 * 
+	 * @param enabled
+	 *            選択可の場合、</code> true </code>
+	 * @param comboLogEscalateFacility
+	 *            設定対象のファシリティコンボボックス
+	 * @param comboLogEscalatePriority
+	 *            設定対象のプライオリティコンボボックス
+	 * @param textLogEscalateMessage
+	 *            設定対象のメッセージ
+	 */
+	private void setEnabled(boolean enabled, 
+			Combo comboLogEscalateFacility,
+			Combo comboLogEscalatePriority,
+			TextWithParameterComposite textLogEscalateMessage) {
+		comboLogEscalateFacility.setEnabled(enabled);
+		comboLogEscalatePriority.setEnabled(enabled);
+		textLogEscalateMessage.setEnabled(enabled);
+	}
 
 	/**
 	 * 重要度のラベルを返します。
@@ -925,10 +984,10 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * @param background ラベルの背景色
 	 * @return 生成されたラベル
 	 */
-	protected Label getLabelPriority(Composite parent,
+	private Label getLabelPriority(Composite parent,
 			String text,
 			Color background
-	) {
+			) {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
@@ -949,7 +1008,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckLogEscalateRun(Composite parent) {
+	private Button getCheckLogEscalateRun(Composite parent) {
 
 		// チェックボックス（実行）
 		Button button = new Button(parent, SWT.CHECK);
@@ -968,7 +1027,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたコンボボックス
 	 */
-	protected Combo getComboLogEscalateFacility(Composite parent) {
+	private Combo getComboLogEscalateFacility(Composite parent) {
 
 		int blank = 0;
 
@@ -1023,7 +1082,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたコンボボックス
 	 */
-	protected Combo getComboLogEscalateSeverity(Composite parent) {
+	private Combo getComboLogEscalateSeverity(Composite parent) {
 
 		int blank = 0;
 
@@ -1065,7 +1124,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のインスタンス
 	 * @return 生成されたテキストボックス
 	 */
-	protected TextWithParameterComposite getStyledTextMessage(Composite parent/*, VerifyListener listener*/) {
+	private TextWithParameterComposite getStyledTextMessage(Composite parent/*, VerifyListener listener*/) {
 
 		// テキスト（送信先（セミコロン区切り））
 		TextWithParameterComposite text = new TextWithParameterComposite(parent, SWT.BORDER | SWT.LEFT);
@@ -1077,25 +1136,21 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
 		text.setToolTipText(Messages.getString("notify.parameter.tooltip"));
 		text.setLayoutData(gridData);
 		text.setColor(new Color(parent.getDisplay(), new RGB(0, 0, 255)));
+		text.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
 		return text;
 	}
 
-	/**
-	 * ログエスカレーションの抑制のチェックボックスを返します。
-	 * 
-	 * @param parent 親のコンポジット
-	 * @return 生成されたチェックボックス
-	 */
-	protected Button getCheckLogEscalateInhibition(Composite parent) {
-
-		// チェックボックス（抑制する）
-		Button button = new Button(parent, SWT.CHECK);
-		GridData gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.CENTER;
-		gridData.grabExcessHorizontalSpace = true;
-		button.setLayoutData(gridData);
-
-		return button;
+	@Override
+	public void setOwnerRoleId(String ownerRoleId) {
+		super.setOwnerRoleId(ownerRoleId);
+		this.m_facilityPath = "";
+		this.m_facilityId = "";
+		this.m_textScope.setText(m_facilityPath);
 	}
+
 }
\ No newline at end of file
