@@ -54,10 +54,14 @@ import com.clustercontrol.ws.notify.NotifyStatusInfo;
 public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/** カラム数（重要度）。 */
-	private static final int WIDTH_PRIORITY 	= 1;
+	private static final int WIDTH_PRIORITY 	= 2;
 
 	/** カラム数（チェックボックス）。 */
-	private static final int WIDTH_CHECK 		= 1;
+	private static final int WIDTH_CHECK 		= 2;
+	
+	/** カラム数（空欄）。 */
+	private static final int WIDTH_BLANK 		= 11;
+
 
 	// ----- instance フィールド ----- //
 
@@ -70,7 +74,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	private NotifyInfo inputData = null;
 
 	/** 入力値の正当性を保持するオブジェクト。 */
-	private ValidateResult validateResult = null;
+	protected ValidateResult validateResult = null;
 
 	/** ステータス 通知（重要度：通知） チェックボックス。 */
 	private Button m_checkStatusNormalInfo = null;
@@ -115,10 +119,10 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
-	 * @param referenceFlg 参照フラグ（参照のみで変更不可の場合、<code> true </code>）
+	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyStatusCreateDialog(Shell parent, String notifyId, boolean referenceFlg) {
-		super(parent, notifyId, referenceFlg);
+	public NotifyStatusCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
+		super(parent, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
@@ -216,7 +220,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 13;
+		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -235,7 +239,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 13;
+		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -255,7 +259,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 13;
+		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -275,7 +279,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 13;
+		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -295,7 +299,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 13;
+		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -382,7 +386,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 更新されていない旨のメッセージに置換える。
 		this.m_radioStatusUpdate = new Button(groupStatus2, SWT.RADIO);
 		gridData = new GridData();
-		gridData.horizontalSpan = 6;
+		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_radioStatusUpdate.setLayoutData(gridData);
@@ -420,7 +424,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 空白
 		label = new Label(groupStatus2, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 5;
+		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -448,7 +452,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		this.inputData = notify;
 
 		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify);
+		super.m_notifyBasic.setInputData(notify, this.updateFlg);
 
 		// 初回通知情報
 		super.m_notifyInitial.setInputData(notify);
@@ -495,6 +499,8 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 			this.m_radioStatusDelete.setSelection(true);
 		}
 
+		this.m_comboStatusPriority.setEnabled(m_radioStatusUpdate.getSelection());
+
 		// 有効／無効
 		if (notify.getValidFlg() != null && notify.getValidFlg() == ValidConstant.TYPE_INVALID) {
 			this.m_confirmValid.setSelection(false);
@@ -502,15 +508,6 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		else {
 			this.m_confirmValid.setSelection(true);
 		}
-
-		// 入力制御
-		if(this.referenceFlg){
-			this.setEnabled(false);
-		}
-		else{
-			this.setEnabled(true);
-		}
-
 	}
 
 	/**
@@ -520,10 +517,10 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * @param checkStatusNormal 通知チェックボックス
 	 * @param checkStatusInhibition 抑制チェックボックス
 	 */
-	private void setInputDataForStatus(NotifyStatusInfo info,
+	protected void setInputDataForStatus(NotifyStatusInfo info,
 			Button checkStatusNormal,
 			Button checkStatusInhibition
-	) {
+			) {
 		// ステータス通知
 		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
 			checkStatusNormal.setSelection(true);
@@ -564,7 +561,6 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		}
 
 		// ステータス情報
-
 		ArrayList<NotifyStatusInfo> list = new ArrayList<NotifyStatusInfo>();
 		list = this.createInputDataForStatus(list, PriorityConstant.TYPE_INFO,		this.m_checkStatusNormalInfo);
 		list = this.createInputDataForStatus(list, PriorityConstant.TYPE_WARNING,	this.m_checkStatusNormalWarning);
@@ -596,11 +592,11 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * @return 通知ステータス情報
 	 * 
 	 */
-	protected ArrayList<NotifyStatusInfo> createInputDataForStatus(
+	private ArrayList<NotifyStatusInfo> createInputDataForStatus(
 			ArrayList<NotifyStatusInfo> list,
 			int priority,
 			Button checkStatusNormal
-	) {
+			) {
 
 		if(list == null)
 			return null;
@@ -674,7 +670,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		NotifyInfo info = this.getInputData();
 		if(info != null){
-			if(this.notifyId == null){
+			if (!this.updateFlg) {
 				// 作成の場合
 				result = new AddNotify().add(info);
 			}
@@ -729,7 +725,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * 
 	 * @see #setEnabledForStatuses(boolean, Button, Button)
 	 */
-	private void setEnabledForStatuses(boolean enable) {
+	protected void setEnabledForStatuses(boolean enable) {
 		// 通知チェックボックス
 		this.m_checkStatusNormalInfo.setEnabled(enable);
 		this.m_checkStatusNormalWarning.setEnabled(enable);
@@ -741,7 +737,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * ステータスの通知情報の選択可/不可を設定します。
 	 * 
 	 */
-	private void setEnabledForStatusDuration() {
+	protected void setEnabledForStatusDuration() {
 
 		boolean enable = false;
 
@@ -811,10 +807,10 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * @param background ラベルの背景色
 	 * @return 生成されたラベル
 	 */
-	protected Label getLabelPriority(Composite parent,
+	private Label getLabelPriority(Composite parent,
 			String text,
 			Color background
-	) {
+			) {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
@@ -835,7 +831,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckStatusNormal(Composite parent) {
+	private Button getCheckStatusNormal(Composite parent) {
 
 		// チェックボックス（通知する）
 		Button button = new Button(parent, SWT.CHECK);
@@ -854,7 +850,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
-	protected Button getCheckStatusInhibition(Composite parent) {
+	private Button getCheckStatusInhibition(Composite parent) {
 
 		// チェックボックス（抑制する）
 		Button button = new Button(parent, SWT.CHECK);
