@@ -28,6 +28,7 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.NotifyNotFound;
 import com.clustercontrol.notify.bean.NotifyInfo;
@@ -79,8 +80,9 @@ public class NotifyDispatcher {
 	 * @param info 通知出力情報
 	 * @param notifyIdList 通知対象の通知ID
 	 * @param queueDeliveryMode JMSの永続化モード指定
+	 * @throws HinemosUnknown 
 	 */
-	public static void notifyAction(OutputBasicInfo info, List<String> notifyIdList, boolean persist) {
+	public static void notifyAction(OutputBasicInfo info, List<String> notifyIdList, boolean persist) throws HinemosUnknown {
 		if(info == null || notifyIdList == null) {
 			m_log.info("notifyAction() invalid argument. info = " + info
 					+ ", notifyIdList = " + notifyIdList
@@ -104,75 +106,70 @@ public class NotifyDispatcher {
 					m_log.info("notifyAction() : notifyId = " + notifyId +" not found.");
 					continue;
 				}
-				try {
-					// 通知情報が「通知する」となっている場合
-					if (notifyValid == ValidConstant.TYPE_VALID) {
-						// デフォルトでは抑制せずに通知する（予期せぬエラーの場合は通知を行う）
-						boolean isNotify = notifyCheck(
-								info.getFacilityId(),
-								info.getPluginId(),
-								info.getMonitorId(),
-								info.getSubKey(),
+				// 通知情報が「通知する」となっている場合
+				if (notifyValid == ValidConstant.TYPE_VALID) {
+					// デフォルトでは抑制せずに通知する（予期せぬエラーの場合は通知を行う）
+					boolean isNotify = notifyCheck(
+							info.getFacilityId(),
+							info.getPluginId(),
+							info.getMonitorId(),
+							info.getSubKey(),
+							notifyId,
+							info.getPriority(),
+							outputDate,
+							prioityChangeFlag,
+							_mode);
+
+					if(isNotify){
+						// 通知出力情報をディープコピーする（AsyncWorkerPlugin.addTaskのため）
+						OutputBasicInfo clonedInfo = info.clone();
+						
+						// Ignore Invalid XML Chars
+						clonedInfo.setMessage(XMLUtil.ignoreInvalidString(clonedInfo.getMessage()));
+						clonedInfo.setMessageOrg(XMLUtil.ignoreInvalidString(clonedInfo.getMessageOrg()));
+						
+						// 通知IDは設定されていないため、ここで設定する
+						// TODO queueDeliveryMode
+						NotifyRequestMessage msg = new NotifyRequestMessage(
+								clonedInfo,
 								notifyId,
-								info.getPriority(),
 								outputDate,
-								prioityChangeFlag,
-								_mode);
+								prioityChangeFlag
+								);
+						
+						m_log.debug("add notify task for sending message"
+								+ " : notifyId=" + notifyId
+								+ ", pluginId=" + clonedInfo.getPluginId()
+								+ ", priority=" + clonedInfo.getPriority()
+								+ ", generationDate=" + clonedInfo.getGenerationDate()
+								+ ", monitorId=" + clonedInfo.getMonitorId()
+								+ ", facilityId=" + clonedInfo.getFacilityId());
 
-						if(isNotify){
-							// 通知出力情報をディープコピーする（AsyncWorkerPlugin.addTaskのため）
-							OutputBasicInfo clonedInfo = info.clone();
-							
-							// Ignore Invalid XML Chars
-							clonedInfo.setMessage(XMLUtil.ignoreInvalidString(clonedInfo.getMessage()));
-							clonedInfo.setMessageOrg(XMLUtil.ignoreInvalidString(clonedInfo.getMessageOrg()));
-							
-							// 通知IDは設定されていないため、ここで設定する
-							// TODO queueDeliveryMode
-							NotifyRequestMessage msg = new NotifyRequestMessage(
-									clonedInfo,
-									notifyId,
-									outputDate,
-									prioityChangeFlag
-									);
-							
-							m_log.debug("add notify task for sending message"
-									+ " : notifyId=" + notifyId
-									+ ", pluginId=" + clonedInfo.getPluginId()
-									+ ", priority=" + clonedInfo.getPriority()
-									+ ", generationDate=" + clonedInfo.getGenerationDate()
-									+ ", monitorId=" + clonedInfo.getMonitorId()
-									+ ", facilityId=" + clonedInfo.getFacilityId());
-
-							switch (notifyType) {
-							case NotifyTypeConstant.TYPE_STATUS :
-								AsyncWorkerPlugin.addTask(NotifyStatusTaskFactory.class.getSimpleName(), msg, persist);
-								break;
-							case NotifyTypeConstant.TYPE_EVENT :
-								AsyncWorkerPlugin.addTask(NotifyEventTaskFactory.class.getSimpleName(), msg, persist);
-								break;
-							case NotifyTypeConstant.TYPE_MAIL :
-								AsyncWorkerPlugin.addTask(NotifyMailTaskFactory.class.getSimpleName(), msg, persist);
-								break;
-							case NotifyTypeConstant.TYPE_COMMAND :
-								AsyncWorkerPlugin.addTask(NotifyCommandTaskFactory.class.getSimpleName(), msg, persist);
-								break;
-							case NotifyTypeConstant.TYPE_LOG_ESCALATE :
-								AsyncWorkerPlugin.addTask(NotifyLogEscalationTaskFactory.class.getSimpleName(), msg, persist);
-								break;
-							case NotifyTypeConstant.TYPE_JOB :
-								AsyncWorkerPlugin.addTask(NotifyJobTaskFactory.class.getSimpleName(), msg, persist);
-								break;
-							default :
-								m_log.warn("notify type is invalid. (notifyType = " + notifyType + ")");
-							}
+						switch (notifyType) {
+						case NotifyTypeConstant.TYPE_STATUS :
+							AsyncWorkerPlugin.addTask(NotifyStatusTaskFactory.class.getSimpleName(), msg, persist);
+							break;
+						case NotifyTypeConstant.TYPE_EVENT :
+							AsyncWorkerPlugin.addTask(NotifyEventTaskFactory.class.getSimpleName(), msg, persist);
+							break;
+						case NotifyTypeConstant.TYPE_MAIL :
+							AsyncWorkerPlugin.addTask(NotifyMailTaskFactory.class.getSimpleName(), msg, persist);
+							break;
+						case NotifyTypeConstant.TYPE_COMMAND :
+							AsyncWorkerPlugin.addTask(NotifyCommandTaskFactory.class.getSimpleName(), msg, persist);
+							break;
+						case NotifyTypeConstant.TYPE_LOG_ESCALATE :
+							AsyncWorkerPlugin.addTask(NotifyLogEscalationTaskFactory.class.getSimpleName(), msg, persist);
+							break;
+						case NotifyTypeConstant.TYPE_JOB :
+							AsyncWorkerPlugin.addTask(NotifyJobTaskFactory.class.getSimpleName(), msg, persist);
+							break;
+						default :
+							m_log.warn("notify type is invalid. (notifyType = " + notifyType + ")");
 						}
-					} else {
-						// TODO:通知しない場合は、キャッシュ情報をアップデートしたほうが良い
 					}
-				} catch (Exception e) {
-					m_log.warn("notifyAction() : " + info + " : "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				} else {
+					// TODO:通知しない場合は、キャッシュ情報をアップデートしたほうが良い
 				}
 			}
 		}
@@ -235,7 +232,6 @@ public class NotifyDispatcher {
 						} catch (NotifyNotFound e) {
 						}
 						if (entity != null) {
-							entity.unchain();	// 削除前処理
 							em.remove(entity);
 						}
 					} catch (Exception e) {
