@@ -22,6 +22,7 @@ import javax.persistence.EntityManager;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
@@ -62,7 +63,7 @@ public class DeleteMailTemplate {
 		// メールテンプレート情報を検索し取得
 		MailTemplateInfoEntity entity = null;
 		try {
-			entity = QueryUtil.getMailTemplateInfoPK(mailTemplateId);
+			entity = QueryUtil.getMailTemplateInfoPK(mailTemplateId, ObjectPrivilegeMode.WRITE);
 		} catch (MailTemplateNotFound e) {
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
