@@ -27,13 +27,12 @@ import org.eclipse.ui.IViewActionDelegate;
 import org.eclipse.ui.IViewPart;
 
 import com.clustercontrol.monitor.action.NotifyTableDefineNoCheckBox;
-import com.clustercontrol.monitor.composite.NotifyListComposite;
+import com.clustercontrol.notify.composite.NotifyListComposite;
 import com.clustercontrol.notify.util.NotifyEndpointWrapper;
 import com.clustercontrol.notify.view.NotifyListView;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.notify.InvalidRole_Exception;
 
-
 /**
  * 通知[一覧]ビューの無効アクションクラス<BR>
  * 
@@ -98,14 +97,14 @@ public class NotifyDisableAction implements IViewActionDelegate {
 			return;
 		}
 
-		boolean hasRole = true; //設定権限を持っているかどうか
+		boolean hasRole = true;
 		// 実行
 		for(String targetId : targetIdList){
 
 			try{
 				NotifyEndpointWrapper.setNotifyStatus(targetId, false);
 				successList.append(targetId + "\n");
-			}catch (InvalidRole_Exception e) {
+			} catch (InvalidRole_Exception e) {
 				failureList.append(targetId + "\n");
 				m_log.warn("run() setNotifyStatus targetId=" + targetId + ", " + e.getMessage(), e);
 				hasRole = false;
@@ -120,7 +119,7 @@ public class NotifyDisableAction implements IViewActionDelegate {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
 		}
-		
+
 		// 成功ダイアログ
 		if(successList.length() != 0){
 			args = new String[]{ successList.toString() } ;
