@@ -31,11 +31,12 @@ import org.eclipse.swt.widgets.Table;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.StatusConstant;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.performance.action.GetPerformanceListTableDefine;
+import com.clustercontrol.performance.composite.action.PerformanceListDoubleClickListener;
 import com.clustercontrol.performance.util.CollectorEndpointWrapper;
 import com.clustercontrol.performance.util.PerformanceFilterPropertyUtil;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.collector.HinemosUnknown_Exception;
 import com.clustercontrol.ws.collector.InvalidRole_Exception;
 import com.clustercontrol.ws.collector.PerformanceFilterInfo;
@@ -123,6 +124,9 @@ public class PerformanceListComposite extends Composite{
 				GetPerformanceListTableDefine.SORT_COLUMN_INDEX,
 				GetPerformanceListTableDefine.SORT_ORDER);
 
+		// ダブルクリックリスナの追加
+		this.tableViewer.addDoubleClickListener(new PerformanceListDoubleClickListener(this));
+
 		// 合計ラベルの作成
 		this.totalLabel = new Label(this, SWT.RIGHT);
 		gridData = new GridData();
@@ -245,6 +249,15 @@ public class PerformanceListComposite extends Composite{
 		return this.tableViewer;
 	}
 
+	/**
+	 * このコンポジットが利用するテーブルを返します。
+	 * 
+	 * @return テーブル
+	 */
+	public Table getTable() {
+		return this.tableViewer.getTable();
+	}
+
 	/**
 	 * コンポジットを更新します。
 	 * <p>
