@@ -121,12 +121,12 @@ implements IWorkbenchPreferencePage {
 	/**
 	 * 設定内容を反映します。
 	 */
-	protected void applySetting() {
+	private void applySetting() {
 		log.debug("applySetting()");
 		IPreferenceStore store = this.getPreferenceStore();
 
 		IWorkbenchPage page = PlatformUI.getWorkbench()
-		.getActiveWorkbenchWindow().getActivePage();
+				.getActiveWorkbenchWindow().getActivePage();
 
 		int max = store.getInt(P_GRAPH_MAX);
 		PerformanceGraphView.setGraphMax(max);
