@@ -22,8 +22,6 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
-import org.eclipse.ui.IWorkbenchPage;
-import org.eclipse.ui.PlatformUI;
 import org.jfree.chart.JFreeChart;
 
 import com.clustercontrol.ClusterControlPlugin;
@@ -78,10 +76,8 @@ public class PerformanceGraphView extends ScopeListBaseView {
 
 		super.getScopeTreeComposite().setScopeTree(null);
 
-		// 性能[一覧]ビューで選択されているIDを元に、ビュー名をセット
-		IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
-		PerformanceListView listView = (PerformanceListView) page.findView(PerformanceListView.ID);
-		this.monitorId = listView.getSelectedMonitorId();
+		// セカンダリIDとして登録した監視IDを元に、ビュー名をセット
+		this.monitorId = this.getViewSite().getSecondaryId();
 		String args[] = {this.monitorId};
 		this.setPartName(Messages.getString("view.performance.graph", args));
 
