@@ -40,8 +40,11 @@ public class GetScopeListTableDefine {
 	/** 注釈 */
 	public static final int DESCRIPTION = 2;
 
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 3;
+
 	/** ソート用データ**/
-	public static final int SORT_VALUE=3;
+	public static final int SORT_VALUE=4;
 
 	/** 初期表示時ソートカラム */
 	//public static final int SORT_COLUMN_INDEX = FACILITY_ID;
@@ -76,6 +79,8 @@ public class GetScopeListTableDefine {
 				new TableColumnInfo(Messages.getString("facility.name", locale), TableColumnInfo.FACILITY_NAME, 150, SWT.LEFT));
 		tableDefine.add(DESCRIPTION,
 				new TableColumnInfo(Messages.getString("description", locale), TableColumnInfo.NONE, 200, SWT.LEFT));
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
 
 		return tableDefine;
 
