@@ -65,14 +65,14 @@ public class FacilityTreeSelectionChangedListener implements ISelectionChangedLi
 
 		// リポジトリ[登録]ビューのインスタンスを取得
 		IWorkbenchPage page = PlatformUI.getWorkbench()
-		.getActiveWorkbenchWindow().getActivePage();
+				.getActiveWorkbenchWindow().getActivePage();
 		IViewPart viewPart = page.findView(ScopeListView.ID);
 
 		if (viewPart != null && selectItem instanceof FacilityTreeItem) {
 			ScopeListView view = (ScopeListView) viewPart.getAdapter(ScopeListView.class);
 
 			// ビューのアクションの有効/無効を設定
-			view.setEnabledAction(selectItem.getData().isBuiltInFlg(),selectItem.getData().getFacilityType(), event.getSelection());
+			view.setEnabledAction(selectItem.getData().isBuiltInFlg(),selectItem.getData().getFacilityType(), event.getSelection(), selectItem.getData().isNotReferFlg());
 		}
 
 	}
