@@ -32,7 +32,7 @@ import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
-import com.clustercontrol.action.FacilityTree;
+import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.repository.composite.NodeFilterComposite;
@@ -115,7 +115,7 @@ public class NodeAssignDialog extends CommonDialog {
 		 */
 
 		// テーブル
-		this.nodeList = new NodeFilterComposite(parent, SWT.NONE);
+		this.nodeList = new NodeFilterComposite(parent, SWT.NONE, facilityId, true);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -228,7 +228,7 @@ public class NodeAssignDialog extends CommonDialog {
 
 		// 画面情報を取得
 		StructuredSelection selection = (StructuredSelection) this.nodeList
-		.getTableViewer().getSelection();
+				.getTableViewer().getSelection();
 
 		Object[] items = selection.toArray();
 		if (items != null) {
@@ -244,7 +244,7 @@ public class NodeAssignDialog extends CommonDialog {
 			RepositoryEndpointWrapper.assignNodeScope(facilityId, this.filterItems);
 
 			// リポジトリキャッシュの更新
-			FacilityTree.reflesh();
+			LocalSession.doCheck();
 
 			// 成功報告ダイアログを生成
 			MessageDialog.openInformation(
