@@ -29,12 +29,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.repository.action.GetNodeFilterProperty;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * ノード検索ダイアログクラス<BR>
@@ -122,6 +122,7 @@ public class NodeFilterDialog extends CommonDialog {
 			filterProperty = new GetNodeFilterProperty().getProperty();
 		}
 		this.propertySheet.setInput(filterProperty);
+		this.propertySheet.expandAll();
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
