@@ -16,13 +16,8 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.repository.factory;
 
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.concurrent.ConcurrentHashMap;
 
-import javax.ejb.EJBException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -37,18 +32,19 @@ import com.clustercontrol.repository.bean.NodeMemoryInfo;
 import com.clustercontrol.repository.bean.NodeNetworkInterfaceInfo;
 import com.clustercontrol.repository.bean.NodeNoteInfo;
 import com.clustercontrol.repository.bean.NodeVariableInfo;
-import com.clustercontrol.repository.ejb.entity.FacilityLocal;
-import com.clustercontrol.repository.ejb.entity.NodeCpuLocal;
-import com.clustercontrol.repository.ejb.entity.NodeDeviceLocal;
-import com.clustercontrol.repository.ejb.entity.NodeDiskLocal;
-import com.clustercontrol.repository.ejb.entity.NodeFilesystemLocal;
-import com.clustercontrol.repository.ejb.entity.NodeHostnameLocal;
-import com.clustercontrol.repository.ejb.entity.NodeLocal;
-import com.clustercontrol.repository.ejb.entity.NodeMemoryLocal;
-import com.clustercontrol.repository.ejb.entity.NodeNetworkInterfaceLocal;
-import com.clustercontrol.repository.ejb.entity.NodeNoteLocal;
-import com.clustercontrol.repository.ejb.entity.NodeUtil;
-import com.clustercontrol.repository.ejb.entity.NodeVariableLocal;
+import com.clustercontrol.repository.model.FacilityEntity;
+import com.clustercontrol.repository.model.NodeCpuEntity;
+import com.clustercontrol.repository.model.NodeDeviceEntity;
+import com.clustercontrol.repository.model.NodeDiskEntity;
+import com.clustercontrol.repository.model.NodeEntity;
+import com.clustercontrol.repository.model.NodeFilesystemEntity;
+import com.clustercontrol.repository.model.NodeHostnameEntity;
+import com.clustercontrol.repository.model.NodeMemoryEntity;
+import com.clustercontrol.repository.model.NodeNetworkInterfaceEntity;
+import com.clustercontrol.repository.model.NodeNoteEntity;
+import com.clustercontrol.repository.model.NodeVariableEntity;
+import com.clustercontrol.repository.util.FacilityUtil;
+import com.clustercontrol.repository.util.QueryUtil;
 
 /**
  * ノード用プロパティを作成するクラス<BR>
@@ -64,7 +60,7 @@ public class NodeProperty {
 
 	private static Object nodeLock = new Object();
 	private static ConcurrentHashMap<String, NodeInfo> nodeCache =
-		new ConcurrentHashMap<String, NodeInfo>();
+			new ConcurrentHashMap<String, NodeInfo>();
 
 	public static void removeNode (String facilityId) {
 		m_log.info("remove NodeCache : " + facilityId);
@@ -87,16 +83,15 @@ public class NodeProperty {
 	 * @param mode ノード情報扱い種別（参照、追加、変更）
 	 * @return ノード情報
 	 * @throws FacilityNotFound
-	 * @throws FinderException
-	 * @throws NamingException
 	 */
 	public static NodeInfo getProperty(String facilityId) throws FacilityNotFound {
+
 		m_log.debug("getProperty() : facilityId = " + facilityId);
 
 		/** ローカル変数 */
 		NodeInfo property = null;
-		NodeLocal node = null;
-		FacilityLocal facility = null;
+		NodeEntity node = null;
+		FacilityEntity facility = null;
 
 		/** メイン処理 */
 		if (facilityId == null || facilityId.compareTo("") == 0) {
@@ -110,17 +105,16 @@ public class NodeProperty {
 			} else {
 				property = new NodeInfo();
 			}
-			
-			try {
-				node = NodeUtil.getLocalHome().findByPrimaryKey(facilityId);
-				facility = node.getFacility();
-			} catch (FinderException e) {
-				throw new FacilityNotFound(e);
 
-			} catch (Exception e) {
-				m_log.warn("failure to get node's properties. (facilityId = " + facilityId + ")", e);
-				throw new EJBException("failure to get node's properties. (facilityId = " + facilityId + ")", e);
+			facility = QueryUtil.getFacilityPK_NONE(facilityId);
+			// ファシリティがノードかどうかを確認する
+			if (!FacilityUtil.isNode(facility)) {
+				FacilityNotFound e = new FacilityNotFound("this facility is not a node. (facilityId = " + facilityId + ")");
+				m_log.info("getProperty() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
 			}
+			node = facility.getNodeEntity();
 
 			// ----- ファシリティ関連 -----
 			// ファシリティID
@@ -130,7 +124,11 @@ public class NodeProperty {
 			// 説明
 			property.setDescription(facility.getDescription());
 			// 有効/無効
-			property.setValid(facility.isValid());
+			property.setValid(FacilityUtil.isValid(facility));
+			// アイコン名
+			property.setIconImage(facility.getIconImage());
+			// オーナーロールID
+			property.setOwnerRoleId(facility.getOwnerRoleId());
 			// 登録ユーザID
 			property.setCreateUserId(facility.getCreateUserId());
 			// 登録日時
@@ -151,10 +149,12 @@ public class NodeProperty {
 			// ----- HW -----
 			// プラットフォーム
 			property.setPlatformFamily(node.getPlatformFamily());
+			// サブプラットフォーム
+			property.setSubPlatformFamily(node.getSubPlatformFamily());
 			// H/Wタイプ
 			property.setHardwareType(node.getHardwareType());
 			// 画面アイコンイメージ
-			property.setIconImage(node.getIconImage());
+			property.setIconImage(facility.getIconImage());
 
 			// ----- IPアドレス関連 -----
 			// IPバージョン
@@ -167,10 +167,10 @@ public class NodeProperty {
 			property.setIpAddressV6(node.getIpAddressV6());
 			// ホスト名
 			ArrayList<NodeHostnameInfo> hostnameList = new ArrayList<NodeHostnameInfo>();
-			if (node.getNodeHostname() != null) {
-				for (NodeHostnameLocal nodeHostname : (Collection<NodeHostnameLocal>)node.getNodeHostname()) {
+			if (node.getNodeHostnameEntities() != null) {
+				for (NodeHostnameEntity nodeHostname : node.getNodeHostnameEntities()) {
 					// ホスト名
-					hostnameList.add(new NodeHostnameInfo(nodeHostname.getHostname()));
+					hostnameList.add(new NodeHostnameInfo(nodeHostname.getId().getHostname()));
 				}
 			}
 			property.setNodeHostnameInfo(hostnameList);
@@ -187,6 +187,23 @@ public class NodeProperty {
 			// 文字セット
 			property.setCharacterSet(node.getCharacterSet());
 
+			// ----- Hinemosエージェント関連 -----
+			// 即時反映用ポート番号
+			if (node.getAgentAwakePort() != -1) {
+				property.setAgentAwakePort(node.getAgentAwakePort());
+			}
+
+			// ----- ジョブ -----
+			// ジョブ優先度
+			if (node.getJobPriority() != -1) {
+				property.setJobPriority(node.getJobPriority());
+			}
+			// ジョブ多重度
+			if (node.getJobMultiplicity() != -1) {
+				property.setJobMultiplicity(node.getJobMultiplicity());
+			}
+
+
 			// ----- サービス -----
 
 			// ----- SNMP関連 -----
@@ -277,26 +294,24 @@ public class NodeProperty {
 
 			// ----- 汎用デバイス情報 -----
 			ArrayList<NodeDeviceInfo> deviceList = new ArrayList<NodeDeviceInfo>();
-			if (node.getNodeDevice() != null) {
-				int cnt = 0;
-				for (NodeDeviceLocal nodeDevice : (Collection<NodeDeviceLocal>)node.getNodeDevice()) {
+			if (node.getNodeDeviceEntities() != null) {
+				for (NodeDeviceEntity nodeDevice : node.getNodeDeviceEntities()) {
 					NodeDeviceInfo device = new NodeDeviceInfo();
 
 					// デバイス種別
-					device.setDeviceType(nodeDevice.getDeviceType());
+					device.setDeviceType(nodeDevice.getId().getDeviceType());
 					// デバイス表示名
 					device.setDeviceDisplayName(nodeDevice.getDeviceDisplayName());
 					// デバイスINDEX
-					device.setDeviceIndex(nodeDevice.getDeviceIndex());
+					device.setDeviceIndex(nodeDevice.getId().getDeviceIndex());
 					// デバイス名
-					device.setDeviceName(nodeDevice.getDeviceName());
+					device.setDeviceName(nodeDevice.getId().getDeviceName());
 					// デバイスサイズ
 					device.setDeviceSize(nodeDevice.getDeviceSize());
 					// デバイスサイズ単位
 					device.setDeviceSizeUnit(nodeDevice.getDeviceSizeUnit());
 					// 説明
 					device.setDeviceDescription(nodeDevice.getDeviceDescription());
-					cnt++;
 					deviceList.add(device);
 				}
 			}
@@ -304,26 +319,24 @@ public class NodeProperty {
 
 			// ----- CPUデバイス情報 -----
 			ArrayList<NodeCpuInfo> cpuList = new ArrayList<NodeCpuInfo>();
-			if (node.getNodeCpu() != null) {
-				int cnt = 0;
-				for(NodeCpuLocal nodeCpu : (Collection<NodeCpuLocal>)node.getNodeCpu()){
+			if (node.getNodeCpuEntities() != null) {
+				for(NodeCpuEntity nodeCpu : node.getNodeCpuEntities()){
 					NodeCpuInfo cpu = new NodeCpuInfo();
 
 					// デバイス種別
-					cpu.setDeviceType(nodeCpu.getDeviceType());
+					cpu.setDeviceType(nodeCpu.getId().getDeviceType());
 					// デバイス表示名
 					cpu.setDeviceDisplayName(nodeCpu.getDeviceDisplayName());
 					// デバイスINDEX
-					cpu.setDeviceIndex(nodeCpu.getDeviceIndex());
+					cpu.setDeviceIndex(nodeCpu.getId().getDeviceIndex());
 					// デバイス名
-					cpu.setDeviceName(nodeCpu.getDeviceName());
+					cpu.setDeviceName(nodeCpu.getId().getDeviceName());
 					// デバイスサイズ
 					cpu.setDeviceSize(nodeCpu.getDeviceSize());
 					// デバイスサイズ単位
 					cpu.setDeviceSizeUnit(nodeCpu.getDeviceSizeUnit());
 					// 説明
 					cpu.setDeviceDescription(nodeCpu.getDeviceDescription());
-					cnt++;
 					cpuList.add(cpu);
 				}
 			}
@@ -331,26 +344,24 @@ public class NodeProperty {
 
 			// ----- MEMデバイス情報 -----
 			ArrayList<NodeMemoryInfo> memList = new ArrayList<NodeMemoryInfo>();
-			if (node.getNodeMemory() != null) {
-				int cnt = 0;
-				for(NodeMemoryLocal nodeMem : (Collection<NodeMemoryLocal>)node.getNodeMemory()){
+			if (node.getNodeMemoryEntities() != null) {
+				for(NodeMemoryEntity nodeMem : node.getNodeMemoryEntities()){
 					NodeMemoryInfo mem = new NodeMemoryInfo();
 
 					// デバイス種別
-					mem.setDeviceType(nodeMem.getDeviceType());
+					mem.setDeviceType(nodeMem.getId().getDeviceType());
 					// デバイス表示名
 					mem.setDeviceDisplayName(nodeMem.getDeviceDisplayName());
 					// デバイスINDEX
-					mem.setDeviceIndex(nodeMem.getDeviceIndex());
+					mem.setDeviceIndex(nodeMem.getId().getDeviceIndex());
 					// デバイス名
-					mem.setDeviceName(nodeMem.getDeviceName());
+					mem.setDeviceName(nodeMem.getId().getDeviceName());
 					// デバイスサイズ
 					mem.setDeviceSize(nodeMem.getDeviceSize());
 					// デバイスサイズ単位
 					mem.setDeviceSizeUnit(nodeMem.getDeviceSizeUnit());
 					// 説明
 					mem.setDeviceDescription(nodeMem.getDeviceDescription());
-					cnt++;
 					memList.add(mem);
 				}
 			}
@@ -358,19 +369,18 @@ public class NodeProperty {
 
 			// ----- NICデバイス情報 -----
 			ArrayList<NodeNetworkInterfaceInfo> nicList = new ArrayList<NodeNetworkInterfaceInfo>();
-			if (node.getNodeNetworkInterface() != null) {
-				int cnt = 0;
-				for(NodeNetworkInterfaceLocal nodeNic : (Collection<NodeNetworkInterfaceLocal>)node.getNodeNetworkInterface()){
+			if (node.getNodeNetworkInterfaceEntities() != null) {
+				for(NodeNetworkInterfaceEntity nodeNic : node.getNodeNetworkInterfaceEntities()){
 					NodeNetworkInterfaceInfo nic = new NodeNetworkInterfaceInfo();
 
 					// デバイス種別
-					nic.setDeviceType(nodeNic.getDeviceType());
+					nic.setDeviceType(nodeNic.getId().getDeviceType());
 					// デバイス表示名
 					nic.setDeviceDisplayName(nodeNic.getDeviceDisplayName());
 					// デバイスINDEX
-					nic.setDeviceIndex(nodeNic.getDeviceIndex());
+					nic.setDeviceIndex(nodeNic.getId().getDeviceIndex());
 					// デバイス名
-					nic.setDeviceName(nodeNic.getDeviceName());
+					nic.setDeviceName(nodeNic.getId().getDeviceName());
 					// デバイスサイズ
 					nic.setDeviceSize(nodeNic.getDeviceSize());
 					// デバイスサイズ単位
@@ -381,7 +391,6 @@ public class NodeProperty {
 					nic.setNicIpAddress(nodeNic.getDeviceNicIpAddress());
 					// NIC MAC
 					nic.setNicMacAddress(nodeNic.getDeviceNicMacAddress());
-					cnt++;
 					nicList.add(nic);
 				}
 			}
@@ -389,19 +398,18 @@ public class NodeProperty {
 
 			// ----- DISKデバイス情報 -----
 			ArrayList<NodeDiskInfo> diskList = new ArrayList<NodeDiskInfo>();
-			if (node.getNodeDisk() != null) {
-				int cnt = 0;
-				for(NodeDiskLocal nodeDisk : (Collection<NodeDiskLocal>)node.getNodeDisk()){
+			if (node.getNodeDiskEntities() != null) {
+				for(NodeDiskEntity nodeDisk : node.getNodeDiskEntities()){
 					NodeDiskInfo disk = new NodeDiskInfo();
 
 					// デバイス種別
-					disk.setDeviceType(nodeDisk.getDeviceType());
+					disk.setDeviceType(nodeDisk.getId().getDeviceType());
 					// デバイス表示名
 					disk.setDeviceDisplayName(nodeDisk.getDeviceDisplayName());
 					// デバイスINDEX
-					disk.setDeviceIndex(nodeDisk.getDeviceIndex());
+					disk.setDeviceIndex(nodeDisk.getId().getDeviceIndex());
 					// デバイス名
-					disk.setDeviceName(nodeDisk.getDeviceName());
+					disk.setDeviceName(nodeDisk.getId().getDeviceName());
 					// デバイスサイズ
 					disk.setDeviceSize(nodeDisk.getDeviceSize());
 					// デバイスサイズ単位
@@ -410,7 +418,6 @@ public class NodeProperty {
 					disk.setDeviceDescription(nodeDisk.getDeviceDescription());
 					// 回転数
 					disk.setDiskRpm(nodeDisk.getDeviceDiskRpm());
-					cnt++;
 					diskList.add(disk);
 				}
 			}
@@ -418,19 +425,18 @@ public class NodeProperty {
 
 			// ---- ファイルシステム情報 -----
 			ArrayList<NodeFilesystemInfo> filesystemList = new ArrayList<NodeFilesystemInfo>();
-			if (node.getNodeFilesystem() != null) {
-				int cnt = 0;
-				for (NodeFilesystemLocal nodeFilesystem : (Collection<NodeFilesystemLocal>)node.getNodeFilesystem()) {
+			if (node.getNodeFilesystemEntities() != null) {
+				for (NodeFilesystemEntity nodeFilesystem : node.getNodeFilesystemEntities()) {
 					NodeFilesystemInfo filesystem = new NodeFilesystemInfo();
 
 					// デバイス種別
-					filesystem.setDeviceType(nodeFilesystem.getDeviceType());
+					filesystem.setDeviceType(nodeFilesystem.getId().getDeviceType());
 					// デバイス表示名
 					filesystem.setDeviceDisplayName(nodeFilesystem.getDeviceDisplayName());
 					// デバイスINDEX
-					filesystem.setDeviceIndex(nodeFilesystem.getDeviceIndex());
+					filesystem.setDeviceIndex(nodeFilesystem.getId().getDeviceIndex());
 					// デバイス名
-					filesystem.setDeviceName(nodeFilesystem.getDeviceName());
+					filesystem.setDeviceName(nodeFilesystem.getId().getDeviceName());
 					// デバイスサイズ
 					filesystem.setDeviceSize(nodeFilesystem.getDeviceSize());
 					// デバイスサイズ単位
@@ -439,7 +445,6 @@ public class NodeProperty {
 					filesystem.setDeviceDescription(nodeFilesystem.getDeviceDescription());
 					// ファイルシステム種別
 					filesystem.setFilesystemType(nodeFilesystem.getDeviceFilesystemType());
-					cnt++;
 					filesystemList.add(filesystem);
 				}
 			}
@@ -447,17 +452,11 @@ public class NodeProperty {
 
 			// ----- サーバ仮想化関連 -----
 			// 仮想化ノード種別
-			property.setVirtualizationNodeType(node.getVirtualizationNodeType());
+			property.setVmNodeType(node.getVmNodeType());
 			// 仮想マシン管理ノード
 			property.setVmManagementNode(node.getVmManagementNode());
-			// 仮想マシンINDEX
-			if (node.getVmIndex() != -1) {
-				property.setVmIndex(node.getVmIndex());
-			}
 			// 仮想マシン名
 			property.setVmName(node.getVmName());
-			// 仮想化ソリューション
-			property.setVirtualizationSolution(node.getVirtualizationSolution());
 			// 仮想マシンID
 			property.setVmId(node.getVmId());
 			// 仮想化ソフト接続ユーザ
@@ -469,26 +468,40 @@ public class NodeProperty {
 
 			// ----- ネットワーク仮想化関連 -----
 			// 仮想スイッチ種別
-			property.setvNetSwitchType(node.getVNetSwitchType());
+			property.setvNetSwitchType(node.getVnetSwitchType());
 			// 仮想スイッチホストノード
-			property.setvNetHostNode(node.getVNetHostNode());
+			property.setvNetHostNode(node.getVnetHostNode());
 			// OpenFlow データパスID
-			property.setOpenFlowDataPathId(node.getOpenFlowDatapathId());
+			property.setOpenFlowDataPathId(node.getOpenflowDataPathId());
 			// OpenFlow コントローラIPアドレス
-			property.setOpenFlowCtrlIpAddress(node.getOpenFlowCtrlIpAddress());
+			property.setOpenFlowCtrlIpAddress(node.getOpenflowCtrlIpAddress());
+
+			// ----- クラウド関連 -----
+			// クラウドノード種別
+			property.setCloudNodeType(node.getCloudNodeType());
+			// クラウドサービス
+			property.setCloudService(node.getCloudService());
+			// クラウドアカウントリソース
+			property.setCloudAccountResouce(node.getCloudAccountResouce());
+			// クラウドリソースタイプ
+			property.setCloudResourceType(node.getCloudResourceType());
+			// クラウドリソースID
+			property.setCloudResourceId(node.getCloudResourceId());
+			// クラウドリージョン
+			property.setCloudRegion(node.getCloudRegion());
+			// クラウドゾーン
+			property.setCloudZone(node.getCloudZone());
 
 			// ----- 	ノード変数 -----
 			ArrayList<NodeVariableInfo> nodeVariableList = new ArrayList<NodeVariableInfo>();
-			if (node.getNodeVariable() != null) {
-				int cnt = 0;
-				for (NodeVariableLocal nodeVariable : (Collection<NodeVariableLocal>)node.getNodeVariable()) {
+			if (node.getNodeVariableEntities() != null) {
+				for (NodeVariableEntity nodeVariable : node.getNodeVariableEntities()) {
 					NodeVariableInfo variable = new NodeVariableInfo();
 
 					// ノード変数名
-					variable.setNodeVariableName(nodeVariable.getNodeVariableName());
+					variable.setNodeVariableName(nodeVariable.getId().getNodeVariableName());
 					// ノード変数値
 					variable.setNodeVariableValue(nodeVariable.getNodeVariableValue());
-					cnt++;
 					nodeVariableList.add(variable);
 				}
 			}
@@ -503,9 +516,9 @@ public class NodeProperty {
 
 			// ----- 備考 -----
 			ArrayList<NodeNoteInfo> noteList = new ArrayList<NodeNoteInfo>();
-			if (node.getNodeNote() != null) {
+			if (node.getNodeNoteEntities() != null) {
 				int cnt = 0;
-				for (NodeNoteLocal nodeNote : (Collection<NodeNoteLocal>)node.getNodeNote()) {
+				for (NodeNoteEntity nodeNote : node.getNodeNoteEntities()) {
 					// 備考
 					noteList.add(new NodeNoteInfo(cnt, nodeNote.getNote()));
 					cnt++;
