@@ -15,16 +15,14 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.repository.factory;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.repository.bean.ScopeInfo;
-import com.clustercontrol.repository.ejb.entity.FacilityLocal;
-import com.clustercontrol.repository.ejb.entity.FacilityUtil;
+import com.clustercontrol.repository.model.FacilityEntity;
+import com.clustercontrol.repository.util.QueryUtil;
 
 
 /**
@@ -43,34 +41,65 @@ public class ScopeProperty {
 	 * @param facilityId
 	 * @param mode
 	 * @return スコープ用プロパティ
-	 * @throws NamingException
 	 * @throws FacilityNotFound
+	 * @throws InvalidRole
 	 */
-	public static ScopeInfo getProperty(String facilityId) throws NamingException, FacilityNotFound {
+	public static ScopeInfo getProperty(String facilityId) throws FacilityNotFound, InvalidRole {
+
 		ScopeInfo property = new ScopeInfo();
 
 		if(facilityId != null && facilityId.compareTo("") != 0){
 
 			//Facility取得
-			FacilityLocal facility;
-			try {
-				facility = FacilityUtil.getLocalHome().findByPrimaryKey(facilityId);
-			} catch (FinderException e) {
-				m_log.warn("getProperty " + e.getMessage(), e);
-				throw new FacilityNotFound(e.getMessage(), e);
-			}
-
-			if(facility != null){
-				//ファシリティID
-				property.setFacilityId(facility.getFacilityId());
-				//ファシリティ名
-				property.setFacilityName(facility.getFacilityName());
-				//説明
-				if(facility.getDescription() != null && facility.getDescription().compareTo("") != 0){
-					property.setDescription(facility.getDescription());
-				}
+			FacilityEntity facility = QueryUtil.getFacilityPK(facilityId);
 
+			//ファシリティID
+			property.setFacilityId(facility.getFacilityId());
+			//ファシリティ名
+			property.setFacilityName(facility.getFacilityName());
+			//説明
+			if(facility.getDescription() != null && facility.getDescription().compareTo("") != 0){
+				property.setDescription(facility.getDescription());
 			}
+			//アイコン
+			property.setIconImage(facility.getIconImage());
+			//オーナーロールID
+			property.setOwnerRoleId(facility.getOwnerRoleId());
+		}
+
+		return property;
+	}
+	
+	/**
+	 * オブジェクト権限のチェックなしでスコープ用プロパティを返します。
+	 * 
+	 * @param facilityId
+	 * @param mode
+	 * @return スコープ用プロパティ
+	 * @throws FacilityNotFound
+	 * @throws InvalidRole
+	 */
+	public static ScopeInfo getProperty_NONE(String facilityId) throws FacilityNotFound, InvalidRole {
+
+		ScopeInfo property = new ScopeInfo();
+
+		if(facilityId != null && facilityId.compareTo("") != 0){
+
+			//Facility取得
+			FacilityEntity facility = QueryUtil.getFacilityPK_NONE(facilityId);
+
+			//ファシリティID
+			property.setFacilityId(facility.getFacilityId());
+			//ファシリティ名
+			property.setFacilityName(facility.getFacilityName());
+			//説明
+			if(facility.getDescription() != null && facility.getDescription().compareTo("") != 0){
+				property.setDescription(facility.getDescription());
+			}
+			//アイコン
+			property.setIconImage(facility.getIconImage());
+			//オーナーロールID
+			property.setOwnerRoleId(facility.getOwnerRoleId());
 		}
 
 		return property;
