@@ -870,18 +870,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeCpuEntities(List<NodeCpuEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeCpuEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeCpuEntity> list = this.getNodeCpuEntities();
-			Iterator<NodeCpuEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeCpuEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeCpuEntity> list = this.getNodeCpuEntities();
+		Iterator<NodeCpuEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeCpuEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -893,18 +889,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeDeviceEntities(List<NodeDeviceEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeDeviceEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeDeviceEntity> list = this.getNodeDeviceEntities();
-			Iterator<NodeDeviceEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeDeviceEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeDeviceEntity> list = this.getNodeDeviceEntities();
+		Iterator<NodeDeviceEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeDeviceEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -916,18 +908,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeDiskEntities(List<NodeDiskEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeDiskEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeDiskEntity> list = this.getNodeDiskEntities();
-			Iterator<NodeDiskEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeDiskEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeDiskEntity> list = this.getNodeDiskEntities();
+		Iterator<NodeDiskEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeDiskEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -939,18 +927,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeFilesystemEntities(List<NodeFilesystemEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeFilesystemEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeFilesystemEntity> list = this.getNodeFilesystemEntities();
-			Iterator<NodeFilesystemEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeFilesystemEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeFilesystemEntity> list = this.getNodeFilesystemEntities();
+		Iterator<NodeFilesystemEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeFilesystemEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -962,18 +946,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeHostnameEntities(List<NodeHostnameEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeHostnameEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeHostnameEntity> list = this.getNodeHostnameEntities();
-			Iterator<NodeHostnameEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeHostnameEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeHostnameEntity> list = this.getNodeHostnameEntities();
+		Iterator<NodeHostnameEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeHostnameEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -985,18 +965,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeMemoryEntities(List<NodeMemoryEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeMemoryEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeMemoryEntity> list = this.getNodeMemoryEntities();
-			Iterator<NodeMemoryEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeMemoryEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeMemoryEntity> list = this.getNodeMemoryEntities();
+		Iterator<NodeMemoryEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeMemoryEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -1008,18 +984,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeNetworkInterfaceEntities(List<NodeNetworkInterfaceEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeNetworkInterfaceEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeNetworkInterfaceEntity> list = this.getNodeNetworkInterfaceEntities();
-			Iterator<NodeNetworkInterfaceEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeNetworkInterfaceEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeNetworkInterfaceEntity> list = this.getNodeNetworkInterfaceEntities();
+		Iterator<NodeNetworkInterfaceEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeNetworkInterfaceEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -1031,18 +1003,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeNoteEntities(List<NodeNoteEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeNoteEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeNoteEntity> list = this.getNodeNoteEntities();
-			Iterator<NodeNoteEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeNoteEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeNoteEntity> list = this.getNodeNoteEntities();
+		Iterator<NodeNoteEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeNoteEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
@@ -1054,18 +1022,14 @@ public class NodeEntity implements Serializable {
 	 * 
 	 */
 	public void deleteNodeVariableEntities(List<NodeVariableEntityPK> notDelPkList) {
-		if (notDelPkList == null || notDelPkList.size() == 0) {
-			this.setNodeVariableEntities(null);
-		} else {
-			EntityManager em = new JpaTransactionManager().getEntityManager();
-			List<NodeVariableEntity> list = this.getNodeVariableEntities();
-			Iterator<NodeVariableEntity> iter = list.iterator();
-			while(iter.hasNext()) {
-				NodeVariableEntity entity = iter.next();
-				if (!notDelPkList.contains(entity.getId())) {
-					iter.remove();
-					em.remove(entity);
-				}
+		EntityManager em = new JpaTransactionManager().getEntityManager();
+		List<NodeVariableEntity> list = this.getNodeVariableEntities();
+		Iterator<NodeVariableEntity> iter = list.iterator();
+		while(iter.hasNext()) {
+			NodeVariableEntity entity = iter.next();
+			if (!notDelPkList.contains(entity.getId())) {
+				iter.remove();
+				em.remove(entity);
 			}
 		}
 	}
