@@ -35,7 +35,7 @@ public class RepositoryUpdateTime {
 	/**
 	 * 更新時刻を更新する
 	 */
-	public static synchronized void refleshUpdateTime(){
+	public static synchronized void refreshUpdateTime(){
 		_updateTime = new Date(System.currentTimeMillis());
 	}
 
