@@ -28,10 +28,10 @@ import org.eclipse.ui.IWorkbenchPage;
 
 import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.bean.TableColumnInfo;
-import com.clustercontrol.composite.CommonTableViewer;
 import com.clustercontrol.repository.composite.NodeListComposite;
 import com.clustercontrol.repository.composite.NodeScopeComposite;
 import com.clustercontrol.view.CommonViewPart;
+import com.clustercontrol.viewer.CommonTableViewer;
 
 /**
  * ノードの割当スコープビュークラス<BR>
@@ -78,7 +78,7 @@ public class NodeScopeView extends CommonViewPart {
 	public void update() {
 		IWorkbench workbench = ClusterControlPlugin.getDefault().getWorkbench();
 		IWorkbenchPage page = workbench.getActiveWorkbenchWindow()
-		.getActivePage();
+				.getActivePage();
 
 		NodeListView view = null;
 		if (page != null) {
@@ -95,7 +95,7 @@ public class NodeScopeView extends CommonViewPart {
 			CommonTableViewer viewer = composite.getTableViewer();
 
 			StructuredSelection selection = (StructuredSelection) viewer
-			.getSelection();
+					.getSelection();
 
 			ArrayList list = (ArrayList) selection.getFirstElement();
 			if (list != null) {
