@@ -15,18 +15,18 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.selfcheck.monitor;
 
-import com.clustercontrol.notify.bean.OutputBasicInfo;
-
 /**
  * セルフチェック機能の処理実装インターフェース
  */
 public interface SelfCheckMonitor {
 
-	public OutputBasicInfo execute();
+	public void execute();
 
 	@Override
 	public String toString();
 
 	public String getMonitorId();
 
+	public String getSubKey();
+
 }
