@@ -40,12 +40,12 @@ import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
-import com.clustercontrol.composite.CommonTableViewer;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.snmptrap.action.GetMaster;
 import com.clustercontrol.snmptrap.action.GetMasterTableDefine;
 import com.clustercontrol.snmptrap.util.MonitorSnmpTrapEndpointWrapper;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorTrapValueInfo;
 import com.clustercontrol.ws.monitor.SnmpTrapMasterInfo;
@@ -356,7 +356,7 @@ public class MasterListComposite extends Composite {
 
 		//選択されたアイテムを取得
 		StructuredSelection selection =
-			(StructuredSelection)tableViewer.getSelection();
+				(StructuredSelection)tableViewer.getSelection();
 		List list = selection.toList();
 
 		if (list != null) {
