@@ -202,6 +202,7 @@ public class SnmpTrapMonitor implements SnmpTrapHandler {
 		public void run() {
 
 			JpaTransactionManager tm = null;
+			boolean warn = true;
 
 			try {
 				tm = new JpaTransactionManager();
@@ -271,29 +272,32 @@ public class SnmpTrapMonitor implements SnmpTrapHandler {
 					}
 
 					List<SnmpVarbind> varbinds = snmptrap.getVarbinds();
-					String[] varbind = new String[varbinds.size()];
-					for (int i = 0; i < varbinds.size(); i++) {
-						switch (varbinds.get(i).type) {
-						case OctetString :
-							varbind[i] = new String(varbinds.get(i).object, charset);
-							break;
-						case Opaque :
-							varbind[i] = new String(varbinds.get(i).object, charset);
-							break;
-						default :
-							varbind[i] = new String(varbinds.get(i).object);
-						}
-					}
+					String[] varbind = null;
 					String varbindStr = "";
-					if (_orgMessageVarbind) {
-						for (String value : varbind) {
-							if (varbindStr.length() == 0) {
-								varbindStr = "VarBind=" + value;
-							} else {
-								varbindStr += ", " + value;
+					if(varbinds != null) {
+						varbind = new String[varbinds.size()];
+						for (int i = 0; i < varbinds.size(); i++) {
+							switch (varbinds.get(i).type) {
+							case OctetString :
+								varbind[i] = new String(varbinds.get(i).object, charset);
+								break;
+							case Opaque :
+								varbind[i] = new String(varbinds.get(i).object, charset);
+								break;
+							default :
+								varbind[i] = new String(varbinds.get(i).object);
 							}
 						}
-						varbindStr += " \n";
+						if (_orgMessageVarbind) {
+							for (String value : varbind) {
+								if (varbindStr.length() == 0) {
+									varbindStr = "VarBind=" + value;
+								} else {
+									varbindStr += ", " + value;
+								}
+							}
+							varbindStr += " \n";
+						}
 					}
 					String communityStr = "";
 					if (_orgMessageCommunity) {
@@ -518,19 +522,22 @@ public class SnmpTrapMonitor implements SnmpTrapHandler {
 				}
 
 				tm.commit();
+				warn = false;
 			} catch (Exception e) {
 				log.warn("unexpected internal error. [" + snmptrap + "] : "
 						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-
-				// Internal Event
-				AplLogger apllog = new AplLogger("TRAP", "trap");
-				String[] args = {snmptrap.enterpriseId, String.valueOf(snmptrap.genericId), String.valueOf(snmptrap.specificId)};
-				apllog.put("SYS", "009", args);
 			} finally {
 				if (tm != null) {
 					tm.close();
 				}
 			}
+			
+			if(warn) {
+				// Internal Event
+				AplLogger apllog = new AplLogger("TRAP", "trap");
+				String[] args = {snmptrap.enterpriseId, String.valueOf(snmptrap.genericId), String.valueOf(snmptrap.specificId)};
+				apllog.put("SYS", "009", args);
+			}
 		}
 	}
 
