@@ -15,12 +15,9 @@
 
 package com.clustercontrol.systemlog.factory;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.ModifyMonitorStringValueType;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 /**
  * システムログ監視情報をマネージャで変更するクラス<BR>
@@ -35,8 +32,7 @@ public class ModifyMonitorSystemlogString extends ModifyMonitorStringValueType{
 	 * @see com.clustercontrol.monitor.run.factory.ModifyMonitor#modifyCheckInfo()
 	 */
 	@Override
-	protected boolean modifyCheckInfo() throws CreateException, FinderException, NamingException {
-
+	protected boolean modifyCheckInfo() throws MonitorNotFound {
 		// システムログ監視のチェック条件はないため、常にtrue
 		return true;
 	}
@@ -53,7 +49,7 @@ public class ModifyMonitorSystemlogString extends ModifyMonitorStringValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_NONE;
+	protected TriggerType getTriggerType() {
+		return TriggerType.NONE;
 	}
 }
